@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,41 +35,76 @@
  */
 package net.sourceforge.plantuml;
 
-import static net.sourceforge.plantuml.ugraphic.ImageBuilder.imageBuilder;
+
 
 import java.io.IOException;
 import java.io.OutputStream;
+import java.util.Collection;
+import java.util.EnumSet;
 import java.util.Objects;
+import java.util.Set;
 
-import net.sourceforge.plantuml.command.BlocLines;
+import net.atmp.ImageBuilder;
+import net.sourceforge.plantuml.abel.DisplayPositioned;
+import net.sourceforge.plantuml.abel.DisplayPositionned;
 import net.sourceforge.plantuml.command.Command;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.ProtectedCommand;
 import net.sourceforge.plantuml.core.Diagram;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.core.UmlSource;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
-import net.sourceforge.plantuml.cucadiagram.DisplayPositionned;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorMapper;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.UFont;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.shape.UText;
+import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
 import net.sourceforge.plantuml.stats.StatsUtilsIncrement;
 import net.sourceforge.plantuml.style.ClockwiseTopRightBottomLeft;
-import net.sourceforge.plantuml.ugraphic.ImageBuilder;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.text.BackSlash;
+import net.sourceforge.plantuml.utils.BlocLines;
 import net.sourceforge.plantuml.version.License;
 import net.sourceforge.plantuml.version.Version;
+import net.sourceforge.plantuml.warning.Warning;
+import net.sourceforge.plantuml.warning.WarningHandler;
 
-public abstract class AbstractPSystem implements Diagram {
+/**
+ * An abstract class for all diagram classes.
+ * 
+ * <p>
+ * Short for "{@link net.sourceforge.plantuml.plasma plasma} system", although
+ * most newer diagram types do not use entities stored in a plasma.
+ *
+ * @see PSystemBuilder
+ */
+public abstract class AbstractPSystem implements Diagram, WarningHandler {
+	// ::remove file when __HAXE__
 
 	private final UmlSource source;
 	private Scale scale;
 	private int splitPagesHorizontal = 1;
 	private int splitPagesVertical = 1;
 
-	public AbstractPSystem(UmlSource source) {
+	private String namespaceSeparator = null;
+	private final PreprocessingArtifact preprocessing;
+
+	public void setNamespaceSeparator(String namespaceSeparator) {
+		this.namespaceSeparator = namespaceSeparator;
+	}
+
+	final public String getNamespaceSeparator() {
+		return namespaceSeparator;
+	}
+
+	public AbstractPSystem(UmlSource source, PreprocessingArtifact preprocessing) {
 		this.source = Objects.requireNonNull(source);
+		this.preprocessing = preprocessing;
 	}
 
 	private String getVersion() {
@@ -78,22 +113,24 @@ public abstract class AbstractPSystem implements Diagram {
 		toAppend.append(Version.versionString());
 		toAppend.append("(" + Version.compileTimeString() + ")\n");
 		toAppend.append("(" + License.getCurrent() + " source distribution)\n");
+		// ::comment when __CORE__
 		for (String name : OptionPrint.interestingProperties()) {
 			toAppend.append(name);
 			toAppend.append(BackSlash.CHAR_NEWLINE);
 		}
+		// ::done
 		return toAppend.toString();
 	}
 
 	final public String getMetadata() {
-		if (source == null) {
+		if (source == null)
 			return getVersion();
-		}
-		final String rawString = source.getRawString();
-		final String plainString = source.getPlainString();
-		if (rawString != null && rawString.equals(plainString)) {
+
+		final String rawString = source.getRawString("\n");
+		final String plainString = source.getPlainString("\n");
+		if (rawString != null && rawString.equals(plainString))
 			return rawString + BackSlash.NEWLINE + getVersion();
-		}
+
 		return rawString + BackSlash.NEWLINE + plainString + BackSlash.NEWLINE + getVersion();
 	}
 
@@ -102,9 +139,9 @@ public abstract class AbstractPSystem implements Diagram {
 	}
 
 	final public long seed() {
-		if (source == null) {
+		if (source == null)
 			return 42;
-		}
+
 		return getSource().seed();
 	}
 
@@ -131,9 +168,9 @@ public abstract class AbstractPSystem implements Diagram {
 	}
 
 	public DisplayPositionned getTitle() {
-		if (source == null) {
+		if (source == null)
 			return DisplayPositioned.single(Display.empty(), HorizontalAlignment.CENTER, VerticalAlignment.TOP);
-		}
+
 		return DisplayPositioned.single(source.getTitle(), HorizontalAlignment.CENTER, VerticalAlignment.TOP);
 	}
 
@@ -152,10 +189,10 @@ public abstract class AbstractPSystem implements Diagram {
 		return true;
 	}
 
-	public CommandExecutionResult executeCommand(Command cmd, BlocLines lines) {
+	public CommandExecutionResult executeCommand(Command cmd, BlocLines lines, ParserPass currentPass) {
 		cmd = new ProtectedCommand(cmd);
 		try {
-			return cmd.execute(this, lines);
+			return cmd.execute(this, lines, currentPass);
 		} catch (NoSuchColorException e) {
 			return CommandExecutionResult.badColor();
 		}
@@ -178,10 +215,12 @@ public abstract class AbstractPSystem implements Diagram {
 //			}
 			return exportDiagramNow(os, index, fileFormatOption);
 		} finally {
-			if (OptionFlags.getInstance().isEnableStats()) {
+			// ::comment when __CORE__
+			if (OptionFlags.getInstance().isEnableStats())
 				StatsUtilsIncrement.onceMoreGenerate(System.currentTimeMillis() - now, getClass(),
 						fileFormatOption.getFileFormat());
-			}
+
+			// ::done
 		}
 	}
 
@@ -196,7 +235,7 @@ public abstract class AbstractPSystem implements Diagram {
 	public ImageBuilder createImageBuilder(FileFormatOption fileFormatOption) throws IOException {
 		final ColorMapper init = fileFormatOption.getColorMapper();
 		final ColorMapper newColorMappter = muteColorMapper(init);
-		return imageBuilder(fileFormatOption.withColorMapper(newColorMappter));
+		return ImageBuilder.create(fileFormatOption.withColorMapper(newColorMappter));
 	}
 
 	protected ColorMapper muteColorMapper(ColorMapper init) {
@@ -213,7 +252,37 @@ public abstract class AbstractPSystem implements Diagram {
 
 	@Override
 	public Display getTitleDisplay() {
-		return null;
+		return Display.NULL;
+	}
+
+	@Override
+	public void exportDiagramGraphic(UGraphic ug, FileFormatOption fileFormatOption) {
+		final UFont font = UFont.monospaced(14);
+		final FontConfiguration fc = FontConfiguration.blackBlueTrue(font);
+		final UText text = UText.build("Not implemented yet for " + getClass().getName(), fc);
+		ug.apply(new UTranslate(10, 10)).draw(text);
+	}
+
+	public Set<ParserPass> getRequiredPass() {
+		return EnumSet.of(ParserPass.ONE);
+	}
+
+	public void startingPass(ParserPass pass) {
+	}
+
+	final public PreprocessingArtifact getPreprocessingArtifact() {
+		return preprocessing;
+	}
+
+	@Override
+	public void addWarning(Warning warning) {
+		throw new UnsupportedOperationException();
+
+	}
+
+	@Override
+	public Collection<Warning> getWarnings() {
+		return preprocessing.getWarnings();
 	}
 
 }
