@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,14 +35,15 @@
  */
 package net.sourceforge.plantuml;
 
-import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.abel.DisplayPositioned;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.svek.DecorateEntityImage;
-import net.sourceforge.plantuml.svek.TextBlockBackcolored;
 
 public class AnnotatedWorker {
+	// ::remove file when __HAXE__
 
 	private final Annotated annotated;
 	private final ISkinParam skinParam;
@@ -57,13 +58,13 @@ public class AnnotatedWorker {
 		this.builder = builder;
 	}
 
-	public TextBlockBackcolored addAdd(TextBlock result) {
+	public TextBlock addAdd(TextBlock result) {
 		result = builder.decoreWithFrame(result);
 		result = addLegend(result);
 		result = addTitle(result);
 		result = addCaption(result);
 		result = builder.addHeaderAndFooter(result);
-		return (TextBlockBackcolored) result;
+		return (TextBlock) result;
 	}
 
 	public TextBlock addLegend(TextBlock original) {
