@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -37,35 +37,44 @@ package net.sourceforge.plantuml;
 
 import java.io.IOException;
 import java.io.InputStream;
-import java.util.Map;
+import java.util.Collection;
+import java.util.LinkedHashSet;
 
-import net.sourceforge.plantuml.anim.Animation;
-import net.sourceforge.plantuml.anim.AnimationDecoder;
+import net.atmp.ImageBuilder;
+import net.sourceforge.plantuml.abel.DisplayPositioned;
+import net.sourceforge.plantuml.abel.DisplayPositionned;
+import net.sourceforge.plantuml.annotation.DuplicateCode;
 import net.sourceforge.plantuml.api.ApiStable;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.core.Diagram;
 import net.sourceforge.plantuml.core.UmlSource;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.DisplayPositioned;
-import net.sourceforge.plantuml.cucadiagram.DisplayPositionned;
 import net.sourceforge.plantuml.cucadiagram.DisplaySection;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.VerticalAlignment;
-import net.sourceforge.plantuml.sprite.Sprite;
+import net.sourceforge.plantuml.klimt.color.ColorMapper;
+import net.sourceforge.plantuml.klimt.color.ColorOrder;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColors;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.sprite.Sprite;
+import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
+import net.sourceforge.plantuml.skin.Pragma;
+import net.sourceforge.plantuml.skin.SkinParam;
+import net.sourceforge.plantuml.skin.UmlDiagramType;
 import net.sourceforge.plantuml.style.ClockwiseTopRightBottomLeft;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleLoader;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
-import net.sourceforge.plantuml.ugraphic.ImageBuilder;
-import net.sourceforge.plantuml.ugraphic.color.ColorMapper;
-import net.sourceforge.plantuml.ugraphic.color.ColorOrder;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
+import net.sourceforge.plantuml.warning.Warning;
 
 public abstract class TitledDiagram extends AbstractPSystem implements Diagram, Annotated {
+	// ::remove file when __HAXE__
 
 	public static boolean FORCE_SMETANA = false;
 	public static boolean FORCE_ELK = false;
@@ -81,20 +90,13 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 
 	private final SkinParam skinParam;
 
-	private Animation animation;
-
-	private final Pragma pragma = new Pragma();
-
-	public Pragma getPragma() {
-		return pragma;
-	}
-
-	public TitledDiagram(UmlSource source, UmlDiagramType type, Map<String, String> orig) {
-		super(source);
+	public TitledDiagram(UmlSource source, UmlDiagramType type, Previous previous,
+			PreprocessingArtifact preprocessing) {
+		super(source, preprocessing);
 		this.type = type;
-		this.skinParam = SkinParam.create(type);
-		if (orig != null)
-			this.skinParam.copyAllFrom(orig);
+		this.skinParam = SkinParam.create(type, Pragma.createEmpty(), preprocessing.getOption());
+		if (previous != null)
+			this.skinParam.copyAllFrom(previous);
 
 	}
 
@@ -118,6 +120,7 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 		skinParam.addSprite(name, sprite);
 	}
 
+	@DuplicateCode(reference = "StyleExtractor")
 	public CommandExecutionResult loadSkin(String newSkin) throws IOException {
 		final String filename = newSkin + ".skin";
 		final InputStream is = StyleLoader.getInputStreamForStyle(filename);
@@ -127,52 +130,8 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 
 		getSkinParam().setDefaultSkin(filename);
 		return CommandExecutionResult.ok();
-		// final String res = "/skin/" + filename + ".skin";
-		// final InputStream internalIs = UmlDiagram.class.getResourceAsStream(res);
-		// if (internalIs != null) {
-		// final BlocLines lines2 = BlocLines.load(internalIs, new
-		// LineLocationImpl(filename, null));
-		// return loadSkinInternal(lines2);
-		// }
-		// if (OptionFlags.ALLOW_INCLUDE == false) {
-		// return CommandExecutionResult.ok();
-		// }
-		// final File f = FileSystem.getInstance().getFile(filename + ".skin");
-		// if (f == null || f.exists() == false || f.canRead() == false) {
-		// return CommandExecutionResult.error("Cannot load skin from " + filename);
-		// }
-		// final BlocLines lines = BlocLines.load(f, new LineLocationImpl(f.getName(),
-		// null));
-		// return loadSkinInternal(lines);
 	}
 
-	// private CommandExecutionResult loadSkinInternal(final BlocLines lines) {
-	// final CommandSkinParam cmd1 = new CommandSkinParam();
-	// final CommandSkinParamMultilines cmd2 = new CommandSkinParamMultilines();
-	// for (int i = 0; i < lines.size(); i++) {
-	// final BlocLines ext1 = lines.subList(i, i + 1);
-	// if (cmd1.isValid(ext1) == CommandControl.OK) {
-	// cmd1.execute(this, ext1);
-	// } else if (cmd2.isValid(ext1) == CommandControl.OK_PARTIAL) {
-	// i = tryMultilines(cmd2, i, lines);
-	// }
-	// }
-	// return CommandExecutionResult.ok();
-	// }
-
-//	private int tryMultilines(CommandSkinParamMultilines cmd2, int i, BlocLines lines) {
-//		for (int j = i + 1; j <= lines.size(); j++) {
-//			final BlocLines ext1 = lines.subList(i, j);
-//			if (cmd2.isValid(ext1) == CommandControl.OK) {
-//				cmd2.execute(this, ext1);
-//				return j;
-//			} else if (cmd2.isValid(ext1) == CommandControl.NOT_OK) {
-//				return j;
-//			}
-//		}
-//		return i;
-//	}
-
 	final public void setTitle(DisplayPositioned title) {
 		if (title.isNull() || title.getDisplay().isWhite())
 			return;
@@ -188,7 +147,7 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 	@ApiStable
 	final public Display getTitleDisplay() {
 		if (title == null)
-			return null;
+			return Display.NULL;
 		return title.getDisplay();
 	}
 
@@ -245,6 +204,7 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 		if (FORCE_SMETANA)
 			return true;
 		return useSmetana;
+		// return true;
 	}
 
 	@Override
@@ -252,19 +212,6 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 		return ClockwiseTopRightBottomLeft.same(10);
 	}
 
-	final public void setAnimation(Iterable<CharSequence> animationData) {
-//		try {
-		final AnimationDecoder animationDecoder = new AnimationDecoder(animationData);
-		this.animation = Animation.create(animationDecoder.decode());
-//		} catch (ScriptException e) {
-//			Logme.error(e);
-//		}
-	}
-
-	final public Animation getAnimation() {
-		return animation;
-	}
-
 	@Override
 	public ImageBuilder createImageBuilder(FileFormatOption fileFormatOption) throws IOException {
 		return super.createImageBuilder(fileFormatOption).styled(this);
@@ -283,7 +230,7 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 
 	@Override
 	protected ColorMapper muteColorMapper(ColorMapper init) {
-		if ("dark".equalsIgnoreCase(getSkinParam().getValue("mode")))
+		if (SkinParam.isDark(getSkinParam()))
 			return ColorMapper.DARK_MODE;
 		final String monochrome = getSkinParam().getValue("monochrome");
 		if ("true".equals(monochrome))
@@ -306,4 +253,33 @@ public abstract class TitledDiagram extends AbstractPSystem implements Diagram,
 
 	}
 
+	protected abstract TextBlock getTextMainBlock(FileFormatOption fileFormatOption);
+
+	@Override
+	public void exportDiagramGraphic(UGraphic ug, FileFormatOption fileFormatOption) {
+		final TextBlock textBlock = getTextMainBlock(fileFormatOption);
+		textBlock.drawU(ug);
+	}
+
+	final public Pragma getPragma() {
+		return skinParam.getPragma();
+	}
+
+	@Override
+	public void addWarning(Warning warning) {
+		getPragma().addWarning(warning);
+	}
+
+	@Override
+	public Collection<Warning> getWarnings() {
+		return join(getPreprocessingArtifact().getWarnings(), getPragma().getWarnings());
+	}
+
+	static private Collection<Warning> join(Collection<Warning> col1, Collection<Warning> col2) {
+		final LinkedHashSet<Warning> result = new LinkedHashSet<>();
+		result.addAll(col1);
+		result.addAll(col2);
+		return result;
+	}
+
 }
