@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -38,31 +38,32 @@ package net.sourceforge.plantuml.activitydiagram3;
 import java.util.Collection;
 import java.util.Objects;
 
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.LineBreakStrategy;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactory;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.activitydiagram3.ftile.WeldingPoint;
 import net.sourceforge.plantuml.activitydiagram3.gtile.Gtile;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
-import net.sourceforge.plantuml.creole.CreoleMode;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.Rainbow;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.decoration.Rainbow;
+import net.sourceforge.plantuml.klimt.LineBreakStrategy;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.CreoleMode;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class Branch {
 
@@ -78,7 +79,9 @@ public class Branch {
 	private final HColor color;
 
 	private Ftile ftile;
+	// ::comment when __CORE__
 	private Gtile gtile;
+	// ::done
 
 	public StyleSignatureBasic getDefaultStyleDefinitionArrow() {
 		return StyleSignatureBasic.of(SName.root, SName.element, SName.activityDiagram, SName.arrow);
@@ -93,14 +96,15 @@ public class Branch {
 	}
 
 	public Branch(StyleBuilder styleBuilder, Swimlane swimlane, LinkRendering labelPositive, Display labelTest,
-			HColor color, LinkRendering inlabel) {
+			HColor color, LinkRendering inlabel, Stereotype stereotype) {
 		this.inlabel = Objects.requireNonNull(inlabel);
 		this.labelTest = Objects.requireNonNull(labelTest);
 		this.labelPositive = Objects.requireNonNull(labelPositive);
 
-		final Style style = getDefaultStyleDefinitionDiamond().getMergedStyle(styleBuilder);
-		this.color = color == null ? style.value(PName.BackGroundColor).asColor(
-				styleBuilder.getSkinParam().getIHtmlColorSet()) : color;
+		final Style style = getDefaultStyleDefinitionDiamond().withTOBECHANGED(stereotype).getMergedStyle(styleBuilder);
+		this.color = color == null
+				? style.value(PName.BackGroundColor).asColor(styleBuilder.getSkinParam().getIHtmlColorSet())
+				: color;
 
 		this.list = new InstructionList(swimlane);
 	}
@@ -118,8 +122,8 @@ public class Branch {
 		return list.kill();
 	}
 
-	public boolean addNote(Display note, NotePosition position, NoteType type, Colors colors, Swimlane swimlaneNote) {
-		return list.addNote(note, position, type, colors, swimlaneNote);
+	public boolean addNote(Display note, NotePosition position, NoteType type, Colors colors, Swimlane swimlaneNote, Stereotype stereotype) {
+		return list.addNote(note, position, type, colors, swimlaneNote, stereotype);
 	}
 
 	public final void setInlinkRendering(LinkRendering inlinkRendering) {
@@ -130,9 +134,11 @@ public class Branch {
 		this.ftile = factory.decorateOut(list.createFtile(factory), inlinkRendering);
 	}
 
+	// ::comment when __CORE__
 	public void updateGtile(ISkinParam skinParam, StringBounder stringBounder) {
 		this.gtile = list.createGtile(skinParam, stringBounder);
 	}
+	// ::done
 
 	public Collection<? extends Swimlane> getSwimlanes() {
 		return list.getSwimlanes();
@@ -143,30 +149,30 @@ public class Branch {
 	}
 
 	public final Rainbow getOut() {
-		if (special != null) {
+		if (special != null)
 			return special.getRainbow();
-		}
-//		if (labelPositive.getRainbow().size() > 0) {
+
+//		if (labelPositive.getRainbow().size() > 0)
 //			return labelPositive.getRainbow();
-//		}
-		if (inlinkRendering == null) {
+
+		if (inlinkRendering == null)
 			return null;
-		}
+
 		return inlinkRendering.getRainbow();
 	}
 
 	public Rainbow getInColor(Rainbow arrowColor) {
-		if (isEmpty()) {
+		if (isEmpty())
 			return getFtile().getOutLinkRendering().getRainbow(arrowColor);
-		}
-		if (labelPositive.getRainbow().size() > 0) {
+
+		if (labelPositive.getRainbow().size() > 0)
 			return labelPositive.getRainbow();
-		}
+
 		final LinkRendering linkIn = getFtile().getInLinkRendering();
 		final Rainbow color = linkIn.getRainbow(arrowColor);
-		if (color.size() == 0) {
+		if (color.size() == 0)
 			return arrowColor;
-		}
+
 		return color;
 	}
 
@@ -186,13 +192,17 @@ public class Branch {
 		return ftile;
 	}
 
+	// ::comment when __CORE__
 	public Gtile getGtile() {
 		return gtile;
 	}
+	// ::done
 
 	public ISkinParam skinParam() {
+		// ::comment when __CORE__
 		if (gtile != null)
 			return gtile.skinParam();
+		// ::done
 		return ftile.skinParam();
 	}
 
@@ -223,17 +233,17 @@ public class Branch {
 	public final Display getDisplayPositive() {
 		if (ftile != null) {
 			final LinkRendering in = ftile.getInLinkRendering();
-			if (in != null && Display.isNull(in.getDisplay()) == false) {
+			if (in != null && Display.isNull(in.getDisplay()) == false)
 				return in.getDisplay();
-			}
+
 		}
 		return labelPositive.getDisplay();
 	}
 
 	public Display getSpecialDisplay() {
-		if (special != null && Display.isNull(special.getDisplay()) == false) {
+		if (special != null && Display.isNull(special.getDisplay()) == false)
 			return special.getDisplay();
-		}
+
 		return null;
 	}
 
