@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -42,25 +42,25 @@ import java.util.List;
 import java.util.Objects;
 import java.util.Set;
 
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.Url;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileDecorateWelding;
 import net.sourceforge.plantuml.activitydiagram3.ftile.FtileFactory;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.activitydiagram3.ftile.WeldingPoint;
-import net.sourceforge.plantuml.activitydiagram3.ftile.vcompact.FtileWithNoteOpale;
 import net.sourceforge.plantuml.activitydiagram3.gtile.Gtile;
 import net.sourceforge.plantuml.activitydiagram3.gtile.GtileIfAlone;
 import net.sourceforge.plantuml.activitydiagram3.gtile.GtileIfHexagon;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.VerticalAlignment;
-import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.sequencediagram.NoteType;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
+import net.sourceforge.plantuml.style.StyleBuilder;
+import net.sourceforge.plantuml.url.Url;
 
 public class InstructionIf extends WithNote implements Instruction, InstructionCollection {
 
@@ -75,31 +75,34 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 	private Branch current;
 	private final LinkRendering topInlinkRendering;
 	private LinkRendering outColor = LinkRendering.none();
+	private final Stereotype stereotype;
 
 	private final Swimlane swimlane;
+	private final StyleBuilder currentStyleBuilder;
 
 	@Override
 	public boolean containsBreak() {
-		for (Branch branch : thens) {
-			if (branch.containsBreak()) {
+		for (Branch branch : thens)
+			if (branch.containsBreak())
 				return true;
-			}
-		}
-		if (elseBranch != null) {
+
+		if (elseBranch != null)
 			return elseBranch.containsBreak();
-		}
+
 		return false;
 	}
 
 	public InstructionIf(Swimlane swimlane, Instruction parent, Display labelTest, LinkRendering whenThen,
-			LinkRendering inlinkRendering, HColor color, ISkinParam skinParam, Url url) {
+			LinkRendering inlinkRendering, HColor color, ISkinParam skinParam, Url url, Stereotype stereotype) {
 		this.url = url;
+		this.stereotype = stereotype;
 		this.parent = parent;
 		this.skinParam = skinParam;
 		this.topInlinkRendering = Objects.requireNonNull(inlinkRendering);
 		this.swimlane = swimlane;
-		this.thens.add(new Branch(skinParam.getCurrentStyleBuilder(), swimlane, whenThen, labelTest, color,
-				LinkRendering.none()));
+		this.currentStyleBuilder = skinParam.getCurrentStyleBuilder();
+		this.thens.add(new Branch(currentStyleBuilder, swimlane, whenThen, labelTest, color, LinkRendering.none(),
+				stereotype));
 		this.current = this.thens.get(0);
 	}
 
@@ -108,6 +111,7 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 		return current.add(ins);
 	}
 
+	// ::comment when __CORE__
 	@Override
 	public Gtile createGtile(ISkinParam skinParam, StringBounder stringBounder) {
 		for (Branch branch : thens)
@@ -129,29 +133,31 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 			return new GtileIfAlone(swimlane, gtiles.get(0), branches.get(0));
 		return GtileIfHexagon.build(swimlane, gtiles, branches);
 	}
+	// ::done
 
 	@Override
 	public Ftile createFtile(FtileFactory factory) {
-		for (Branch branch : thens) {
+		for (Branch branch : thens)
 			branch.updateFtile(factory);
-		}
+
 		if (elseBranch == null)
-			this.elseBranch = new Branch(skinParam.getCurrentStyleBuilder(), swimlane, LinkRendering.none(),
-					Display.NULL, null, LinkRendering.none());
+			this.elseBranch = new Branch(currentStyleBuilder, swimlane, LinkRendering.none(),
+					Display.NULL, null, LinkRendering.none(), stereotype);
 
 		elseBranch.updateFtile(factory);
-		Ftile result = factory.createIf(swimlane, thens, elseBranch, outColor, topInlinkRendering, url);
-		if (getPositionedNotes().size() > 0) {
-			result = FtileWithNoteOpale.create(result, getPositionedNotes(), skinParam, false, VerticalAlignment.CENTER);
-		}
+		Ftile result = factory.createIf(swimlane, thens, elseBranch, outColor, topInlinkRendering, url,
+				getPositionedNotes(), stereotype, currentStyleBuilder);
+//		if (getPositionedNotes().size() > 0)
+//			result = FtileWithNoteOpale.create(result, getPositionedNotes(), false, VerticalAlignment.CENTER);
+
 		final List<WeldingPoint> weldingPoints = new ArrayList<>();
-		for (Branch branch : thens) {
+		for (Branch branch : thens)
 			weldingPoints.addAll(branch.getWeldingPoints());
-		}
+
 		weldingPoints.addAll(elseBranch.getWeldingPoints());
-		if (weldingPoints.size() > 0) {
+		if (weldingPoints.size() > 0)
 			result = new FtileDecorateWelding(result, weldingPoints);
-		}
+
 		return result;
 	}
 
@@ -160,24 +166,26 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 	}
 
 	public boolean swithToElse2(LinkRendering whenElse, LinkRendering nextLinkRenderer) {
-		if (elseBranch != null) {
+		this.current.setSpecial(nextLinkRenderer);
+
+		if (elseBranch != null)
 			return false;
-		}
+
 		this.current.setInlinkRendering(nextLinkRenderer);
 		this.elseBranch = new Branch(skinParam.getCurrentStyleBuilder(), swimlane, whenElse, Display.NULL, null,
-				LinkRendering.none());
+				LinkRendering.none(), stereotype);
 		this.current = elseBranch;
 		return true;
 	}
 
 	public boolean elseIf(LinkRendering inlabel, Display test, LinkRendering whenThen, LinkRendering nextLinkRenderer,
 			HColor color) {
-		if (elseBranch != null) {
+		if (elseBranch != null)
 			return false;
-		}
-		// this.current.setInlinkRendering(nextLinkRenderer);
+
 		this.current.setSpecial(nextLinkRenderer);
-		this.current = new Branch(skinParam.getCurrentStyleBuilder(), swimlane, whenThen, test, color, inlabel);
+		this.current = new Branch(skinParam.getCurrentStyleBuilder(), swimlane, whenThen, test, color, inlabel,
+				stereotype);
 		this.thens.add(current);
 		return true;
 
@@ -185,27 +193,27 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 
 	public void endif(LinkRendering nextLinkRenderer) {
 		endifCalled = true;
-		if (elseBranch == null) {
+		if (elseBranch == null)
 			this.elseBranch = new Branch(skinParam.getCurrentStyleBuilder(), swimlane, LinkRendering.none(),
-					Display.NULL, null, LinkRendering.none());
-		}
+					Display.NULL, null, LinkRendering.none(), stereotype);
+
 		this.elseBranch.setSpecial(nextLinkRenderer);
 		this.current.setInlinkRendering(nextLinkRenderer);
 	}
 
 	@Override
 	final public boolean kill() {
-		if (endifCalled) {
+		if (endifCalled)
 			for (Branch branch : thens) {
-				if (branch.getLast() != null && branch.getLast().kill() == false) {
+				if (branch.getLast() != null && branch.getLast().kill() == false)
 					return false;
-				}
-				if (elseBranch != null && elseBranch.getLast() != null && elseBranch.getLast().kill() == false) {
+
+				if (elseBranch != null && elseBranch.getLast() != null && elseBranch.getLast().kill() == false)
 					return false;
-				}
+
 				return true;
 			}
-		}
+
 		return current.kill();
 	}
 
@@ -215,26 +223,26 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 	}
 
 	@Override
-	public boolean addNote(Display note, NotePosition position, NoteType type, Colors colors, Swimlane swimlaneNote) {
-		if (endifCalled || current.isEmpty()) {
-			return super.addNote(note, position, type, colors, swimlaneNote);
-		} else {
-			return current.addNote(note, position, type, colors, swimlaneNote);
-		}
+	public boolean addNote(Display note, NotePosition position, NoteType type, Colors colors, Swimlane swimlaneNote, Stereotype stereotype) {
+		if (endifCalled || current.isEmpty())
+			return super.addNote(note, position, type, colors, swimlaneNote, stereotype);
+		else
+			return current.addNote(note, position, type, colors, swimlaneNote, stereotype);
+
 	}
 
 	@Override
 	public Set<Swimlane> getSwimlanes() {
 		final Set<Swimlane> result = new HashSet<>();
-		if (swimlane != null) {
+		if (swimlane != null)
 			result.add(swimlane);
-		}
-		for (Branch branch : thens) {
+
+		for (Branch branch : thens)
 			result.addAll(branch.getSwimlanes());
-		}
-		if (elseBranch != null) {
+
+		if (elseBranch != null)
 			result.addAll(elseBranch.getSwimlanes());
-		}
+
 		return Collections.unmodifiableSet(result);
 	}
 
@@ -250,9 +258,9 @@ public class InstructionIf extends WithNote implements Instruction, InstructionC
 
 	@Override
 	public Instruction getLast() {
-		if (elseBranch == null) {
+		if (elseBranch == null)
 			return thens.get(thens.size() - 1).getLast();
-		}
+
 		return elseBranch.getLast();
 	}
 
