@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,22 +35,24 @@
  */
 package net.sourceforge.plantuml.activitydiagram3.command;
 
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.activitydiagram3.ActivityDiagram3;
 import net.sourceforge.plantuml.activitydiagram3.LinkRendering;
 import net.sourceforge.plantuml.activitydiagram3.ftile.BoxStyle;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexOptional;
-import net.sourceforge.plantuml.command.regex.RegexOr;
-import net.sourceforge.plantuml.command.regex.RegexResult;
-import net.sourceforge.plantuml.cucadiagram.Display;
+import net.sourceforge.plantuml.decoration.Rainbow;
 import net.sourceforge.plantuml.descdiagram.command.CommandLinkElement;
-import net.sourceforge.plantuml.graphic.Rainbow;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexOptional;
+import net.sourceforge.plantuml.regex.RegexOr;
+import net.sourceforge.plantuml.regex.RegexResult;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandBackward3 extends SingleLineCommand2<ActivityDiagram3> {
 
@@ -86,25 +88,34 @@ public class CommandBackward3 extends SingleLineCommand2<ActivityDiagram3> {
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(ActivityDiagram3 diagram, LineLocation location, RegexResult arg) throws NoSuchColorException {
+	protected CommandExecutionResult executeArg(ActivityDiagram3 diagram, LineLocation location, RegexResult arg, ParserPass currentPass)
+			throws NoSuchColorException {
 		final BoxStyle boxStyle;
 		final String styleString = arg.get("STYLE", 0);
 
-		if (styleString == null) {
+		if (styleString == null)
 			boxStyle = BoxStyle.PLAIN;
-		} else {
-			boxStyle = BoxStyle.fromChar(styleString.charAt(0));
-		}
+		else
+			boxStyle = BoxStyle.fromString(styleString);
 
-		final Display label = Display.getWithNewlines(arg.get("LABEL", 0));
+		BoxStyle.checkDeprecatedWarning(diagram, styleString);
+
+		final String stereo = arg.get("STYLE", 1);
+
+		Stereotype stereotype = null;
+		if (stereo != null)
+			stereotype = Stereotype.build(stereo);
+
+		final Display label = Display.getWithNewlines(diagram.getPragma(), arg.get("LABEL", 0));
 
 		final LinkRendering in = getBackRendering(diagram, arg, "INCOMING");
 		final LinkRendering out = getBackRendering(diagram, arg, "OUTCOMING");
 
-		return diagram.backward(label, boxStyle, in, out);
+		return diagram.backward(label, boxStyle, in, out, stereotype);
 	}
 
-	static public LinkRendering getBackRendering(ActivityDiagram3 diagram, RegexResult arg, String name) throws NoSuchColorException {
+	static public LinkRendering getBackRendering(ActivityDiagram3 diagram, RegexResult arg, String name)
+			throws NoSuchColorException {
 		final LinkRendering in;
 		final Rainbow incomingColor = getRainbow(name + "_COLOR", diagram, arg);
 		if (incomingColor == null)
@@ -112,10 +123,11 @@ public class CommandBackward3 extends SingleLineCommand2<ActivityDiagram3> {
 		else
 			in = LinkRendering.create(incomingColor);
 		final String label = arg.get(name, 0);
-		return in.withDisplay(Display.getWithNewlines(label));
+		return in.withDisplay(Display.getWithNewlines(diagram.getPragma(), label));
 	}
 
-	static private Rainbow getRainbow(String key, ActivityDiagram3 diagram, RegexResult arg) throws NoSuchColorException {
+	static private Rainbow getRainbow(String key, ActivityDiagram3 diagram, RegexResult arg)
+			throws NoSuchColorException {
 		final String colorString = arg.get(key, 0);
 		if (colorString == null) {
 			return null;
