@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -38,9 +38,7 @@ package net.sourceforge.plantuml.activitydiagram3.ftile.vcompact;
 import java.util.ArrayList;
 import java.util.List;
 
-import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.activitydiagram3.ftile.AbstractConnection;
-import net.sourceforge.plantuml.activitydiagram3.ftile.Arrows;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Connection;
 import net.sourceforge.plantuml.activitydiagram3.ftile.ConnectionTranslatable;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Ftile;
@@ -52,15 +50,16 @@ import net.sourceforge.plantuml.activitydiagram3.ftile.FtileUtils;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Snake;
 import net.sourceforge.plantuml.activitydiagram3.ftile.Swimlane;
 import net.sourceforge.plantuml.activitydiagram3.ftile.vertical.FtileBlackBlock;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.Rainbow;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.decoration.Rainbow;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
 
 public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 
@@ -76,48 +75,6 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 		this.out = out;
 	}
 
-	protected List<Ftile> getFoo2(List<Ftile> all) {
-		final double maxHeight = computeMaxHeight(all);
-		final double ymargin1 = getSuppSpace1(all, getStringBounder());
-		final double ymargin2 = getSuppSpace2(all, getStringBounder());
-		final List<Ftile> result = new ArrayList<>();
-		for (Ftile ftile : all) {
-			final Ftile newFtile = computeNewFtile(ftile, maxHeight, ymargin1, ymargin2);
-			result.add(newFtile);
-		}
-		return result;
-	}
-
-	private Ftile computeNewFtile(Ftile ftile, double maxHeight, double ymargin1, double ymargin2) {
-		final double spaceArroundBlackBar = 20;
-		final double xMargin = 14;
-		Ftile tmp;
-		tmp = FtileUtils.addHorizontalMargin(ftile, xMargin, xMargin + getSuppForIncomingArrow(ftile));
-		tmp = new FtileHeightFixedCentered(tmp, maxHeight + 2 * spaceArroundBlackBar);
-		tmp = new FtileHeightFixedMarged(ymargin1, tmp, ymargin2);
-		return tmp;
-	}
-
-	private double getSuppForIncomingArrow(Ftile ftile) {
-		final double x1 = getXSuppForDisplay(ftile, ftile.getInLinkRendering().getDisplay());
-		final double x2 = getXSuppForDisplay(ftile, ftile.getOutLinkRendering().getDisplay());
-		return Math.max(x1, x2);
-	}
-
-	private double getXSuppForDisplay(Ftile ftile, Display label) {
-		final TextBlock text = getTextBlock(label);
-		if (text == null)
-			return 0;
-
-		final double textWidth = text.calculateDimension(getStringBounder()).getWidth();
-		final FtileGeometry ftileDim = ftile.calculateDimension(getStringBounder());
-		final double pos2 = ftileDim.getLeft() + textWidth;
-		if (pos2 > ftileDim.getWidth())
-			return pos2 - ftileDim.getWidth();
-
-		return 0;
-	}
-
 	@Override
 	protected Swimlane swimlaneOutForStep2() {
 		return out;
@@ -128,7 +85,7 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 		Ftile result = middle;
 		final List<Connection> conns = new ArrayList<>();
 		final Swimlane swimlaneBlack = in;
-		final Style style = getStyleSignature().getMergedStyle(skinParam().getCurrentStyleBuilder());
+		final Style style = getStyleSignatureArrow().getMergedStyle(skinParam().getCurrentStyleBuilder());
 		final Ftile black = new FtileBlackBlock(skinParam(), swimlaneBlack);
 		double x = 0;
 		for (Ftile tmp : list99) {
@@ -146,33 +103,6 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 		return new FtileAssemblySimple(black, result);
 	}
 
-	private double getSuppSpace1(List<Ftile> all, StringBounder stringBounder) {
-		double result = 0;
-		for (Ftile child : all) {
-			final TextBlock text = getTextBlock(child.getInLinkRendering().getDisplay());
-			if (text == null)
-				continue;
-
-			final XDimension2D dim = text.calculateDimension(stringBounder);
-			result = Math.max(result, dim.getHeight());
-
-		}
-		return result;
-	}
-
-	private double getSuppSpace2(List<Ftile> all, StringBounder stringBounder) {
-		double result = 0;
-		for (Ftile child : all) {
-			final TextBlock text = getTextBlock(child.getOutLinkRendering().getDisplay());
-			if (text == null)
-				continue;
-
-			final XDimension2D dim = text.calculateDimension(stringBounder);
-			result = Math.max(result, dim.getHeight());
-		}
-		return result;
-	}
-
 	private double getJustBeforeBar2(Ftile middle, StringBounder stringBounder) {
 		return barHeight + getHeightOfMiddle(middle);
 	}
@@ -182,9 +112,9 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 		final Swimlane swimlaneBlack = out;
 		final Ftile out = new FtileBlackBlock(skinParam(), swimlaneBlack);
 		((FtileBlackBlock) out).setBlackBlockDimension(result.calculateDimension(getStringBounder()).getWidth(),
-				barHeight);
+				barHeight);	
 		if (label != null)
-			((FtileBlackBlock) out).setLabel(getTextBlock(Display.getWithNewlines(label)));
+			((FtileBlackBlock) out).setLabel(getTextBlock(Display.getWithNewlines(skinParam().getPragma(), label)));
 
 		result = new FtileAssemblySimple(result, out);
 		final List<Connection> conns = new ArrayList<>();
@@ -223,7 +153,7 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 		public void drawU(UGraphic ug) {
 			ug = ug.apply(UTranslate.dx(x));
 			final FtileGeometry geo2 = getFtile2().calculateDimension(getStringBounder());
-			Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown());
+			Snake snake = Snake.create(skinParam(), arrowColor, skinParam().arrows().asToDown());
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
@@ -241,7 +171,7 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 			final XPoint2D p1 = new XPoint2D(geo2.getLeft(), 0);
 			final XPoint2D p2 = new XPoint2D(geo2.getLeft(), geo2.getInY());
 
-			Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown()).ignoreForCompression();
+			Snake snake = Snake.create(skinParam(), arrowColor, skinParam().arrows().asToDown()).ignoreForCompression();
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
@@ -277,7 +207,7 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 			if (geo1.hasPointOut() == false)
 				return;
 
-			Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown());
+			Snake snake = Snake.create(skinParam(), arrowColor, skinParam().arrows().asToDown());
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
@@ -298,7 +228,7 @@ public class ParallelBuilderFork extends AbstractParallelFtilesBuilder {
 			final XPoint2D p1 = new XPoint2D(geo.getLeft(), barHeight + geo.getOutY());
 			final XPoint2D p2 = new XPoint2D(geo.getLeft(), justBeforeBar2);
 
-			Snake snake = Snake.create(skinParam(), arrowColor, Arrows.asToDown()).ignoreForCompression();
+			Snake snake = Snake.create(skinParam(), arrowColor, skinParam().arrows().asToDown()).ignoreForCompression();
 			if (Display.isNull(label) == false)
 				snake = snake.withLabel(getTextBlock(label), arrowHorizontalAlignment());
 
