@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -35,31 +35,32 @@
  */
 package net.sourceforge.plantuml.classdiagram.command;
 
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagram;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.EntityGender;
+import net.sourceforge.plantuml.abel.EntityGenderUtils;
+import net.sourceforge.plantuml.abel.EntityPortion;
+import net.sourceforge.plantuml.abel.LeafType;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexOptional;
-import net.sourceforge.plantuml.command.regex.RegexResult;
-import net.sourceforge.plantuml.cucadiagram.Code;
-import net.sourceforge.plantuml.cucadiagram.EntityGender;
-import net.sourceforge.plantuml.cucadiagram.EntityGenderUtils;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
-import net.sourceforge.plantuml.cucadiagram.EntityUtils;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
-import net.sourceforge.plantuml.cucadiagram.Ident;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
 import net.sourceforge.plantuml.descdiagram.DescriptionDiagram;
 import net.sourceforge.plantuml.objectdiagram.AbstractClassOrObjectDiagram;
+import net.sourceforge.plantuml.plasma.Quark;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexOptional;
+import net.sourceforge.plantuml.regex.RegexResult;
 import net.sourceforge.plantuml.sequencediagram.SequenceDiagram;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandHideShowByGender extends SingleLineCommand2<UmlDiagram> {
 
-	public CommandHideShowByGender() {
+	public static final CommandHideShowByGender ME = new CommandHideShowByGender();
+
+	private CommandHideShowByGender() {
 		super(getRegexConcat());
 	}
 
@@ -79,30 +80,31 @@ public class CommandHideShowByGender extends SingleLineCommand2<UmlDiagram> {
 	}
 
 	private final EntityGender emptyByGender(EntityPortion portion) {
-		if (portion == EntityPortion.METHOD) {
+		if (portion == EntityPortion.METHOD)
 			return EntityGenderUtils.emptyMethods();
-		}
-		if (portion == EntityPortion.FIELD) {
+
+		if (portion == EntityPortion.FIELD)
 			return EntityGenderUtils.emptyFields();
-		}
-		if (portion == EntityPortion.MEMBER) {
+
+		if (portion == EntityPortion.MEMBER)
 			throw new IllegalArgumentException();
-			// return EntityGenderUtils.emptyMembers();
-		}
+		// return EntityGenderUtils.emptyMembers();
+
 		return EntityGenderUtils.all();
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(UmlDiagram diagram, LineLocation location, RegexResult arg) {
-		if (diagram instanceof AbstractClassOrObjectDiagram) {
+	protected CommandExecutionResult executeArg(UmlDiagram diagram, LineLocation location, RegexResult arg,
+			ParserPass currentPass) {
+		if (diagram instanceof AbstractClassOrObjectDiagram)
 			return executeClassDiagram((AbstractClassOrObjectDiagram) diagram, arg);
-		}
-		if (diagram instanceof DescriptionDiagram) {
+
+		if (diagram instanceof DescriptionDiagram)
 			return executeDescriptionDiagram((DescriptionDiagram) diagram, arg);
-		}
-		if (diagram instanceof SequenceDiagram) {
+
+		if (diagram instanceof SequenceDiagram)
 			return executeSequenceDiagram((SequenceDiagram) diagram, arg);
-		}
+
 		// Just ignored
 		return CommandExecutionResult.ok();
 	}
@@ -117,35 +119,37 @@ public class CommandHideShowByGender extends SingleLineCommand2<UmlDiagram> {
 		final EntityPortion portion = getEntityPortion(arg.get("PORTION", 0));
 		final EntityGender gender;
 		final String arg1 = arg.get("GENDER", 0);
-		if (arg1 == null) {
+		if (arg1 == null)
 			gender = EntityGenderUtils.all();
-		} else if (arg1.equalsIgnoreCase("class")) {
+		else if (arg1.equalsIgnoreCase("class"))
 			gender = EntityGenderUtils.byEntityType(LeafType.CLASS);
-		} else if (arg1.equalsIgnoreCase("object")) {
+		else if (arg1.equalsIgnoreCase("object"))
 			gender = EntityGenderUtils.byEntityType(LeafType.OBJECT);
-		} else if (arg1.equalsIgnoreCase("interface")) {
+		else if (arg1.equalsIgnoreCase("interface"))
 			gender = EntityGenderUtils.byEntityType(LeafType.INTERFACE);
-		} else if (arg1.equalsIgnoreCase("enum")) {
+		else if (arg1.equalsIgnoreCase("enum"))
 			gender = EntityGenderUtils.byEntityType(LeafType.ENUM);
-		} else if (arg1.equalsIgnoreCase("abstract")) {
+		else if (arg1.equalsIgnoreCase("abstract"))
 			gender = EntityGenderUtils.byEntityType(LeafType.ABSTRACT_CLASS);
-		} else if (arg1.equalsIgnoreCase("annotation")) {
+		else if (arg1.equalsIgnoreCase("annotation"))
 			gender = EntityGenderUtils.byEntityType(LeafType.ANNOTATION);
-		} else if (arg1.equalsIgnoreCase("protocol")) {
+		else if (arg1.equalsIgnoreCase("protocol"))
 			gender = EntityGenderUtils.byEntityType(LeafType.PROTOCOL);
-		} else if (arg1.equalsIgnoreCase("struct")) {
+		else if (arg1.equalsIgnoreCase("struct"))
 			gender = EntityGenderUtils.byEntityType(LeafType.STRUCT);
-		} else if (arg1.equalsIgnoreCase("exception")) {
+		else if (arg1.equalsIgnoreCase("exception"))
 			gender = EntityGenderUtils.byEntityType(LeafType.EXCEPTION);
-		} else if (arg1.equalsIgnoreCase("metaclass")) {
+		else if (arg1.equalsIgnoreCase("metaclass"))
 			gender = EntityGenderUtils.byEntityType(LeafType.METACLASS);
-		} else if (arg1.equalsIgnoreCase("stereotype")) {
+		else if (arg1.equalsIgnoreCase("stereotype"))
 			gender = EntityGenderUtils.byEntityType(LeafType.STEREOTYPE);
-		} else if (arg1.startsWith("<<")) {
+		else if (arg1.startsWith("<<"))
 			gender = EntityGenderUtils.byStereotype(arg1);
-		} else {
-			final IEntity entity = diagram.getOrCreateLeaf(diagram.buildLeafIdent(arg1), diagram.buildCode(arg1), null,
-					null);
+		else {
+			final Quark<Entity> quark = diagram.quarkInContext(true, diagram.cleanId(arg1));
+			if (quark.getData() == null)
+				return CommandExecutionResult.error("No such element " + quark.getName());
+			final Entity entity = quark.getData();
 			gender = EntityGenderUtils.byEntityAlone(entity);
 		}
 
@@ -159,78 +163,84 @@ public class CommandHideShowByGender extends SingleLineCommand2<UmlDiagram> {
 
 		EntityGender gender = null;
 		String arg1 = arg.get("GENDER", 0);
-		if (arg1 == null) {
+		if (arg1 == null)
 			gender = EntityGenderUtils.all();
-		} else if (arg1.equalsIgnoreCase("class")) {
+		else if (arg1.equalsIgnoreCase("class"))
 			gender = EntityGenderUtils.byEntityType(LeafType.CLASS);
-		} else if (arg1.equalsIgnoreCase("object")) {
+		else if (arg1.equalsIgnoreCase("object"))
 			gender = EntityGenderUtils.byEntityType(LeafType.OBJECT);
-		} else if (arg1.equalsIgnoreCase("interface")) {
+		else if (arg1.equalsIgnoreCase("interface"))
 			gender = EntityGenderUtils.byEntityType(LeafType.INTERFACE);
-		} else if (arg1.equalsIgnoreCase("enum")) {
+		else if (arg1.equalsIgnoreCase("enum"))
 			gender = EntityGenderUtils.byEntityType(LeafType.ENUM);
-		} else if (arg1.equalsIgnoreCase("abstract")) {
+		else if (arg1.equalsIgnoreCase("abstract"))
 			gender = EntityGenderUtils.byEntityType(LeafType.ABSTRACT_CLASS);
-		} else if (arg1.equalsIgnoreCase("annotation")) {
+		else if (arg1.equalsIgnoreCase("annotation"))
 			gender = EntityGenderUtils.byEntityType(LeafType.ANNOTATION);
-		} else if (arg1.equalsIgnoreCase("protocol")) {
+		else if (arg1.equalsIgnoreCase("protocol"))
 			gender = EntityGenderUtils.byEntityType(LeafType.PROTOCOL);
-		} else if (arg1.equalsIgnoreCase("struct")) {
+		else if (arg1.equalsIgnoreCase("struct"))
 			gender = EntityGenderUtils.byEntityType(LeafType.STRUCT);
-		} else if (arg1.equalsIgnoreCase("exception")) {
+		else if (arg1.equalsIgnoreCase("exception"))
 			gender = EntityGenderUtils.byEntityType(LeafType.EXCEPTION);
-		} else if (arg1.equalsIgnoreCase("metaclass")) {
+		else if (arg1.equalsIgnoreCase("metaclass"))
 			gender = EntityGenderUtils.byEntityType(LeafType.METACLASS);
-		} else if (arg1.equalsIgnoreCase("stereotype")) {
+		else if (arg1.equalsIgnoreCase("stereotype"))
 			gender = EntityGenderUtils.byEntityType(LeafType.STEREOTYPE);
-		} else if (arg1.startsWith("<<")) {
+		else if (arg1.startsWith("<<"))
 			gender = EntityGenderUtils.byStereotype(arg1);
-		} else {
+		else {
 			arg1 = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(arg1);
-			final Ident ident = diagram.buildLeafIdent(arg1);
-			final Code code = diagram.V1972() ? ident : diagram.buildCode(arg1);
-			final IEntity entity = diagram.getOrCreateLeaf(ident, code, null, null);
-			gender = EntityGenderUtils.byEntityAlone(entity);
-		}
-		if (gender != null) {
-			final boolean empty = arg.get("EMPTY", 0) != null;
-			final boolean emptyMembers = empty && portion == EntityPortion.MEMBER;
-			if (empty == true && emptyMembers == false) {
-				gender = EntityGenderUtils.and(gender, emptyByGender(portion));
-			}
-			if (EntityUtils.groupRoot(diagram.getCurrentGroup()) == false) {
-				gender = EntityGenderUtils.and(gender, EntityGenderUtils.byPackage(diagram.getCurrentGroup()));
-			}
+			final Quark<Entity> quark = diagram.quarkInContext(true, diagram.cleanId(arg1));
+			if (quark == null)
+				// Not sure it could really happens... to be checked
+				return CommandExecutionResult.error("No such quark " + arg1);
 
-			if (emptyMembers) {
-				diagram.hideOrShow(EntityGenderUtils.and(gender, emptyByGender(EntityPortion.FIELD)),
-						EntityPortion.FIELD, arg.get("COMMAND", 0).equalsIgnoreCase("show"));
-				diagram.hideOrShow(EntityGenderUtils.and(gender, emptyByGender(EntityPortion.METHOD)),
-						EntityPortion.METHOD, arg.get("COMMAND", 0).equalsIgnoreCase("show"));
-			} else {
-				diagram.hideOrShow(gender, portion, arg.get("COMMAND", 0).equalsIgnoreCase("show"));
+			if (portion == EntityPortion.METHOD)
+				gender = EntityGenderUtils.byClassName(arg1);
+			else {
+				Entity entity = quark.getData();
+				if (entity == null)
+					return CommandExecutionResult.error("No such element " + quark.getName());
+				gender = EntityGenderUtils.byEntityAlone(entity);
 			}
 		}
+		final boolean empty = arg.get("EMPTY", 0) != null;
+		final boolean emptyMembers = empty && portion == EntityPortion.MEMBER;
+		if (empty && !emptyMembers)
+			gender = EntityGenderUtils.and(gender, emptyByGender(portion));
+
+		if (!diagram.getCurrentGroup().isRoot())
+			gender = EntityGenderUtils.and(gender, EntityGenderUtils.byPackage(diagram.getCurrentGroup()));
+
+		if (emptyMembers) {
+			diagram.hideOrShow(EntityGenderUtils.and(gender, emptyByGender(EntityPortion.FIELD)), EntityPortion.FIELD,
+					arg.get("COMMAND", 0).equalsIgnoreCase("show"));
+			diagram.hideOrShow(EntityGenderUtils.and(gender, emptyByGender(EntityPortion.METHOD)), EntityPortion.METHOD,
+					arg.get("COMMAND", 0).equalsIgnoreCase("show"));
+		} else
+			diagram.hideOrShow(gender, portion, arg.get("COMMAND", 0).equalsIgnoreCase("show"));
+
 		return CommandExecutionResult.ok();
 	}
 
 	private EntityPortion getEntityPortion(String s) {
 		final String sub = StringUtils.goLowerCase(s.substring(0, 3));
-		if (sub.equals("met")) {
+		if (sub.equals("met"))
 			return EntityPortion.METHOD;
-		}
-		if (sub.equals("mem")) {
+
+		if (sub.equals("mem"))
 			return EntityPortion.MEMBER;
-		}
-		if (sub.equals("att") || sub.equals("fie")) {
+
+		if (sub.equals("att") || sub.equals("fie"))
 			return EntityPortion.FIELD;
-		}
-		if (sub.equals("cir")) {
+
+		if (sub.equals("cir"))
 			return EntityPortion.CIRCLED_CHARACTER;
-		}
-		if (sub.equals("ste")) {
+
+		if (sub.equals("ste"))
 			return EntityPortion.STEREOTYPE;
-		}
+
 		throw new IllegalArgumentException();
 	}
 
