@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,12 +35,13 @@
  */
 package net.sourceforge.plantuml.command;
 
-import net.sourceforge.plantuml.StringLocated;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.Matcher2;
-import net.sourceforge.plantuml.command.regex.MyPattern;
 import net.sourceforge.plantuml.core.Diagram;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.Matcher2;
+import net.sourceforge.plantuml.regex.MyPattern;
+import net.sourceforge.plantuml.text.StringLocated;
+import net.sourceforge.plantuml.utils.BlocLines;
 
 public abstract class CommandMultilines2<S extends Diagram> implements Command<S> {
 
@@ -102,19 +103,19 @@ public abstract class CommandMultilines2<S extends Diagram> implements Command<S
 		return finalVerification(lines);
 	}
 
-	public final CommandExecutionResult execute(S system, BlocLines lines) {
+	public final CommandExecutionResult execute(S system, BlocLines lines, ParserPass currentPass) {
 		lines = lines.cleanList(strategy);
 		if (syntaxWithFinalBracket())
 			lines = lines.eventuallyMoveBracket();
 
 		try {
-			return executeNow(system, lines);
+			return executeNow(system, lines, currentPass);
 		} catch (NoSuchColorException e) {
 			return CommandExecutionResult.badColor();
 		}
 	}
 
-	protected abstract CommandExecutionResult executeNow(S system, BlocLines lines) throws NoSuchColorException;
+	protected abstract CommandExecutionResult executeNow(S system, BlocLines lines, ParserPass currentPass) throws NoSuchColorException;
 
 	protected boolean isCommandForbidden() {
 		return false;
@@ -127,5 +128,11 @@ public abstract class CommandMultilines2<S extends Diagram> implements Command<S
 	protected final IRegex getStartingPattern() {
 		return starting;
 	}
+	
+	@Override
+	public boolean isEligibleFor(ParserPass pass) {
+		return pass == ParserPass.ONE;
+	}
+
 
 }
