@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,17 +35,20 @@
  */
 package net.sourceforge.plantuml.command;
 
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.TitledDiagram;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexResult;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexResult;
 import net.sourceforge.plantuml.style.NoStyleAvailableException;
+import net.sourceforge.plantuml.utils.LineLocation;
+import net.sourceforge.plantuml.warning.Warning;
 
 public class CommandSkinParam extends SingleLineCommand2<TitledDiagram> {
 
-	public CommandSkinParam() {
+	public static final CommandSkinParam ME = new CommandSkinParam();
+
+	private CommandSkinParam() {
 		super(getRegexConcat());
 	}
 
@@ -53,15 +56,21 @@ public class CommandSkinParam extends SingleLineCommand2<TitledDiagram> {
 		return RegexConcat.build(CommandSkinParam.class.getName(), RegexLeaf.start(), //
 				new RegexLeaf("TYPE", "(skinparam|skinparamlocked)"), //
 				RegexLeaf.spaceOneOrMore(), //
-				new RegexLeaf("NAME", "([\\w.]*(?:\\<\\<.*\\>\\>)?[\\w.]*)"), //
+				new RegexLeaf("NAME", "([\\w.]*(?:\\<\\<[^<>]*\\>\\>)?[\\w.]*)"), //
 				RegexLeaf.spaceOneOrMore(), //
 				new RegexLeaf("VALUE", "([^{}]*)"), RegexLeaf.end()); //
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(TitledDiagram diagram, LineLocation location, RegexResult arg) {
+	protected CommandExecutionResult executeArg(TitledDiagram diagram, LineLocation location, RegexResult arg,
+			ParserPass currentPass) {
 		try {
-			diagram.setParam(arg.get("NAME", 0), arg.get("VALUE", 0));
+			final String name = arg.get("NAME", 0);
+			if ("handwritten".equalsIgnoreCase(name))
+				diagram.addWarning(new Warning("Please use '!option handwritten true' to enable handwritten "));
+
+			diagram.setParam(name, arg.get("VALUE", 0));
+
 			return CommandExecutionResult.ok();
 		} catch (NoStyleAvailableException e) {
 			// Logme.error(e);
