@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -37,9 +37,10 @@ package net.sourceforge.plantuml.command;
 
 import java.util.Objects;
 
-import net.sourceforge.plantuml.Log;
 import net.sourceforge.plantuml.core.Diagram;
 import net.sourceforge.plantuml.log.Logme;
+import net.sourceforge.plantuml.utils.BlocLines;
+import net.sourceforge.plantuml.utils.Log;
 import net.sourceforge.plantuml.version.Version;
 
 public class ProtectedCommand<S extends Diagram> implements Command<S> {
@@ -50,18 +51,19 @@ public class ProtectedCommand<S extends Diagram> implements Command<S> {
 		this.cmd = Objects.requireNonNull(cmd);
 	}
 
-	public CommandExecutionResult execute(S system, BlocLines lines) {
+	public CommandExecutionResult execute(S system, BlocLines lines, ParserPass currentPass) {
 		try {
-			final CommandExecutionResult result = cmd.execute(system, lines);
+			// WasmLog.log("...running " + cmd.getClass().getName() + " ...");
+			final CommandExecutionResult result = cmd.execute(system, lines, currentPass);
 			// if (result.isOk()) {
 			// // TRACECOMMAND
-			// System.err.println("CMD = " + cmd.getClass());
+			// System.err.println("CMD = " + cmd.getClass() + " " + currentPass);
 			// }
 			return result;
 		} catch (Throwable t) {
 			Log.error("Error " + t);
 			Logme.error(t);
-			String msg = "You should send a mail to plantuml@gmail.com or post to http://plantuml.com/qa with this log (V"
+			String msg = "You should send a mail to plantuml@gmail.com or post to https://plantuml.com/qa with this log (V"
 					+ Version.versionString() + ")";
 			Log.error(msg);
 			msg += " " + t.toString();
@@ -77,4 +79,9 @@ public class ProtectedCommand<S extends Diagram> implements Command<S> {
 		return cmd.getDescription();
 	}
 
+	@Override
+	public boolean isEligibleFor(ParserPass pass) {
+		return cmd.isEligibleFor(pass);
+	}
+
 }
