@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -36,43 +36,41 @@
  */
 package net.sourceforge.plantuml.descdiagram.command;
 
-import net.sourceforge.plantuml.FontParam;
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.UrlBuilder;
-import net.sourceforge.plantuml.UrlMode;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.LeafType;
 import net.sourceforge.plantuml.classdiagram.AbstractEntityDiagram;
 import net.sourceforge.plantuml.classdiagram.command.CommandCreateClassMultilines;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexOptional;
-import net.sourceforge.plantuml.command.regex.RegexOr;
-import net.sourceforge.plantuml.command.regex.RegexResult;
-import net.sourceforge.plantuml.cucadiagram.Code;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.EntityUtils;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.Ident;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
-import net.sourceforge.plantuml.cucadiagram.Stereotag;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
+import net.sourceforge.plantuml.decoration.symbol.USymbol;
+import net.sourceforge.plantuml.decoration.symbol.USymbols;
 import net.sourceforge.plantuml.descdiagram.DescriptionDiagram;
-import net.sourceforge.plantuml.graphic.USymbol;
-import net.sourceforge.plantuml.graphic.USymbols;
-import net.sourceforge.plantuml.graphic.color.ColorParser;
-import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.color.ColorParser;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.font.FontParam;
+import net.sourceforge.plantuml.plasma.Quark;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexOr;
+import net.sourceforge.plantuml.regex.RegexResult;
+import net.sourceforge.plantuml.stereo.Stereotag;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.stereo.StereotypePattern;
+import net.sourceforge.plantuml.url.Url;
+import net.sourceforge.plantuml.url.UrlBuilder;
+import net.sourceforge.plantuml.url.UrlMode;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiagram> {
 
-	public static final String ALL_TYPES = "person|artifact|actor/|actor|folder|card|file|package|rectangle|hexagon|label|node|frame|cloud|database|queue|stack|storage|agent|usecase/|usecase|component|boundary|control|entity|interface|circle|collections|port|portin|portout";
+	public static final String ALL_TYPES = "person|artifact|actor/|actor|folder|card|file|package|rectangle|hexagon|label|node|frame|cloud|action|process|database|queue|stack|storage|agent|usecase/|usecase|component|boundary|control|entity|interface|circle|collections|port|portin|portout";
 
 	public CommandCreateElementFull() {
 		super(getRegexConcat());
@@ -87,47 +85,29 @@ public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiag
 						new RegexLeaf("CODE1", CODE_WITH_QUOTE), //
 						new RegexConcat(//
 								new RegexLeaf("DISPLAY2", DISPLAY), //
-								new RegexOptional( //
-										new RegexConcat( //
-												RegexLeaf.spaceOneOrMore(), //
-												new RegexLeaf("STEREOTYPE2", "(\\<\\<.+\\>\\>)")//
-										)), //
-								RegexLeaf.spaceZeroOrMore(), //
+								StereotypePattern.optional("STEREOTYPE2"), //
 								new RegexLeaf("as"), //
 								RegexLeaf.spaceOneOrMore(), //
 								new RegexLeaf("CODE2", CODE)), //
 						new RegexConcat(//
 								new RegexLeaf("CODE3", CODE), //
-								new RegexOptional( //
-										new RegexConcat( //
-												RegexLeaf.spaceOneOrMore(), //
-												new RegexLeaf("STEREOTYPE3", "(\\<\\<.+\\>\\>)") //
-										)), //
-								RegexLeaf.spaceOneOrMore(), //
+								StereotypePattern.optional("STEREOTYPE3"), //
 								new RegexLeaf("as"), //
 								RegexLeaf.spaceZeroOrMore(), //
 								new RegexLeaf("DISPLAY3", DISPLAY)), //
 						new RegexConcat(//
 								new RegexLeaf("DISPLAY4", DISPLAY_WITHOUT_QUOTE), //
-								new RegexOptional( //
-										new RegexConcat( //
-												RegexLeaf.spaceOneOrMore(), //
-												new RegexLeaf("STEREOTYPE4", "(\\<\\<.+\\>\\>)") //
-										)), //
-								RegexLeaf.spaceZeroOrMore(), //
+								StereotypePattern.optional("STEREOTYPE4"), //
 								new RegexLeaf("as"), //
 								RegexLeaf.spaceOneOrMore(), //
 								new RegexLeaf("CODE4", CODE)) //
 				), //
-				new RegexOptional( //
-						new RegexConcat( //
-								RegexLeaf.spaceZeroOrMore(), //
-								new RegexLeaf("STEREOTYPE", "(\\<\\<.+\\>\\>)") //
-						)), //
 				RegexLeaf.spaceZeroOrMore(), //
-				new RegexLeaf("TAGS", Stereotag.pattern() + "?"), //
+				new RegexLeaf("TAGS1", Stereotag.pattern() + "?"), //
+				StereotypePattern.optional("STEREOTYPE"), //
+				new RegexLeaf("TAGS2", Stereotag.pattern() + "?"), //
 				RegexLeaf.spaceZeroOrMore(), //
-				new RegexLeaf("URL", "(" + UrlBuilder.getRegexp() + ")?"), //
+				UrlBuilder.OPTIONAL, //
 				RegexLeaf.spaceZeroOrMore(), //
 				color().getRegex(), RegexLeaf.end());
 	}
@@ -157,7 +137,7 @@ public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiag
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(DescriptionDiagram diagram, LineLocation location, RegexResult arg)
+	protected CommandExecutionResult executeArg(DescriptionDiagram diagram, LineLocation location, RegexResult arg, ParserPass currentPass)
 			throws NoSuchColorException {
 		String codeRaw = arg.getLazzy("CODE", 0);
 		String displayRaw = arg.getLazzy("DISPLAY", 0);
@@ -229,36 +209,35 @@ public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiag
 
 		}
 
-		final String idShort = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(codeRaw);
-		final Ident ident = diagram.buildLeafIdent(idShort);
-		final Code code = diagram.V1972() ? ident : diagram.buildCode(idShort);
-		if (!diagram.V1972() && diagram.isGroup(code))
-			return CommandExecutionResult.error("This element (" + code.getName() + ") is already defined");
+		final Quark<Entity> quark = diagram.quarkInContext(false, diagram.cleanId(codeRaw));
 
-		if (diagram.V1972() && diagram.isGroupStrict(ident))
-			return CommandExecutionResult.error("This element (" + ident.getName() + ") is already defined");
+		if (diagram.isGroup(quark))
+			return CommandExecutionResult.error("This element (" + quark.getName() + ") is already defined");
 
 		String display = displayRaw;
 		if (display == null)
-			display = code.getName();
+			display = quark.getName();
 
 		display = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(display);
 		final String stereotype = arg.getLazzy("STEREOTYPE", 0);
-		if (existsWithBadType3(diagram, code, ident, type, usymbol))
-			return CommandExecutionResult.error("This element (" + code.getName() + ") is already defined");
+		if (existsWithBadType3(diagram, quark, type, usymbol))
+			return CommandExecutionResult.error("This element (" + quark.getName() + ") is already defined");
 
-		if ((type == LeafType.PORTIN || type == LeafType.PORTOUT) && EntityUtils.groupRoot(diagram.getCurrentGroup()))
+		if ((type == LeafType.PORTIN || type == LeafType.PORTOUT) && diagram.getCurrentGroup().isRoot())
 			return CommandExecutionResult.error("Port can only be used inside an element and not at root level");
 
-		final IEntity entity = diagram.getOrCreateLeaf(ident, code, type, usymbol);
-		entity.setDisplay(Display.getWithNewlines(display));
-		entity.setUSymbol(usymbol);
+		Entity entity = quark.getData();
+		if (entity == null)
+			entity = diagram.reallyCreateLeaf(location, quark, Display.getWithNewlines(diagram.getPragma(), display), type, usymbol);
+
+		entity.setDisplay(Display.getWithNewlines(diagram.getPragma(), display));
+
 		if (stereotype != null)
 			entity.setStereotype(Stereotype.build(stereotype, diagram.getSkinParam().getCircledCharacterRadius(),
 					diagram.getSkinParam().getFont(null, false, FontParam.CIRCLED_CHARACTER),
 					diagram.getSkinParam().getIHtmlColorSet()));
 
-		CommandCreateClassMultilines.addTags(entity, arg.get("TAGS", 0));
+		CommandCreateClassMultilines.addTags(entity, arg.getLazzy("TAGS", 0));
 
 		final String urlString = arg.get("URL", 0);
 		if (urlString != null) {
@@ -276,39 +255,22 @@ public class CommandCreateElementFull extends SingleLineCommand2<DescriptionDiag
 
 		entity.setColors(colors);
 
-		// entity.setSpecificColorTOBEREMOVED(ColorType.BACK,
-		// diagram.getSkinParam().getIHtmlColorSet().getColorIfValid(arg.get("COLOR",
-		// 0)));
 		return CommandExecutionResult.ok();
 	}
 
-	public static boolean existsWithBadType3(AbstractEntityDiagram diagram, Code code, Ident ident, LeafType type,
+	public static boolean existsWithBadType3(AbstractEntityDiagram diagram, Quark<Entity> code, LeafType type,
 			USymbol usymbol) {
-		if (diagram.V1972()) {
-			if (diagram.leafExistSmart(ident) == false)
-				return false;
-
-			final ILeaf other = diagram.getLeafSmart(ident);
-			if (other.getLeafType() != type)
-				return true;
-
-			if (usymbol != null && other.getUSymbol() != usymbol)
-				return true;
-
+		if (code.getData() == null)
 			return false;
-		} else {
-			if (diagram.leafExist(code) == false)
-				return false;
 
-			final ILeaf other = diagram.getLeaf(code);
-			if (other.getLeafType() != type)
-				return true;
+		final Entity other = code.getData();
+		if (other.getLeafType() != type)
+			return true;
 
-			if (usymbol != null && other.getUSymbol() != usymbol)
-				return true;
+		if (usymbol != null && other.getUSymbol() != usymbol)
+			return true;
 
-			return false;
-		}
+		return false;
 	}
 
 	private char getCharEncoding(final String codeRaw) {
