@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,36 +35,34 @@
  */
 package net.sourceforge.plantuml.descdiagram.command;
 
-import net.sourceforge.plantuml.FontParam;
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.UrlBuilder;
-import net.sourceforge.plantuml.UrlMode;
-import net.sourceforge.plantuml.classdiagram.AbstractEntityDiagram;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.LeafType;
 import net.sourceforge.plantuml.classdiagram.ClassDiagram;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexOptional;
-import net.sourceforge.plantuml.command.regex.RegexOr;
-import net.sourceforge.plantuml.command.regex.RegexResult;
-import net.sourceforge.plantuml.cucadiagram.Code;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.Ident;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.graphic.USymbol;
-import net.sourceforge.plantuml.graphic.USymbols;
-import net.sourceforge.plantuml.graphic.color.ColorParser;
-import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.decoration.symbol.USymbol;
+import net.sourceforge.plantuml.decoration.symbol.USymbols;
+import net.sourceforge.plantuml.klimt.color.ColorParser;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.font.FontParam;
+import net.sourceforge.plantuml.plasma.Quark;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexOptional;
+import net.sourceforge.plantuml.regex.RegexOr;
+import net.sourceforge.plantuml.regex.RegexResult;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.url.Url;
+import net.sourceforge.plantuml.url.UrlBuilder;
+import net.sourceforge.plantuml.url.UrlMode;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandCreateElementParenthesis extends SingleLineCommand2<ClassDiagram> {
 
@@ -119,7 +117,7 @@ public class CommandCreateElementParenthesis extends SingleLineCommand2<ClassDia
 								new RegexLeaf("STEREOTYPE", "(\\<\\<.+\\>\\>)") //
 						)), //
 				RegexLeaf.spaceZeroOrMore(), //
-				new RegexLeaf("URL", "(" + UrlBuilder.getRegexp() + ")?"), //
+				UrlBuilder.OPTIONAL, //
 				RegexLeaf.spaceZeroOrMore(), //
 				color().getRegex(), RegexLeaf.end());
 	}
@@ -141,7 +139,7 @@ public class CommandCreateElementParenthesis extends SingleLineCommand2<ClassDia
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(ClassDiagram diagram, LineLocation location, RegexResult arg)
+	protected CommandExecutionResult executeArg(ClassDiagram diagram, LineLocation location, RegexResult arg, ParserPass currentPass)
 			throws NoSuchColorException {
 		String codeRaw = arg.getLazzy("CODE", 0);
 		final String displayRaw = arg.getLazzy("DISPLAY", 0);
@@ -152,32 +150,26 @@ public class CommandCreateElementParenthesis extends SingleLineCommand2<ClassDia
 		type = LeafType.DESCRIPTION;
 		usymbol = USymbols.fromString(symbol, diagram.getSkinParam());
 
-		final String idShort = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(codeRaw);
-		final Ident ident = diagram.buildLeafIdent(idShort);
-		final Code code = diagram.V1972() ? ident : diagram.buildCode(idShort);
-		if (!diagram.V1972() && diagram.isGroup(code)) {
-			return CommandExecutionResult.error("This element (" + code.getName() + ") is already defined");
-		}
-		if (diagram.V1972() && diagram.isGroupStrict(ident)) {
-			return CommandExecutionResult.error("This element (" + ident.getName() + ") is already defined");
-		}
+		final Quark<Entity> quark = diagram.quarkInContext(false, diagram.cleanId(codeRaw));
+		if (quark.getData() != null)
+			return CommandExecutionResult.error("This element (" + quark.getName() + ") is already defined");
+
 		String display = displayRaw;
-		if (display == null) {
-			display = code.getName();
-		}
+		if (display == null)
+			display = quark.getName();
+
 		display = StringUtils.eventuallyRemoveStartingAndEndingDoubleQuote(display);
 		final String stereotype = arg.getLazzy("STEREOTYPE", 0);
-		if (existsWithBadType3(diagram, code, ident, type, usymbol)) {
-			return CommandExecutionResult.error("This element (" + code.getName() + ") is already defined");
-		}
-		final IEntity entity = diagram.getOrCreateLeaf(ident, code, type, usymbol);
-		entity.setDisplay(Display.getWithNewlines(display));
-		entity.setUSymbol(usymbol);
-		if (stereotype != null) {
+		if (CommandCreateElementFull.existsWithBadType3(diagram, quark, type, usymbol))
+			return CommandExecutionResult.error("This element (" + quark.getName() + ") is already defined");
+
+		final Entity entity = diagram.reallyCreateLeaf(location, quark, Display.getWithNewlines(diagram.getPragma(), display), type, usymbol);
+		entity.setDisplay(Display.getWithNewlines(diagram.getPragma(), display));
+
+		if (stereotype != null)
 			entity.setStereotype(Stereotype.build(stereotype, diagram.getSkinParam().getCircledCharacterRadius(),
 					diagram.getSkinParam().getFont(null, false, FontParam.CIRCLED_CHARACTER),
 					diagram.getSkinParam().getIHtmlColorSet()));
-		}
 
 		final String urlString = arg.get("URL", 0);
 		if (urlString != null) {
@@ -189,11 +181,10 @@ public class CommandCreateElementParenthesis extends SingleLineCommand2<ClassDia
 		Colors colors = color().getColor(arg, diagram.getSkinParam().getIHtmlColorSet());
 		final String s = arg.get("LINECOLOR", 1);
 
-		final HColor lineColor = s == null ? null
-				: diagram.getSkinParam().getIHtmlColorSet().getColor(s);
-		if (lineColor != null) {
+		final HColor lineColor = s == null ? null : diagram.getSkinParam().getIHtmlColorSet().getColor(s);
+		if (lineColor != null)
 			colors = colors.add(ColorType.LINE, lineColor);
-		}
+
 		entity.setColors(colors);
 
 		// entity.setSpecificColorTOBEREMOVED(ColorType.BACK,
@@ -202,35 +193,6 @@ public class CommandCreateElementParenthesis extends SingleLineCommand2<ClassDia
 		return CommandExecutionResult.ok();
 	}
 
-	public static boolean existsWithBadType3(AbstractEntityDiagram diagram, Code code, Ident ident, LeafType type,
-			USymbol usymbol) {
-		if (diagram.V1972()) {
-			if (diagram.leafExistSmart(ident) == false) {
-				return false;
-			}
-			final ILeaf other = diagram.getLeafSmart(ident);
-			if (other.getLeafType() != type) {
-				return true;
-			}
-			if (usymbol != null && other.getUSymbol() != usymbol) {
-				return true;
-			}
-			return false;
-		} else {
-			if (diagram.leafExist(code) == false) {
-				return false;
-			}
-			final ILeaf other = diagram.getLeaf(code);
-			if (other.getLeafType() != type) {
-				return true;
-			}
-			if (usymbol != null && other.getUSymbol() != usymbol) {
-				return true;
-			}
-			return false;
-		}
-	}
-
 	private char getCharEncoding(final String codeRaw) {
 		return codeRaw != null && codeRaw.length() > 2 ? codeRaw.charAt(0) : 0;
 	}
