@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -43,27 +43,21 @@ import java.util.EnumSet;
 import java.util.LinkedHashMap;
 import java.util.List;
 import java.util.Map;
-import java.util.Map.Entry;
 
-import net.sourceforge.plantuml.AlignmentParam;
+import net.atmp.CucaDiagram;
 import net.sourceforge.plantuml.FileFormatOption;
-import net.sourceforge.plantuml.FontParam;
-import net.sourceforge.plantuml.ISkinParam;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.UmlDiagram;
-import net.sourceforge.plantuml.UmlDiagramType;
+import net.sourceforge.plantuml.abel.CucaNote;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.GroupType;
+import net.sourceforge.plantuml.abel.LeafType;
+import net.sourceforge.plantuml.abel.Link;
+import net.sourceforge.plantuml.abel.LinkArrow;
+import net.sourceforge.plantuml.annotation.DuplicateCode;
 import net.sourceforge.plantuml.api.ImageDataSimple;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
 import net.sourceforge.plantuml.core.ImageData;
-import net.sourceforge.plantuml.cucadiagram.CucaDiagram;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.GroupType;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
-import net.sourceforge.plantuml.cucadiagram.IGroup;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.Link;
-import net.sourceforge.plantuml.cucadiagram.entity.EntityFactory;
+import net.sourceforge.plantuml.eggs.QuoteUtils;
 
 /*
  * You can choose between real "org.eclipse.elk..." classes or proxied "net.sourceforge.plantuml.elk.proxy..."
@@ -103,36 +97,39 @@ import net.sourceforge.plantuml.elk.proxy.graph.ElkEdge;
 import net.sourceforge.plantuml.elk.proxy.graph.ElkLabel;
 import net.sourceforge.plantuml.elk.proxy.graph.ElkNode;
 import net.sourceforge.plantuml.elk.proxy.graph.util.ElkGraphUtil;
-import net.sourceforge.plantuml.graphic.AbstractTextBlock;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.QuoteUtils;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.USymbolFolder;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.CreoleMode;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.FontParam;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.MinMax;
+import net.sourceforge.plantuml.klimt.geom.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
 import net.sourceforge.plantuml.log.Logme;
-import net.sourceforge.plantuml.style.PName;
+import net.sourceforge.plantuml.skin.AlignmentParam;
+import net.sourceforge.plantuml.skin.UmlDiagramType;
+import net.sourceforge.plantuml.skin.VisibilityModifier;
+import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.svek.Bibliotekon;
-import net.sourceforge.plantuml.svek.Cluster;
-import net.sourceforge.plantuml.svek.ClusterDecoration;
-import net.sourceforge.plantuml.svek.ClusterPosition;
+import net.sourceforge.plantuml.style.StyleSignature;
+import net.sourceforge.plantuml.style.StyleSignatureBasic;
+import net.sourceforge.plantuml.svek.ClusterHeader;
 import net.sourceforge.plantuml.svek.CucaDiagramFileMaker;
-import net.sourceforge.plantuml.svek.DotStringFactory;
 import net.sourceforge.plantuml.svek.GeneralImageBuilder;
 import net.sourceforge.plantuml.svek.GraphvizCrash;
 import net.sourceforge.plantuml.svek.IEntityImage;
-import net.sourceforge.plantuml.svek.PackageStyle;
-import net.sourceforge.plantuml.svek.TextBlockBackcolored;
-import net.sourceforge.plantuml.ugraphic.MinMax;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
+import net.sourceforge.plantuml.svek.SvekNode;
+import net.sourceforge.plantuml.svek.image.EntityImageNoteLink;
+import net.sourceforge.plantuml.utils.Position;
 
 /*
  * Some notes:
@@ -145,45 +142,125 @@ Long hierarchical edge
 https://rtsys.informatik.uni-kiel.de/~biblio/downloads/theses/yab-bt.pdf
 https://rtsys.informatik.uni-kiel.de/~biblio/downloads/theses/thw-bt.pdf
  */
-public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
+@DuplicateCode(reference = "SvekEdge, CucaDiagramFileMakerElk, CucaDiagramFileMakerSmetana")
+public class CucaDiagramFileMakerElk extends CucaDiagramFileMaker {
+	// ::remove folder when __CORE__
 
-	private final CucaDiagram diagram;
-	private final StringBounder stringBounder;
-	private final DotStringFactory dotStringFactory;
-
-	private final Map<ILeaf, ElkNode> nodes = new LinkedHashMap<ILeaf, ElkNode>();
-	private final Map<IGroup, ElkNode> clusters = new LinkedHashMap<IGroup, ElkNode>();
+	private final Map<Entity, ElkNode> nodes = new LinkedHashMap<Entity, ElkNode>();
+	private final Map<Entity, ElkNode> clusters = new LinkedHashMap<Entity, ElkNode>();
 	private final Map<Link, ElkEdge> edges = new LinkedHashMap<Link, ElkEdge>();
 
-	public CucaDiagramFileMakerElk(CucaDiagram diagram, StringBounder stringBounder) {
-		this.diagram = diagram;
-		this.stringBounder = stringBounder;
-		this.dotStringFactory = new DotStringFactory(stringBounder, diagram);
-
+	public CucaDiagramFileMakerElk(CucaDiagram diagram) {
+		super(diagram);
 	}
 
-	private TextBlock getLabel(Link link) {
-		if (Display.isNull(link.getLabel())) {
-			return null;
+	// Duplication from SvekEdge
+	final public StyleSignature getDefaultStyleDefinitionArrow(Stereotype stereotype, SName styleName) {
+		StyleSignature result = StyleSignatureBasic.of(SName.root, SName.element, styleName, SName.arrow);
+		if (stereotype != null)
+			result = result.withTOBECHANGED(stereotype);
+
+		return result;
+	}
+
+	private FontConfiguration getFontForLink(Link link, final ISkinParam skinParam) {
+		final SName styleName = skinParam.getUmlDiagramType().getStyleName();
+
+		final Style style = getDefaultStyleDefinitionArrow(link.getStereotype(), styleName)
+				.getMergedStyle(link.getStyleBuilder());
+		return style.getFontConfiguration(skinParam.getIHtmlColorSet());
+	}
+
+	private HorizontalAlignment getMessageTextAlignment(UmlDiagramType umlDiagramType, ISkinParam skinParam) {
+		if (umlDiagramType == UmlDiagramType.STATE)
+			return skinParam.getHorizontalAlignment(AlignmentParam.stateMessageAlignment, null, false, null);
+
+		return skinParam.getDefaultTextAlignment(HorizontalAlignment.CENTER);
+	}
+
+	private TextBlock addVisibilityModifier(TextBlock block, Link link, ISkinParam skinParam) {
+		final VisibilityModifier visibilityModifier = link.getVisibilityModifier();
+		if (visibilityModifier != null) {
+			final Rose rose = new Rose();
+			final HColor fore = rose.getHtmlColor(skinParam, visibilityModifier.getForeground());
+			TextBlock visibility = visibilityModifier.getUBlock(skinParam.classAttributeIconSize(), fore, null, false);
+			visibility = TextBlockUtils.withMargin(visibility, 0, 1, 2, 0);
+			block = TextBlockUtils.mergeLR(visibility, block, VerticalAlignment.CENTER);
 		}
-		final ISkinParam skinParam = diagram.getSkinParam();
-		final FontConfiguration labelFont = FontConfiguration.create(skinParam, FontParam.ARROW, null);
-		final TextBlock label = link.getLabel().create(labelFont,
-				skinParam.getDefaultTextAlignment(HorizontalAlignment.CENTER), skinParam);
-		if (TextBlockUtils.isEmpty(label, stringBounder))
-			return null;
-
-		return label;
+		final double marginLabel = 1; // startUid.equalsId(endUid) ? 6 : 1;
+		return TextBlockUtils.withMargin(block, marginLabel, marginLabel);
 	}
 
-	private TextBlock getQuantifier(Link link, int n) {
+	private LinkArrow getLinkArrow(Link link) {
+		return link.getLinkArrow();
+	}
+
+	private TextBlock getLabel(StringBounder stringBounder, Link link) {
+		ISkinParam skinParam = diagram.getSkinParam();
+		final double marginLabel = 1; // startUid.equals(endUid) ? 6 : 1;
+
+		// final FontConfiguration labelFont =
+		// style.getFontConfiguration(skinParam.getIHtmlColorSet());
+//		TextBlock labelOnly = link.getLabel().create(labelFont,
+//				skinParam.getDefaultTextAlignment(HorizontalAlignment.CENTER), skinParam);
+
+		final UmlDiagramType type = skinParam.getUmlDiagramType();
+		final FontConfiguration font = getFontForLink(link, skinParam);
+
+		TextBlock labelOnly;
+		// toto2
+		if (Display.isNull(link.getLabel())) {
+			labelOnly = TextBlockUtils.EMPTY_TEXT_BLOCK;
+			if (getLinkArrow(link) != LinkArrow.NONE_OR_SEVERAL) {
+				// labelOnly = StringWithArrow.addMagicArrow(labelOnly, this, font);
+			}
+
+		} else {
+			final HorizontalAlignment alignment = getMessageTextAlignment(type, skinParam);
+			final boolean hasSeveralGuideLines = link.getLabel().hasSeveralGuideLines();
+			final TextBlock block;
+			// if (hasSeveralGuideLines)
+			// block = StringWithArrow.addSeveralMagicArrows(link.getLabel(), this, font,
+			// alignment, skinParam);
+			// else
+			block = link.getLabel().create0(font, alignment, skinParam, skinParam.maxMessageSize(),
+					CreoleMode.SIMPLE_LINE, null, null);
+
+			labelOnly = addVisibilityModifier(block, link, skinParam);
+			if (getLinkArrow(link) != LinkArrow.NONE_OR_SEVERAL && hasSeveralGuideLines == false) {
+				// labelOnly = StringWithArrow.addMagicArrow(labelOnly, this, font);
+			}
+
+		}
+
+		final CucaNote note = link.getNote();
+		if (note == null) {
+			if (TextBlockUtils.isEmpty(labelOnly, stringBounder) == false)
+				labelOnly = TextBlockUtils.withMargin(labelOnly, marginLabel, marginLabel);
+			return labelOnly;
+		}
+		final TextBlock noteOnly = new EntityImageNoteLink(note.getDisplay(), note.getColors(), skinParam,
+				link.getStyleBuilder());
+
+		if (note.getPosition() == Position.LEFT)
+			return TextBlockUtils.mergeLR(noteOnly, labelOnly, VerticalAlignment.CENTER);
+		else if (note.getPosition() == Position.RIGHT)
+			return TextBlockUtils.mergeLR(labelOnly, noteOnly, VerticalAlignment.CENTER);
+		else if (note.getPosition() == Position.TOP)
+			return TextBlockUtils.mergeTB(noteOnly, labelOnly, HorizontalAlignment.CENTER);
+		else
+			return TextBlockUtils.mergeTB(labelOnly, noteOnly, HorizontalAlignment.CENTER);
+
+	}
+
+	private TextBlock getQuantifier(StringBounder stringBounder, Link link, int n) {
 		final String tmp = n == 1 ? link.getQuantifier1() : link.getQuantifier2();
 		if (tmp == null)
 			return null;
 
 		final ISkinParam skinParam = diagram.getSkinParam();
 		final FontConfiguration labelFont = FontConfiguration.create(skinParam, FontParam.ARROW, null);
-		final TextBlock label = Display.getWithNewlines(tmp).create(labelFont,
+		final TextBlock label = Display.getWithNewlines(diagram.getPragma(), tmp).create(labelFont,
 				skinParam.getDefaultTextAlignment(HorizontalAlignment.CENTER), skinParam);
 		if (TextBlockUtils.isEmpty(label, stringBounder))
 			return null;
@@ -192,7 +269,7 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 	}
 
 	// Retrieve the real position of a node, depending on its parents
-	private XPoint2D getPosition(ElkNode elkNode) {
+	public static XPoint2D getPosition(ElkNode elkNode) {
 		final ElkNode parent = elkNode.getParent();
 
 		final double x = elkNode.getX();
@@ -209,147 +286,16 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 
 	}
 
-	// The Drawing class does the real drawing
-	class Drawing extends AbstractTextBlock implements TextBlockBackcolored {
-
-		// min and max of all coord
-		private final MinMax minMax;
-
-		public Drawing(MinMax minMax) {
-			this.minMax = minMax;
-		}
-
-		public void drawU(UGraphic ug) {
-			drawAllClusters(ug);
-			drawAllNodes(ug);
-			drawAllEdges(ug);
-		}
-
-		private void drawAllClusters(UGraphic ug) {
-			for (Entry<IGroup, ElkNode> ent : clusters.entrySet())
-				drawSingleCluster(ug, ent.getKey(), ent.getValue());
-
-		}
-
-		private void drawAllNodes(UGraphic ug) {
-			for (Entry<ILeaf, ElkNode> ent : nodes.entrySet())
-				drawSingleNode(ug, ent.getKey(), ent.getValue());
-
-		}
-
-		private void drawAllEdges(UGraphic ug) {
-			for (Entry<Link, ElkEdge> ent : edges.entrySet()) {
-				final Link link = ent.getKey();
-				if (link.isInvis())
-					continue;
-
-				drawSingleEdge(ug, link, ent.getValue());
-			}
-		}
-
-		private void drawSingleCluster(UGraphic ug, IGroup group, ElkNode elkNode) {
-			final XPoint2D corner = getPosition(elkNode);
-			final URectangle rect = new URectangle(elkNode.getWidth(), elkNode.getHeight());
-
-			PackageStyle packageStyle = group.getPackageStyle();
-			final ISkinParam skinParam = diagram.getSkinParam();
-			if (packageStyle == null)
-				packageStyle = skinParam.packageStyle();
-
-			final UmlDiagramType umlDiagramType = diagram.getUmlDiagramType();
-
-			final Style style = Cluster.getDefaultStyleDefinition(umlDiagramType.getStyleName(), group.getUSymbol())
-					.getMergedStyle(skinParam.getCurrentStyleBuilder());
-			final double shadowing = style.value(PName.Shadowing).asDouble();
-			final UStroke stroke = Cluster.getStrokeInternal(group, style);
-
-			HColor backColor = getBackColor(umlDiagramType);
-			backColor = Cluster.getBackColor(backColor, group.getStereotype(), umlDiagramType.getStyleName(),
-					group.getUSymbol(), skinParam.getCurrentStyleBuilder(), skinParam.getIHtmlColorSet());
-
-			final double roundCorner = style.value(PName.RoundCorner).asDouble();
-//			final double roundCorner = group.getUSymbol() == null ? 0
-//					: group.getUSymbol().getSkinParameter().getRoundCorner(skinParam, group.getStereotype());
-
-			final TextBlock ztitle = getTitleBlock(group);
-			final TextBlock zstereo = TextBlockUtils.empty(0, 0);
-
-			final ClusterPosition clusterPosition = new ClusterPosition(0, 0, elkNode.getWidth(), elkNode.getHeight());
-			final ClusterDecoration decoration = new ClusterDecoration(packageStyle, group.getUSymbol(), ztitle,
-					zstereo, clusterPosition, stroke);
-
-			final HColor borderColor = HColors.BLACK;
-			decoration.drawU(ug.apply(new UTranslate(corner)), backColor, borderColor, shadowing, roundCorner,
-					skinParam.getHorizontalAlignment(AlignmentParam.packageTitleAlignment, null, false, null),
-					skinParam.getStereotypeAlignment(), 0);
-
-//			// Print a simple rectangle right now
-//			ug.apply(HColorUtils.BLACK).apply(new UStroke(1.5)).apply(new UTranslate(corner)).draw(rect);
-		}
-
-		private TextBlock getTitleBlock(IGroup g) {
-			final Display label = g.getDisplay();
-			if (label == null)
-				return TextBlockUtils.empty(0, 0);
-
-			final ISkinParam skinParam = diagram.getSkinParam();
-			final FontConfiguration fontConfiguration = g.getFontConfigurationForTitle(skinParam);
-			return label.create(fontConfiguration, HorizontalAlignment.CENTER, skinParam);
-		}
-
-		private HColor getBackColor(UmlDiagramType umlDiagramType) {
-			return null;
-		}
-
-		private void drawSingleNode(UGraphic ug, ILeaf leaf, ElkNode elkNode) {
-			final IEntityImage image = printEntityInternal(leaf);
-			// Retrieve coord from ELK
-			final XPoint2D corner = getPosition(elkNode);
-
-			// Print the node image at right coord
-			image.drawU(ug.apply(new UTranslate(corner)));
-		}
-
-		private void drawSingleEdge(UGraphic ug, Link link, ElkEdge edge) {
-			// Unfortunately, we have to translate "edge" in its own "cluster" coordinate
-			final XPoint2D translate = getPosition(edge.getContainingNode());
-
-			final double magicY2 = 0;
-			final IEntity dest = link.getEntity2();
-			if (dest.getUSymbol() instanceof USymbolFolder) {
-//				System.err.println("dest=" + dest);
-//				final IEntityImage image = printEntityInternal((ILeaf) dest);
-//				System.err.println("image=" + image);
-
-			}
-			final ElkPath elkPath = new ElkPath(diagram, SName.classDiagram, link, edge, getLabel(link),
-					getQuantifier(link, 1), getQuantifier(link, 2), magicY2);
-			elkPath.drawU(ug.apply(new UTranslate(translate)));
-		}
-
-		public XDimension2D calculateDimension(StringBounder stringBounder) {
-			if (minMax == null)
-				throw new UnsupportedOperationException();
-
-			return minMax.getDimension();
-		}
-
-		public HColor getBackcolor() {
-			return null;
-		}
-
-	}
-
-	private Collection<ILeaf> getUnpackagedEntities() {
-		final List<ILeaf> result = new ArrayList<>();
-		for (ILeaf ent : diagram.getLeafsvalues())
-			if (diagram.getEntityFactory().getRootGroup() == ent.getParentContainer())
+	private Collection<Entity> getUnpackagedEntities() {
+		final List<Entity> result = new ArrayList<>();
+		for (Entity ent : diagram.leafs())
+			if (diagram.getRootGroup() == ent.getParentContainer())
 				result.add(ent);
 
 		return result;
 	}
 
-	private ElkNode getElkNode(final IEntity entity) {
+	private ElkNode getElkNode(final Entity entity) {
 		ElkNode node = nodes.get(entity);
 		if (node == null)
 			node = clusters.get(entity);
@@ -367,16 +313,19 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 			root.setProperty(CoreOptions.DIRECTION, Direction.DOWN);
 			root.setProperty(CoreOptions.HIERARCHY_HANDLING, HierarchyHandling.INCLUDE_CHILDREN);
 
-			printAllSubgroups(root, diagram.getRootGroup());
-			printEntities(root, getUnpackagedEntities());
+			final StringBounder stringBounder = fileFormatOption.getDefaultStringBounder(diagram.getSkinParam());
 
-			manageAllEdges();
+			this.printAllSubgroups(stringBounder, root, diagram.getRootGroup());
+			this.printEntities(stringBounder, root, getUnpackagedEntities());
+
+			this.manageAllEdges(stringBounder);
 
 			new RecursiveGraphLayoutEngine().layout(root, new NullElkProgressMonitor());
 
-			final MinMax minMax = TextBlockUtils.getMinMax(new Drawing(null), stringBounder, false);
+			final MinMax minMax = TextBlockUtils.getMinMax(
+					new MyElkDrawing(clusterManager, diagram, null, clusters, edges, nodes), stringBounder, false);
 
-			final TextBlock drawable = new Drawing(minMax);
+			final TextBlock drawable = new MyElkDrawing(clusterManager, diagram, minMax, clusters, edges, nodes);
 			return diagram.createImageBuilder(fileFormatOption) //
 					.drawable(drawable) //
 					.write(os); //
@@ -384,28 +333,31 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 		} catch (Throwable e) {
 			UmlDiagram.exportDiagramError(os, e, fileFormatOption, diagram.seed(), diagram.getMetadata(),
 					diagram.getFlashData(), getFailureText3(e));
-			return ImageDataSimple.error();
+			return ImageDataSimple.error(e);
 		}
 
 	}
 
-	private void printAllSubgroups(ElkNode cluster, IGroup group) {
-		for (IGroup g : diagram.getChildrenGroups(group)) {
-			if (g.isRemoved()) {
+	private void printAllSubgroups(StringBounder stringBounder, ElkNode cluster, Entity group) {
+		for (Entity g : diagram.getChildrenGroups(group)) {
+			if (g.isRemoved())
 				continue;
-			}
+
 			if (diagram.isEmpty(g) && g.getGroupType() == GroupType.PACKAGE) {
-				final ISkinParam skinParam = diagram.getSkinParam();
-				final EntityFactory entityFactory = diagram.getEntityFactory();
-				final ILeaf folder = entityFactory.createLeafForEmptyGroup(g, skinParam);
-				System.err.println("STILL IN PROGRESS");
-				// printEntityNew(folder);
+				g.muteToType(LeafType.EMPTY_PACKAGE);
+				this.prinEntity(stringBounder, g, cluster);
 			} else {
 
 				// We create the "cluster" in ELK for this group
 				final ElkNode elkCluster = ElkGraphUtil.createNode(cluster);
 				elkCluster.setProperty(CoreOptions.DIRECTION, Direction.DOWN);
-				elkCluster.setProperty(CoreOptions.PADDING, new ElkPadding(40, 15, 15, 15));
+
+				final ClusterHeader clusterHeader = new ClusterHeader(g, diagram, stringBounder);
+
+				final int titleAndAttributeHeight = clusterHeader.getTitleAndAttributeHeight();
+
+				final double topPadding = Math.max(25, titleAndAttributeHeight) + 15;
+				elkCluster.setProperty(CoreOptions.PADDING, new ElkPadding(topPadding, 15, 15, 15));
 
 				// Not sure this is usefull to put a label on a "cluster"
 				final ElkLabel label = ElkGraphUtil.createLabel(elkCluster);
@@ -413,50 +365,54 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 				// We need it anyway to recurse up to the real "root"
 
 				this.clusters.put(g, elkCluster);
-				printSingleGroup(g);
+				this.printSingleGroup(stringBounder, g);
 			}
 		}
 
 	}
 
-	private void printSingleGroup(IGroup g) {
+	private void printSingleGroup(StringBounder stringBounder, Entity g) {
 		if (g.getGroupType() == GroupType.CONCURRENT_STATE)
 			return;
 
-		this.printEntities(clusters.get(g), g.getLeafsDirect());
-		printAllSubgroups(clusters.get(g), g);
+		this.printEntities(stringBounder, clusters.get(g), g.leafs());
+		this.printAllSubgroups(stringBounder, clusters.get(g), g);
 	}
 
-	private void printEntities(ElkNode parent, Collection<ILeaf> entities) {
+	private void printEntities(StringBounder stringBounder, ElkNode parent, Collection<Entity> entities) {
 		// Convert all "leaf" to ELK node
-		for (ILeaf ent : entities) {
+		for (Entity ent : entities) {
 			if (ent.isRemoved())
 				continue;
 
-			manageSingleNode(parent, ent);
+			this.prinEntity(stringBounder, ent, parent);
 		}
 	}
 
-	private void manageAllEdges() {
+	private void manageAllEdges(StringBounder stringBounder) {
 		// Convert all "link" to ELK edge
 		for (final Link link : diagram.getLinks())
-			manageSingleEdge(link);
+			this.manageSingleEdge(stringBounder, link);
 
 	}
 
-	private void manageSingleNode(final ElkNode root, ILeaf leaf) {
-		final IEntityImage image = printEntityInternal(leaf);
+	@DuplicateCode(reference = "CucaDiagramFileMakerSmetana::printEntity")
+	private void prinEntity(StringBounder stringBounder, Entity ent, ElkNode parent) {
+		final IEntityImage image = printEntityInternal(ent);
 
 		// Expected dimension of the node
 		final XDimension2D dimension = image.calculateDimension(stringBounder);
 
+		final SvekNode node = getBibliotekon().createNode(ent, image, stringBounder);
+		clusterManager.addNode(node);
+
 		// Here, we try to tell ELK to use this dimension as node dimension
-		final ElkNode node = ElkGraphUtil.createNode(root);
-		node.setDimensions(dimension.getWidth(), dimension.getHeight());
+		final ElkNode elkNode = ElkGraphUtil.createNode(parent);
+		elkNode.setDimensions(dimension.getWidth(), dimension.getHeight());
 
 		// There is no real "label" here
 		// We just would like to force node dimension
-		final ElkLabel label = ElkGraphUtil.createLabel(node);
+		final ElkLabel label = ElkGraphUtil.createLabel(elkNode);
 		label.setText("X");
 
 		// I don't know why we have to do this hack, but somebody has to fix it
@@ -478,16 +434,16 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 		// EnumSet.noneOf(SizeOptions.class));
 
 		// Let's store this
-		nodes.put(leaf, node);
+		nodes.put(ent, elkNode);
 	}
 
-	private void manageSingleEdge(final Link link) {
+	private void manageSingleEdge(StringBounder stringBounder, final Link link) {
 		final ElkNode node1 = getElkNode(link.getEntity1());
 		final ElkNode node2 = getElkNode(link.getEntity2());
 
 		final ElkEdge edge = ElkGraphUtil.createSimpleEdge(node1, node2);
 
-		final TextBlock labelLink = getLabel(link);
+		final TextBlock labelLink = getLabel(stringBounder, link);
 		if (labelLink != null) {
 			final ElkLabel edgeLabel = ElkGraphUtil.createLabel(edge);
 			final XDimension2D dim = labelLink.calculateDimension(stringBounder);
@@ -499,7 +455,7 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 		}
 		if (link.getQuantifier1() != null) {
 			final ElkLabel edgeLabel = ElkGraphUtil.createLabel(edge);
-			final XDimension2D dim = getQuantifier(link, 1).calculateDimension(stringBounder);
+			final XDimension2D dim = getQuantifier(stringBounder, link, 1).calculateDimension(stringBounder);
 			// Nasty trick, we store the kind of label in the text
 			edgeLabel.setText("1");
 			edgeLabel.setDimensions(dim.getWidth(), dim.getHeight());
@@ -510,7 +466,7 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 		}
 		if (link.getQuantifier2() != null) {
 			final ElkLabel edgeLabel = ElkGraphUtil.createLabel(edge);
-			final XDimension2D dim = getQuantifier(link, 2).calculateDimension(stringBounder);
+			final XDimension2D dim = getQuantifier(stringBounder, link, 2).calculateDimension(stringBounder);
 			// Nasty trick, we store the kind of label in the text
 			edgeLabel.setText("2");
 			edgeLabel.setDimensions(dim.getWidth(), dim.getHeight());
@@ -535,16 +491,12 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 		strings.add("Sorry, ELK intregration is really alpha feature...");
 		strings.add(" ");
 		strings.add("You should send this diagram and this image to <b>plantuml@gmail.com</b> or");
-		strings.add("post to <b>http://plantuml.com/qa</b> to solve this issue.");
+		strings.add("post to <b>https://plantuml.com/qa</b> to solve this issue.");
 		strings.add(" ");
 		return strings;
 	}
 
-	private Bibliotekon getBibliotekon() {
-		return dotStringFactory.getBibliotekon();
-	}
-
-	private IEntityImage printEntityInternal(ILeaf ent) {
+	private IEntityImage printEntityInternal(Entity ent) {
 		if (ent.isRemoved())
 			throw new IllegalStateException();
 
@@ -553,10 +505,15 @@ public class CucaDiagramFileMakerElk implements CucaDiagramFileMaker {
 			if (skinParam.sameClassWidth())
 				System.err.println("NOT YET IMPLEMENED");
 
-			return GeneralImageBuilder.createEntityImageBlock(ent, skinParam, diagram.isHideEmptyDescriptionForState(),
-					diagram, getBibliotekon(), null, diagram.getUmlDiagramType(), diagram.getLinks());
+			return GeneralImageBuilder.createEntityImageBlock(ent, diagram.isHideEmptyDescriptionForState(), diagram,
+					getBibliotekon(), null, diagram.getLinks());
 		}
 		return ent.getSvekImage();
 	}
 
+	@Override
+	public void createOneGraphic(UGraphic ug) {
+		throw new UnsupportedOperationException();
+	}
+
 }
