@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -44,58 +44,57 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
-import net.sourceforge.plantuml.BackSlash;
+import net.atmp.ImageBuilder;
+import net.atmp.PixelImage;
 import net.sourceforge.plantuml.ErrorUml;
 import net.sourceforge.plantuml.FileFormat;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.FileImageData;
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.PlainDiagram;
-import net.sourceforge.plantuml.SpriteContainerEmpty;
-import net.sourceforge.plantuml.StringLocated;
 import net.sourceforge.plantuml.api.ImageDataSimple;
 import net.sourceforge.plantuml.asciiart.UmlCharArea;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XRectangle2D;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.core.UmlSource;
-import net.sourceforge.plantuml.cucadiagram.Display;
 import net.sourceforge.plantuml.eggs.PSystemWelcome;
 import net.sourceforge.plantuml.flashcode.FlashCodeFactory;
-import net.sourceforge.plantuml.flashcode.FlashCodeUtils;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.GraphicPosition;
-import net.sourceforge.plantuml.graphic.GraphicStrings;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.InnerStrategy;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockRaw;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.UDrawable;
-import net.sourceforge.plantuml.graphic.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.AffineTransformType;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.color.HColorSimple;
+import net.sourceforge.plantuml.klimt.color.HColors;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.drawing.txt.UGraphicTxt;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.font.UFont;
+import net.sourceforge.plantuml.klimt.geom.GraphicPosition;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.MinMax;
+import net.sourceforge.plantuml.klimt.geom.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.AbstractTextBlock;
+import net.sourceforge.plantuml.klimt.shape.GraphicStrings;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockRaw;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
+import net.sourceforge.plantuml.klimt.shape.UDrawable;
+import net.sourceforge.plantuml.klimt.shape.UImage;
+import net.sourceforge.plantuml.klimt.sprite.SpriteContainerEmpty;
+import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
 import net.sourceforge.plantuml.security.SecurityUtils;
 import net.sourceforge.plantuml.svek.GraphvizCrash;
-import net.sourceforge.plantuml.svek.TextBlockBackcolored;
-import net.sourceforge.plantuml.ugraphic.AffineTransformType;
-import net.sourceforge.plantuml.ugraphic.ImageBuilder;
-import net.sourceforge.plantuml.ugraphic.MinMax;
-import net.sourceforge.plantuml.ugraphic.PixelImage;
-import net.sourceforge.plantuml.ugraphic.UFont;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UImage;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
-import net.sourceforge.plantuml.ugraphic.color.HColorSimple;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
-import net.sourceforge.plantuml.ugraphic.txt.UGraphicTxt;
+import net.sourceforge.plantuml.text.BackSlash;
+import net.sourceforge.plantuml.text.StringLocated;
+import net.sourceforge.plantuml.utils.LineLocation;
 import net.sourceforge.plantuml.version.LicenseInfo;
 import net.sourceforge.plantuml.version.PSystemVersion;
 import net.sourceforge.plantuml.version.Version;
 
 public abstract class PSystemError extends PlainDiagram {
+	// ::remove folder when __HAXE__
 
 	// Dodgy kludge for testing - we will need a different approach if we want to
 	// test addMessageDedication() etc.
@@ -108,8 +107,8 @@ public abstract class PSystemError extends PlainDiagram {
 	protected List<StringLocated> trace;
 	protected ErrorUml singleError;
 
-	public PSystemError(UmlSource source) {
-		super(source);
+	public PSystemError(UmlSource source, PreprocessingArtifact preprocessing) {
+		super(source, preprocessing);
 	}
 
 	@Override
@@ -145,7 +144,7 @@ public abstract class PSystemError extends PlainDiagram {
 		return sb.toString();
 	}
 
-	private TextBlockBackcolored getGraphicalFormatted() {
+	private TextBlock getGraphicalFormatted() {
 		final FontConfiguration fc0 = GraphicStrings.sansSerif14(HColors.BLACK).bold();
 		final FontConfiguration fc1 = GraphicStrings.sansSerif14(HColors.MY_GREEN).bold();
 		final FontConfiguration fc2 = GraphicStrings.sansSerif14(HColors.RED).bold();
@@ -233,6 +232,7 @@ public abstract class PSystemError extends PlainDiagram {
 	@Override
 	final protected ImageData exportDiagramNow(OutputStream os, int num, FileFormatOption fileFormat)
 			throws IOException {
+		// ::comment when __CORE__
 		if (fileFormat.getFileFormat() == FileFormat.ATXT || fileFormat.getFileFormat() == FileFormat.UTXT) {
 			final UGraphicTxt ugt = new UGraphicTxt();
 			final UmlCharArea area = ugt.getCharArea();
@@ -241,12 +241,13 @@ public abstract class PSystemError extends PlainDiagram {
 			return new ImageDataSimple(1, 1);
 
 		}
+		// ::done
 		return super.exportDiagramNow(os, num, fileFormat);
 	}
 
 	@Override
 	protected UDrawable getRootDrawable(FileFormatOption fileFormatOption) throws IOException {
-		final TextBlockBackcolored result = getGraphicalFormatted();
+		final TextBlock result = getGraphicalFormatted();
 
 		TextBlock udrawable;
 		if (getSource().getTotalLineCountLessThan5()) {
@@ -264,8 +265,10 @@ public abstract class PSystemError extends PlainDiagram {
 			udrawable = addMessageLiberapay(udrawable);
 		} else if (min == 30 || min == 39 || min == 48) {
 			udrawable = addMessageDedication(udrawable);
+			// ::comment when __CORE__
 		} else if (getSource().containsIgnoreCase("arecibo")) {
 			udrawable = addMessageArecibo(udrawable);
+			// ::done
 		}
 		return udrawable;
 	}
@@ -288,19 +291,22 @@ public abstract class PSystemError extends PlainDiagram {
 		return full.subList(full.size() - 1, full.size());
 	}
 
-	private TextBlockBackcolored getWelcome() throws IOException {
-		return new PSystemWelcome(getSource(), GraphicPosition.BACKGROUND_CORNER_TOP_RIGHT).getGraphicStrings();
+	private TextBlock getWelcome() throws IOException {
+		return new PSystemWelcome(getSource(), GraphicPosition.BACKGROUND_CORNER_TOP_RIGHT, getPreprocessingArtifact())
+				.getGraphicStrings();
 	}
 
-	private TextBlock addWelcome(final TextBlockBackcolored result) throws IOException {
-		final TextBlockBackcolored welcome = getWelcome();
+	private TextBlock addWelcome(final TextBlock result) throws IOException {
+		final TextBlock welcome = getWelcome();
 		return TextBlockUtils.mergeTB(welcome, result, HorizontalAlignment.LEFT);
 	}
 
 	private TextBlock addMessageLiberapay(final TextBlock source) throws IOException {
-		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid()) {
+		// ::comment when __CORE__
+		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid())
 			return source;
-		}
+		// ::done
+
 		final TextBlock message = getMessageLiberapay();
 		TextBlock result = TextBlockUtils.mergeTB(message, source, HorizontalAlignment.LEFT);
 		result = TextBlockUtils.mergeTB(result, message, HorizontalAlignment.LEFT);
@@ -308,9 +314,11 @@ public abstract class PSystemError extends PlainDiagram {
 	}
 
 	private TextBlock addMessagePatreon(final TextBlock source) throws IOException {
-		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid()) {
+		// ::comment when __CORE__
+		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid())
 			return source;
-		}
+		// ::done
+
 		final TextBlock message = getMessagePatreon();
 		TextBlock result = TextBlockUtils.mergeTB(message, source, HorizontalAlignment.LEFT);
 		result = TextBlockUtils.mergeTB(result, message, HorizontalAlignment.LEFT);
@@ -318,14 +326,17 @@ public abstract class PSystemError extends PlainDiagram {
 	}
 
 	private TextBlock addMessageDedication(final TextBlock source) throws IOException {
-		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid()) {
+		// ::comment when __CORE__
+		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid())
 			return source;
-		}
+		// ::done
+
 		final TextBlock message = getMessageDedication();
 		TextBlock result = TextBlockUtils.mergeTB(message, source, HorizontalAlignment.LEFT);
 		return result;
 	}
 
+	// ::comment when __CORE__
 	private TextBlock addMessageAdopt(final TextBlock source) throws IOException {
 		if (LicenseInfo.retrieveNamedOrDistributorQuickIsValid()) {
 			return source;
@@ -341,13 +352,15 @@ public abstract class PSystemError extends PlainDiagram {
 		TextBlock result = TextBlockUtils.mergeLR(source, TextBlockUtils.fromUImage(message), VerticalAlignment.TOP);
 		return result;
 	}
+	// ::done
 
-	private TextBlockBackcolored getMessageDedication() {
-		final FlashCodeUtils utils = FlashCodeFactory.getFlashCodeUtils();
+	private TextBlock getMessageDedication() {
 		final HColorSimple backColor = (HColorSimple) HColorSet.instance().getColorOrWhite("#eae2c9");
 
-		final BufferedImage qrcode = smaller(
-				utils.exportFlashcode("http://plantuml.com/dedication", Color.BLACK, backColor.getAwtColor()));
+		// ::comment when __CORE__
+		final BufferedImage qrcode = smaller(FlashCodeFactory.getFlashCodeUtils()
+				.exportFlashcode("https://plantuml.com/dedication", Color.BLACK, backColor.getAwtColor()));
+		// ::done
 		final Display disp = Display.create("<b>Add your own dedication into PlantUML", " ", "For just $5 per month!",
 				"Details on <i>[[https://plantuml.com/dedication]]");
 
@@ -356,21 +369,25 @@ public abstract class PSystemError extends PlainDiagram {
 		final TextBlock text = TextBlockUtils
 				.withMargin(disp.create(fc, HorizontalAlignment.LEFT, new SpriteContainerEmpty()), 10, 0);
 		final TextBlock result;
+		// ::comment when __CORE__
 		if (qrcode == null) {
+			// ::done
 			result = text;
+			// ::comment when __CORE__
 		} else {
 			final UImage qr = new UImage(new PixelImage(qrcode, AffineTransformType.TYPE_NEAREST_NEIGHBOR)).scale(3);
 			result = TextBlockUtils.mergeLR(text, TextBlockUtils.fromUImage(qr), VerticalAlignment.CENTER);
 		}
+		// ::done
 		return TextBlockUtils.addBackcolor(result, backColor);
 
 	}
 
-	private TextBlockBackcolored getMessageAdopt() {
+	private TextBlock getMessageAdopt() {
 		final HColor backColor = HColorSet.instance().getColorOrWhite("#eff4d2");
 
 		final Display disp = Display.create("<b>Adopt-a-Word and put your message here!", " ",
-				"Details on <i>[[http://plantuml.com/adopt]]", " ");
+				"Details on <i>[[https://plantuml.com/adopt]]", " ");
 
 		final UFont font = UFont.sansSerif(14);
 		final FontConfiguration fc = FontConfiguration.create(font, HColors.BLACK, HColors.BLACK, null);
@@ -382,36 +399,47 @@ public abstract class PSystemError extends PlainDiagram {
 
 	}
 
-	private TextBlockBackcolored getMessagePatreon() {
+	private TextBlock getMessagePatreon() {
 		final UImage message = new UImage(
 				new PixelImage(PSystemVersion.getTime01(), AffineTransformType.TYPE_BILINEAR));
 		final Color back = new Color(message.getImage(1).getRGB(0, 0));
 		final HColor backColor = HColors.simple(back);
 
-		final FlashCodeUtils utils = FlashCodeFactory.getFlashCodeUtils();
-		final BufferedImage qrcode = smaller(
-				utils.exportFlashcode("http://plantuml.com/patreon", Color.BLACK, Color.WHITE));
+		// ::comment when __CORE__
+		final BufferedImage qrcode = smaller(FlashCodeFactory.getFlashCodeUtils()
+				.exportFlashcode("https://plantuml.com/patreon", Color.BLACK, Color.WHITE));
+		// ::done
 
 		final int scale = 2;
 
-		final double imWidth = message.getWidth() + (qrcode == null ? 0 : qrcode.getWidth() * scale + 20);
-		final double imHeight = qrcode == null ? message.getHeight()
-				: Math.max(message.getHeight(), qrcode.getHeight() * scale + 10);
-		return new TextBlockBackcolored() {
+		final double imWidth;
+		final double imHeight;
+		// ::comment when __CORE__
+		if (qrcode == null) {
+			// ::done
+			imWidth = message.getWidth();
+			imHeight = message.getHeight();
+			// ::comment when __CORE__
+		} else {
+			imWidth = message.getWidth() + qrcode.getWidth() * scale + 20;
+			imHeight = Math.max(message.getHeight(), qrcode.getHeight() * scale + 10);
+		}
+		// ::done
+		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
+				// ::comment when __CORE__
 				if (qrcode == null) {
+					// ::done
 					ug.apply(new UTranslate(1, 1)).draw(message);
+					// ::comment when __CORE__
 				} else {
 					final UImage qr = new UImage(new PixelImage(qrcode, AffineTransformType.TYPE_NEAREST_NEIGHBOR))
 							.scale(scale);
 					ug.apply(new UTranslate(1, (imHeight - message.getHeight()) / 2)).draw(message);
 					ug.apply(new UTranslate(1 + message.getWidth(), (imHeight - qr.getHeight()) / 2)).draw(qr);
 				}
-			}
-
-			public XRectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
-				return null;
+				// ::done
 			}
 
 			public XDimension2D calculateDimension(StringBounder stringBounder) {
@@ -429,35 +457,48 @@ public abstract class PSystemError extends PlainDiagram {
 
 	}
 
-	private TextBlockBackcolored getMessageLiberapay() {
+	private TextBlock getMessageLiberapay() {
 		final UImage message = new UImage(
 				new PixelImage(PSystemVersion.getTime15(), AffineTransformType.TYPE_BILINEAR));
 		final Color back = new Color(message.getImage(1).getRGB(0, 0));
 		final HColor backColor = HColors.simple(back);
 
-		final FlashCodeUtils utils = FlashCodeFactory.getFlashCodeUtils();
-		final BufferedImage qrcode = smaller(utils.exportFlashcode("http://plantuml.com/lp", Color.BLACK, Color.WHITE));
+		// ::comment when __CORE__
+		final BufferedImage qrcode = smaller(FlashCodeFactory.getFlashCodeUtils()
+				.exportFlashcode("https://plantuml.com/lp", Color.BLACK, Color.WHITE));
+		// ::done
 
 		final int scale = 2;
 
-		final double imWidth = message.getWidth() + (qrcode == null ? 0 : qrcode.getWidth() * scale + 20);
-		final double imHeight = qrcode == null ? message.getHeight()
-				: Math.max(message.getHeight(), qrcode.getHeight() * scale + 10);
-		return new TextBlockBackcolored() {
+		final double imWidth;
+		final double imHeight;
+		// ::comment when __CORE__
+		if (qrcode == null) {
+			// ::done
+			imWidth = message.getWidth();
+			imHeight = message.getHeight();
+			// ::comment when __CORE__
+		} else {
+			imWidth = message.getWidth() + qrcode.getWidth() * scale + 20;
+			imHeight = Math.max(message.getHeight(), qrcode.getHeight() * scale + 10);
+		}
+		// ::done
+
+		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
+				// ::comment when __CORE__
 				if (qrcode == null) {
+					// ::done
 					ug.apply(new UTranslate(1, 1)).draw(message);
+					// ::comment when __CORE__
 				} else {
 					final UImage qr = new UImage(new PixelImage(qrcode, AffineTransformType.TYPE_NEAREST_NEIGHBOR))
 							.scale(scale);
 					ug.apply(new UTranslate(1, (imHeight - message.getHeight()) / 2)).draw(message);
 					ug.apply(new UTranslate(1 + message.getWidth(), (imHeight - qr.getHeight()) / 2)).draw(qr);
 				}
-			}
-
-			public XRectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
-				return null;
+				// ::done
 			}
 
 			public XDimension2D calculateDimension(StringBounder stringBounder) {
@@ -488,4 +529,4 @@ public abstract class PSystemError extends PlainDiagram {
 		return im.getSubimage(nb, nb, im.getWidth() - 2 * nb, im.getHeight() - 2 * nb);
 	}
 
-}
\ No newline at end of file
+}
