@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -150,6 +150,9 @@ public class Movement {
 		if (letter.is('l'))
 			return new Movement(new SvgCommandLetter("L"), delta.add(getSvgPosition(0)));
 
+		if (letter.is('t'))
+			return new Movement(new SvgCommandLetter("T"), delta.add(getSvgPosition(0)));
+
 		if (letter.is('z'))
 			return new Movement(new SvgCommandLetter("Z"));
 
@@ -157,6 +160,9 @@ public class Movement {
 			return new Movement(new SvgCommandLetter("C"), delta.add(getSvgPosition(0)), delta.add(getSvgPosition(2)),
 					delta.add(getSvgPosition(4)));
 
+		if (letter.is('q'))
+			return new Movement(new SvgCommandLetter("Q"), delta.add(getSvgPosition(0)), delta.add(getSvgPosition(2)));
+
 		if (letter.is('s'))
 			return new Movement(new SvgCommandLetter("S"), delta.add(getSvgPosition(0)), delta.add(getSvgPosition(2)));
 
