@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -45,20 +45,23 @@ import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
-import net.sourceforge.plantuml.cucadiagram.dot.Graphviz;
-import net.sourceforge.plantuml.cucadiagram.dot.GraphvizUtils;
-import net.sourceforge.plantuml.cucadiagram.dot.ProcessState;
+import net.sourceforge.plantuml.dot.Graphviz;
+import net.sourceforge.plantuml.dot.GraphvizUtils;
+import net.sourceforge.plantuml.dot.ProcessState;
+import net.sourceforge.plantuml.klimt.geom.MinFinder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.DotPath;
 import net.sourceforge.plantuml.security.SFile;
-import net.sourceforge.plantuml.svek.MinFinder;
 import net.sourceforge.plantuml.svek.SvgResult;
 import net.sourceforge.plantuml.svek.YDelta;
 
 public class GraphvizSolverB {
+	// ::remove file when __CORE__
 
 	// static private void traceDotString(String dotString) throws IOException {
-	// final File f = SecurityUtils.File("dottmpfile" + UniqueSequence.getValue() + ".tmp");
+	// final File f = SecurityUtils.File("dottmpfile" + UniqueSequence.getValue() +
+	// ".tmp");
 	// PrintWriter pw = null;
 	// try {
 	// pw = SecurityUtils.PrintWriter(new FileWriter(f));
@@ -72,7 +75,8 @@ public class GraphvizSolverB {
 	// }
 	//
 	// static private void traceSvgString(String svg) throws IOException {
-	// final File f = SecurityUtils.File("svgtmpfile" + UniqueSequence.getValue() + ".svg");
+	// final File f = SecurityUtils.File("svgtmpfile" + UniqueSequence.getValue() +
+	// ".svg");
 	// PrintWriter pw = null;
 	// try {
 	// pw = SecurityUtils.PrintWriter(new FileWriter(f));
@@ -102,9 +106,9 @@ public class GraphvizSolverB {
 		final ByteArrayOutputStream baos = new ByteArrayOutputStream();
 		final ProcessState state = graphviz.createFile3(baos);
 		baos.close();
-		if (state.differs(ProcessState.TERMINATED_OK())) {
+		if (state.differs(ProcessState.TERMINATED_OK()))
 			throw new IllegalStateException("Timeout2 " + state);
-		}
+
 		final byte[] result = baos.toByteArray();
 		final String s = new String(result, UTF_8);
 		// Log.println("result=" + s);
@@ -115,9 +119,9 @@ public class GraphvizSolverB {
 
 		final Pattern pGraph = Pattern.compile("(?m)\\<svg\\s+width=\"(\\d+)pt\"\\s+height=\"(\\d+)pt\"");
 		final Matcher mGraph = pGraph.matcher(s);
-		if (mGraph.find() == false) {
+		if (mGraph.find() == false)
 			throw new IllegalStateException();
-		}
+
 		final int width = Integer.parseInt(mGraph.group(1));
 		final int height = Integer.parseInt(mGraph.group(2));
 
@@ -125,9 +129,9 @@ public class GraphvizSolverB {
 		for (Block b : root.getRecursiveContents()) {
 			final String start = "b" + b.getUid();
 			final int p1 = s.indexOf("<title>" + start + "</title>");
-			if (p1 == -1) {
+			if (p1 == -1)
 				throw new IllegalStateException();
-			}
+
 			final List<XPoint2D> pointsList = extractPointsList(s, p1, yDelta);
 			b.setX(getMinX(pointsList));
 			b.setY(getMinY(pointsList));
@@ -137,9 +141,9 @@ public class GraphvizSolverB {
 		for (Cluster cl : root.getSubClusters()) {
 			final String start = "cluster" + cl.getUid();
 			final int p1 = s.indexOf("<title>" + start + "</title>");
-			if (p1 == -1) {
+			if (p1 == -1)
 				throw new IllegalStateException();
-			}
+
 			final List<XPoint2D> pointsList = extractPointsList(s, p1, yDelta);
 			cl.setX(getMinX(pointsList));
 			cl.setY(getMinY(pointsList));
@@ -155,13 +159,13 @@ public class GraphvizSolverB {
 			final String end = "b" + p.getEnd().getUid();
 			final String searched = "<title>" + start + "&#45;&gt;" + end + "</title>";
 			final int p1 = s.indexOf(searched);
-			if (p1 == -1) {
+			if (p1 == -1)
 				throw new IllegalStateException(searched);
-			}
+
 			final int p2 = s.indexOf(" d=\"", p1);
 			final int p3 = s.indexOf("\"", p2 + " d=\"".length());
 			final String points = s.substring(p2 + " d=\"".length(), p3);
-			final DotPath dotPath = new DotPath(new SvgResult(points, yDelta));
+			final DotPath dotPath = new SvgResult(points, yDelta).toDotPath();
 			p.setDotPath(dotPath);
 			minMax.manage(dotPath.getMinFinder());
 
@@ -183,41 +187,37 @@ public class GraphvizSolverB {
 
 	static private double getMaxX(List<XPoint2D> points) {
 		double result = points.get(0).x;
-		for (int i = 1; i < points.size(); i++) {
-			if (points.get(i).x > result) {
+		for (int i = 1; i < points.size(); i++)
+			if (points.get(i).x > result)
 				result = points.get(i).x;
-			}
-		}
+
 		return result;
 	}
 
 	static private double getMinX(List<XPoint2D> points) {
 		double result = points.get(0).x;
-		for (int i = 1; i < points.size(); i++) {
-			if (points.get(i).x < result) {
+		for (int i = 1; i < points.size(); i++)
+			if (points.get(i).x < result)
 				result = points.get(i).x;
-			}
-		}
+
 		return result;
 	}
 
 	static private double getMaxY(List<XPoint2D> points) {
 		double result = points.get(0).y;
-		for (int i = 1; i < points.size(); i++) {
-			if (points.get(i).y > result) {
+		for (int i = 1; i < points.size(); i++)
+			if (points.get(i).y > result)
 				result = points.get(i).y;
-			}
-		}
+
 		return result;
 	}
 
 	static private double getMinY(List<XPoint2D> points) {
 		double result = points.get(0).y;
-		for (int i = 1; i < points.size(); i++) {
-			if (points.get(i).y < result) {
+		for (int i = 1; i < points.size(); i++)
+			if (points.get(i).y < result)
 				result = points.get(i).y;
-			}
-		}
+
 		return result;
 	}
 
@@ -225,18 +225,17 @@ public class GraphvizSolverB {
 		final Graphviz graphviz = GraphvizUtils.create(null, dotString, "png");
 		try (OutputStream os = f.createBufferedOutputStream()) {
 			final ProcessState state = graphviz.createFile3(os);
-			if (state.differs(ProcessState.TERMINATED_OK())) {
+			if (state.differs(ProcessState.TERMINATED_OK()))
 				throw new IllegalStateException("Timeout3 " + state);
-			}
+
 		}
 	}
 
 	private Path getPath(Collection<Path> paths, int start, int end) {
-		for (Path p : paths) {
-			if (p.getStart().getUid() == start && p.getEnd().getUid() == end) {
+		for (Path p : paths)
+			if (p.getStart().getUid() == start && p.getEnd().getUid() == end)
 				return p;
-			}
-		}
+
 		throw new IllegalArgumentException();
 
 	}
