@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -36,26 +36,32 @@
  */
 package net.sourceforge.plantuml.preproc2;
 
+import static java.nio.charset.StandardCharsets.UTF_8;
+
+import java.io.ByteArrayInputStream;
 import java.io.IOException;
 import java.io.InputStream;
 import java.io.InputStreamReader;
 import java.io.UnsupportedEncodingException;
 import java.nio.charset.Charset;
+import java.util.ArrayList;
+import java.util.Collection;
+import java.util.List;
 import java.util.regex.Matcher;
 import java.util.regex.Pattern;
 
-import net.sourceforge.plantuml.LineLocation;
-import net.sourceforge.plantuml.Log;
-import net.sourceforge.plantuml.StringLocated;
 import net.sourceforge.plantuml.StringUtils;
 import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.preproc.ReadLine;
+import net.sourceforge.plantuml.preproc.ReadLineConcat;
 import net.sourceforge.plantuml.preproc.ReadLineReader;
 import net.sourceforge.plantuml.preproc.ReadLineSimple;
 import net.sourceforge.plantuml.preproc.StartDiagramExtractReader;
 import net.sourceforge.plantuml.preproc.Stdlib;
 import net.sourceforge.plantuml.security.SURL;
+import net.sourceforge.plantuml.text.StringLocated;
 import net.sourceforge.plantuml.tim.EaterException;
+import net.sourceforge.plantuml.utils.Log;
 
 public class PreprocessorUtils {
 
@@ -94,6 +100,22 @@ public class PreprocessorUtils {
 		return result;
 	}
 
+	// ::comment when __CORE__
+	public static ReadLine getReaderNonstandardInclude(StringLocated s, String filename) {
+		if (filename.endsWith(".puml") == false)
+			filename = filename + ".puml";
+		Log.info("Loading non standard " + filename);
+		final String res = "/stdlib/" + filename;
+		InputStream is = Stdlib.class.getResourceAsStream(res);
+
+		if (is == null)
+			return null;
+
+		final String description = "[" + filename + "]";
+		return ReadLineReader.create(new InputStreamReader(is), description);
+	}
+	// ::done
+
 	public static ReadLine getReaderStdlibInclude(StringLocated s, String filename) {
 		Log.info("Loading sdlib " + filename);
 		InputStream is = getStdlibInputStream(filename);
@@ -102,9 +124,9 @@ public class PreprocessorUtils {
 
 		final String description = "<" + filename + ">";
 		try {
-			if (StartDiagramExtractReader.containsStartDiagram(is, s, description)) {
+			if (StartDiagramExtractReader.containsStartDiagram(is, description)) {
 				is = getStdlibInputStream(filename);
-				return StartDiagramExtractReader.build(is, s, description);
+				return StartDiagramExtractReader.build(is, description);
 			}
 			is = getStdlibInputStream(filename);
 			if (is == null)
@@ -117,27 +139,40 @@ public class PreprocessorUtils {
 		}
 	}
 
+	public static ReadLine getReaderStdlibIncludeSprites(StringLocated s, String root) throws IOException {
+		final Stdlib lib = Stdlib.retrieve(root);
+		final Collection<String> filenames = lib.getAllFilenamesWithSprites();
+		final List<ReadLine> readers = new ArrayList<>();
+
+		for (String name : filenames) {
+			final String data = lib.loadResource(name);
+			final InputStream is = new ByteArrayInputStream(data.getBytes(UTF_8));
+			readers.add(StartDiagramExtractReader.build(is, "<" + root + "/" + name + ">"));
+		}
+		return new ReadLineConcat(readers);
+	}
+
 	public static ReadLine getReaderIncludeUrl(final SURL url, StringLocated s, String suf, Charset charset)
 			throws EaterException {
 		try {
 			if (StartDiagramExtractReader.containsStartDiagram(url, s, charset))
 				return StartDiagramExtractReader.build(url, s, suf, charset);
 
-			return getReaderInclude(url, s.getLocation(), charset);
+			return getReaderInclude(url, s, charset);
 		} catch (IOException e) {
 			Logme.error(e);
-			throw EaterException.located("Cannot open URL " + e.getMessage());
+			throw new EaterException("Cannot open URL " + e.getMessage(), s);
 		}
 
 	}
 
-	public static ReadLine getReaderInclude(SURL url, LineLocation lineLocation, Charset charset)
+	public static ReadLine getReaderInclude(SURL url, StringLocated s, Charset charset)
 			throws EaterException, UnsupportedEncodingException {
 		final InputStream is = url.openStream();
 		if (is == null)
-			throw EaterException.located("Cannot open URL");
+			throw new EaterException("Cannot open URL", s);
 
-		return ReadLineReader.create(new InputStreamReader(is, charset), url.toString(), lineLocation);
+		return ReadLineReader.create(new InputStreamReader(is, charset), url.toString(), s.getLocation());
 	}
 
 }
