@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
+ *
+ * Project Info:  https://plantuml.com
  *
- * Project Info:  http://plantuml.com
- * 
  * If you like this project or if you find it useful, you can support us at:
- * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
- * 
+ *
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,7 +30,7 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.project;
@@ -53,20 +53,26 @@ import java.util.regex.Pattern;
 
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.TitledDiagram;
-import net.sourceforge.plantuml.UmlDiagramType;
 import net.sourceforge.plantuml.WithSprite;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XRectangle2D;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.core.UmlSource;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.InnerStrategy;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.UDrawable;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.color.HColors;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.AbstractTextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.UDrawable;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
 import net.sourceforge.plantuml.log.Logme;
+import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
 import net.sourceforge.plantuml.project.core.Moment;
 import net.sourceforge.plantuml.project.core.MomentImpl;
 import net.sourceforge.plantuml.project.core.PrintScale;
@@ -80,6 +86,7 @@ import net.sourceforge.plantuml.project.core.TaskInstant;
 import net.sourceforge.plantuml.project.core.TaskSeparator;
 import net.sourceforge.plantuml.project.draw.FingerPrint;
 import net.sourceforge.plantuml.project.draw.ResourceDraw;
+import net.sourceforge.plantuml.project.draw.ResourceDrawNumbers;
 import net.sourceforge.plantuml.project.draw.TaskDraw;
 import net.sourceforge.plantuml.project.draw.TaskDrawDiamond;
 import net.sourceforge.plantuml.project.draw.TaskDrawGroup;
@@ -92,7 +99,9 @@ import net.sourceforge.plantuml.project.draw.TimeHeaderQuarterly;
 import net.sourceforge.plantuml.project.draw.TimeHeaderSimple;
 import net.sourceforge.plantuml.project.draw.TimeHeaderWeekly;
 import net.sourceforge.plantuml.project.draw.TimeHeaderYearly;
+import net.sourceforge.plantuml.project.draw.WeeklyHeaderStrategy;
 import net.sourceforge.plantuml.project.lang.CenterBorderColor;
+import net.sourceforge.plantuml.project.solver.ImpossibleSolvingException;
 import net.sourceforge.plantuml.project.time.Day;
 import net.sourceforge.plantuml.project.time.DayOfWeek;
 import net.sourceforge.plantuml.project.time.WeekNumberStrategy;
@@ -100,26 +109,21 @@ import net.sourceforge.plantuml.project.timescale.TimeScale;
 import net.sourceforge.plantuml.real.Real;
 import net.sourceforge.plantuml.real.RealOrigin;
 import net.sourceforge.plantuml.real.RealUtils;
+import net.sourceforge.plantuml.skin.UmlDiagramType;
+import net.sourceforge.plantuml.stereo.Stereotype;
 import net.sourceforge.plantuml.style.ClockwiseTopRightBottomLeft;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.GraphvizCrash;
-import net.sourceforge.plantuml.svek.TextBlockBackcolored;
-import net.sourceforge.plantuml.ugraphic.MinMax;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
+import net.sourceforge.plantuml.text.BackSlash;
 
-public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprite {
+public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprite, GanttStyle {
 
 	private final Map<Task, TaskDraw> draws = new LinkedHashMap<Task, TaskDraw>();
 	private final Map<TaskCode, Task> tasks = new LinkedHashMap<TaskCode, Task>();
-	private final Map<String, Task> byShortName = new HashMap<String, Task>();
+
 	private final List<GanttConstraint> constraints = new ArrayList<>();
 	private final HColorSet colorSet = HColorSet.instance();
 
@@ -149,21 +153,26 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 
 	private final RealOrigin origin = RealUtils.createOrigin();
 
+	private int defaultCompletion = 100;
+
+	private Task it;
+	private Resource they;
+
 	public CommandExecutionResult changeLanguage(String lang) {
 		this.locale = new Locale(lang);
 		return CommandExecutionResult.ok();
 	}
 
 	public DiagramDescription getDescription() {
-		return new DiagramDescription("(Project)");
+		return new DiagramDescription("(Gantt)");
 	}
 
 	public void setWeekNumberStrategy(DayOfWeek firstDayOfWeek, int minimalDaysInFirstWeek) {
 		this.weekNumberStrategy = new WeekNumberStrategy(firstDayOfWeek, minimalDaysInFirstWeek);
 	}
 
-	public GanttDiagram(UmlSource source) {
-		super(source, UmlDiagramType.GANTT, null);
+	public GanttDiagram(UmlSource source, PreprocessingArtifact preprocessing) {
+		super(source, UmlDiagramType.GANTT, null, preprocessing);
 	}
 
 	public final int getDpi(FileFormatOption fileFormatOption) {
@@ -173,8 +182,7 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 	@Override
 	protected ImageData exportDiagramNow(OutputStream os, int index, FileFormatOption fileFormatOption)
 			throws IOException {
-		final StringBounder stringBounder = fileFormatOption.getDefaultStringBounder(getSkinParam());
-		return createImageBuilder(fileFormatOption).drawable(getTextBlock(stringBounder)).write(os);
+		return createImageBuilder(fileFormatOption).drawable(getTextMainBlock(fileFormatOption)).write(os);
 	}
 
 	public void setPrintScale(PrintScale printScale) {
@@ -202,16 +210,29 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		return false;
 	}
 
-	private TextBlockBackcolored getTextBlock(StringBounder stringBounder) {
+	@Override
+	public String checkFinalError() {
+		try {
+			initMinMax();
+		} catch (ImpossibleSolvingException ex) {
+			return ex.getMessage();
+		}
+		return null;
+	}
+
+	@Override
+	protected TextBlock getTextMainBlock(FileFormatOption fileFormatOption) {
+		final StringBounder stringBounder = fileFormatOption.getDefaultStringBounder(getSkinParam());
 		if (printStart == null) {
 			initMinMax();
 		} else {
 			this.min = printStart;
 			this.max = printEnd;
 		}
-		final TimeHeader timeHeader = getTimeHeader();
-		initTaskAndResourceDraws(timeHeader.getTimeScale(), timeHeader.getFullHeaderHeight(), stringBounder);
-		return new TextBlockBackcolored() {
+		final TimeHeader timeHeader = getTimeHeader(stringBounder);
+		initTaskAndResourceDraws(timeHeader.getTimeScale(), timeHeader.getFullHeaderHeight(stringBounder),
+				stringBounder);
+		return new AbstractTextBlock() {
 
 			public void drawU(UGraphic ug) {
 				try {
@@ -223,16 +244,15 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 							.of(SName.root, SName.element, SName.ganttDiagram, SName.timeline)
 							.getMergedStyle(getCurrentStyleBuilder());
 
-					final HColor back = timelineStyle.value(PName.BackGroundColor)
-							.asColor(getIHtmlColorSet());
+					final HColor back = timelineStyle.value(PName.BackGroundColor).asColor(getIHtmlColorSet());
 					if (back.isTransparent() == false) {
-						final URectangle rect1 = new URectangle(calculateDimension(ug.getStringBounder()).getWidth(),
-								timeHeader.getTimeHeaderHeight());
+						final URectangle rect1 = URectangle.build(calculateDimension(ug.getStringBounder()).getWidth(),
+								timeHeader.getTimeHeaderHeight(ug.getStringBounder()));
 						ug.apply(back.bg()).draw(rect1);
 						if (showFootbox) {
-							final URectangle rect2 = new URectangle(
+							final URectangle rect2 = URectangle.build(
 									calculateDimension(ug.getStringBounder()).getWidth(),
-									timeHeader.getTimeFooterHeight());
+									timeHeader.getTimeFooterHeight(ug.getStringBounder()));
 							ug.apply(back.bg()).apply(UTranslate.dy(totalHeightWithoutFooter)).draw(rect2);
 						}
 					}
@@ -251,7 +271,8 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 
 				} catch (Throwable t) {
 					Logme.error(t);
-					final UDrawable crash = new GraphvizCrash(getSource().getPlainString(), false, t);
+					final UDrawable crash = new GraphvizCrash(getSource().getPlainString(BackSlash.lineSeparator()),
+							false, t);
 					crash.drawU(ug);
 
 				}
@@ -271,13 +292,9 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 				return width;
 			}
 
-			public XRectangle2D getInnerPosition(String member, StringBounder stringBounder, InnerStrategy strategy) {
-				return null;
-			}
-
 			public XDimension2D calculateDimension(StringBounder stringBounder) {
 				return new XDimension2D(getTitlesColumnWidth(stringBounder) + getBarsColumnWidth(timeHeader),
-						getTotalHeight(timeHeader));
+						getTotalHeight(stringBounder, timeHeader));
 			}
 
 			private double getBarsColumnWidth(final TimeHeader timeHeader) {
@@ -286,37 +303,31 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 				return xmax - xmin;
 			}
 
-			public MinMax getMinMax(StringBounder stringBounder) {
-				throw new UnsupportedOperationException();
-			}
-
-			public HColor getBackcolor() {
-				return null;
-			}
 		};
 	}
 
-	private TimeHeader getTimeHeader() {
+	private TimeHeader getTimeHeader(StringBounder stringBounder) {
 		if (openClose.getStartingDay() == null)
-			return new TimeHeaderSimple(thParam(), printScale);
+			return new TimeHeaderSimple(stringBounder, thParam(), printScale);
 		else if (printScale == PrintScale.DAILY)
-			return new TimeHeaderDaily(thParam(), nameDays, printStart, printEnd);
+			return new TimeHeaderDaily(stringBounder, thParam(), nameDays, printStart);
 		else if (printScale == PrintScale.WEEKLY)
-			return new TimeHeaderWeekly(thParam(), weekNumberStrategy, withCalendarDate);
+			return new TimeHeaderWeekly(stringBounder, thParam(), weekNumberStrategy, weeklyHeaderStrategy, nameDays,
+					printStart);
 		else if (printScale == PrintScale.MONTHLY)
-			return new TimeHeaderMonthly(thParam());
+			return new TimeHeaderMonthly(stringBounder, thParam(), nameDays, printStart);
 		else if (printScale == PrintScale.QUARTERLY)
-			return new TimeHeaderQuarterly(thParam());
+			return new TimeHeaderQuarterly(stringBounder, thParam(), printStart);
 		else if (printScale == PrintScale.YEARLY)
-			return new TimeHeaderYearly(thParam());
+			return new TimeHeaderYearly(stringBounder, thParam(), printStart);
 		else
 			throw new IllegalStateException();
 
 	}
 
 	private TimeHeaderParameters thParam() {
-		return new TimeHeaderParameters(colorDays(), getFactorScale(), min, max, getIHtmlColorSet(),
-				getTimelineStyle(), getClosedStyle(), locale, openClose, colorDaysOfWeek, verticalSeparatorBefore);
+		return new TimeHeaderParameters(colorDays(), getFactorScale(), min, max, getIHtmlColorSet(), locale, openClose,
+				colorDaysOfWeek, verticalSeparatorBefore, this, hideClosed);
 	}
 
 	private Map<Day, HColor> colorDays() {
@@ -324,19 +335,21 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		return Collections.unmodifiableMap(colorDaysInternal);
 	}
 
-	private Style getClosedStyle() {
-		return StyleSignatureBasic.of(SName.root, SName.element, SName.ganttDiagram, SName.closed)
+	@Override
+	public final Style getStyle(SName param) {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.ganttDiagram, param)
 				.getMergedStyle(getCurrentStyleBuilder());
 	}
 
-	private Style getTimelineStyle() {
-		return StyleSignatureBasic.of(SName.root, SName.element, SName.ganttDiagram, SName.timeline)
+	@Override
+	public final Style getStyle(SName param1, SName param2) {
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.ganttDiagram, param1, param2)
 				.getMergedStyle(getCurrentStyleBuilder());
 	}
 
-	private double getTotalHeight(TimeHeader timeHeader) {
+	private double getTotalHeight(StringBounder stringBounder, TimeHeader timeHeader) {
 		if (showFootbox)
-			return totalHeightWithoutFooter + timeHeader.getTimeFooterHeight();
+			return totalHeightWithoutFooter + timeHeader.getTimeFooterHeight(stringBounder);
 
 		return totalHeightWithoutFooter;
 	}
@@ -433,21 +446,21 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 						getSkinParam().getIHtmlColorSet());
 			} else if (task instanceof TaskGroup) {
 				final TaskGroup taskGroup = (TaskGroup) task;
-				draw = new TaskDrawGroup(timeScale, y, taskGroup.getCode().getSimpleDisplay(), getStart(taskGroup),
-						getEnd(taskGroup), getSkinParam(), task, this, task.getStyleBuilder());
+				draw = new TaskDrawGroup(timeScale, y, taskGroup.getCode().getDisplay(), getStart(taskGroup),
+						getEnd(taskGroup), task, this, task.getStyleBuilder());
 			} else {
 				final TaskImpl tmp = (TaskImpl) task;
-				final String disp = hideResourceName ? tmp.getCode().getSimpleDisplay() : tmp.getPrettyDisplay();
+				final String disp = hideResourceName ? tmp.getCode().getDisplay() : tmp.getPrettyDisplay();
 				if (tmp.isDiamond()) {
-					draw = new TaskDrawDiamond(timeScale, y, disp, getStart(tmp), getSkinParam(), task, this,
-							task.getStyleBuilder());
+					draw = new TaskDrawDiamond(timeScale, y, disp, getStart(tmp), task, this, task.getStyleBuilder());
 				} else {
 					final boolean oddStart = printStart != null && min.compareTo(getStart(tmp)) == 0;
 					final boolean oddEnd = printStart != null && max.compareTo(getEnd(tmp)) == 0;
 					draw = new TaskDrawRegular(timeScale, y, disp, getStart(tmp), getEnd(tmp), oddStart, oddEnd,
 							getSkinParam(), task, this, getConstraints(task), task.getStyleBuilder());
 				}
-				draw.setColorsAndCompletion(tmp.getColors(), tmp.getCompletion(), tmp.getUrl(), tmp.getNote());
+				draw.setColorsAndCompletion(tmp.getColors(), tmp.getCompletion(), tmp.getUrl(), tmp.getNote(),
+						tmp.getNoteStereotype());
 			}
 			if (task.getRow() == null)
 				y = y.addAtLeast(draw.getFullHeightTask(stringBounder));
@@ -461,21 +474,30 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 			yy = headerHeight;
 		} else if (this.hideResourceFoobox == false)
 			for (Resource res : resources.values()) {
-				final ResourceDraw draw = new ResourceDraw(this, res, timeScale, yy, min, max);
+				final ResourceDraw draw = buildResourceDraw(this, res, timeScale, yy, min, max);
 				res.setTaskDraw(draw);
-				yy += draw.getHeight();
+				yy += draw.getHeight(stringBounder);
 			}
 
 		this.totalHeightWithoutFooter = yy;
 	}
 
+	private ResourceDraw buildResourceDraw(GanttDiagram gantt, Resource res, TimeScale timeScale, double y, Day min,
+			Day max) {
+//		if (printScale == PrintScale.DAILY || printScale == PrintScale.MONTHLY || printScale == PrintScale.QUARTERLY
+//				|| printScale == PrintScale.YEARLY)
+//			return new ResourceDrawHistogram(gantt, res, timeScale, y, min, max);
+
+		return new ResourceDrawNumbers(gantt, res, timeScale, y, min, max);
+		// return new ResourceDrawVersion2(gantt, res, timeScale, y, min, max);
+	}
+
 	private Collection<GanttConstraint> getConstraints(Task task) {
 		final List<GanttConstraint> result = new ArrayList<>();
-		for (GanttConstraint constraint : constraints) {
+		for (GanttConstraint constraint : constraints)
 			if (constraint.isOn(task))
 				result.add(constraint);
 
-		}
 		return Collections.unmodifiableCollection(result);
 	}
 
@@ -570,11 +592,7 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 	}
 
 	public Task getExistingTask(String id) {
-		final Task result = byShortName.get(Objects.requireNonNull(id));
-		if (result != null)
-			return result;
-
-		final TaskCode code = new TaskCode(id);
+		final TaskCode code = TaskCode.fromId(Objects.requireNonNull(id));
 		return tasks.get(code);
 	}
 
@@ -587,33 +605,21 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		return result;
 	}
 
-	public Task getOrCreateTask(String codeOrShortName, String shortName, boolean linkedToPrevious) {
-		Objects.requireNonNull(codeOrShortName);
-		Task result = shortName == null ? null : byShortName.get(shortName);
-		if (result != null)
-			return result;
-
-		result = byShortName.get(codeOrShortName);
-		if (result != null)
-			return result;
-
-		final TaskCode code = new TaskCode(codeOrShortName);
-		result = tasks.get(code);
+	public Task getOrCreateTask(TaskCode code, boolean linkedToPrevious) {
+		Task result = tasks.get(Objects.requireNonNull(code));
 		if (result == null) {
 			Task previous = null;
 			if (linkedToPrevious)
 				previous = getLastCreatedTask();
 
-			final OpenClose except = this.openCloseForTask.get(codeOrShortName);
+			final OpenClose except = this.openCloseForTask.get(code.getId());
 
 			result = new TaskImpl(getSkinParam().getCurrentStyleBuilder(), code, openClose.mutateMe(except),
-					openClose.getStartingDay());
+					openClose.getStartingDay(), defaultCompletion);
 			if (currentGroup != null)
 				currentGroup.addTask(result);
 
 			tasks.put(code, result);
-			if (byShortName != null)
-				byShortName.put(shortName, result);
 
 			if (previous != null)
 				forceTaskOrder(previous, result);
@@ -638,8 +644,8 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 
 	private TaskGroup currentGroup = null;
 
-	public CommandExecutionResult addGroup(String name) {
-		TaskGroup group = new TaskGroup(this.currentGroup, getSkinParam().getCurrentStyleBuilder(), name);
+	public CommandExecutionResult addGroup(TaskCode code) {
+		TaskGroup group = new TaskGroup(this.currentGroup, getSkinParam().getCurrentStyleBuilder(), code);
 
 		if (this.currentGroup != null)
 			this.currentGroup.addTask(group);
@@ -666,7 +672,7 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		return colorSet;
 	}
 
-	public void setStartingDate(Day start) {
+	public void setProjectStartingDate(Day start) {
 		openClose.setStartingDay(start);
 		this.min = start;
 	}
@@ -678,6 +684,11 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		return openClose.getStartingDay();
 	}
 
+	public Day getEndingDate() {
+		initMinMax();
+		return max;
+	}
+
 	public int daysInWeek() {
 		return openClose.daysInWeek();
 	}
@@ -776,6 +787,13 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		nameDays.put(day, name);
 	}
 
+	public Day getToday() {
+		if (today == null)
+			this.today = Day.today();
+
+		return today;
+	}
+
 	public void setTodayColors(CenterBorderColor colors) {
 		if (today == null)
 			this.today = Day.today();
@@ -802,14 +820,14 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		return draws.get(task);
 	}
 
-	public CommandExecutionResult addNote(Display note) {
+	public CommandExecutionResult addNote(Display note, Stereotype stereotype) {
 		Task last = null;
 		for (Task current : tasks.values())
 			last = current;
 		if (last == null)
 			return CommandExecutionResult.error("No task defined");
 
-		last.setNote(note);
+		last.setNote(note, stereotype);
 		return CommandExecutionResult.ok();
 	}
 
@@ -833,10 +851,10 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		this.labelStrategy = strategy;
 	}
 
-	private boolean withCalendarDate;
+	private WeeklyHeaderStrategy weeklyHeaderStrategy;
 
-	public void setWithCalendarDate(boolean withCalendarDate) {
-		this.withCalendarDate = withCalendarDate;
+	public void setWeeklyHeaderStrategy(WeeklyHeaderStrategy weeklyHeaderStrategy) {
+		this.weeklyHeaderStrategy = weeklyHeaderStrategy;
 	}
 
 	private boolean hideResourceName;
@@ -858,4 +876,41 @@ public class GanttDiagram extends TitledDiagram implements ToTaskDraw, WithSprit
 		verticalSeparatorBefore.add(day);
 	}
 
+	public void setTaskDefaultCompletion(int defaultCompletion) {
+		this.defaultCompletion = defaultCompletion;
+	}
+
+	public List<TaskDrawRegular> getAllTasksForResource(Resource res) {
+		final List<TaskDrawRegular> result = new ArrayList<TaskDrawRegular>();
+		for (Task task : tasks.values())
+			if (task.isAssignedTo(res)) {
+				final TaskDrawRegular draw = (TaskDrawRegular) draws.get(task);
+				result.add(draw);
+			}
+
+		return Collections.unmodifiableList(result);
+	}
+
+	public void setIt(Task result) {
+		this.it = result;
+	}
+
+	public Task getIt() {
+		return it;
+	}
+
+	public final Resource getThey() {
+		return they;
+	}
+
+	public final void setThey(Resource they) {
+		this.they = they;
+	}
+
+	private boolean hideClosed = false;
+
+	public void setHideClosed(boolean hideClosed) {
+		this.hideClosed = hideClosed;
+	}
+
 }
