@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,18 +35,19 @@
  */
 package net.sourceforge.plantuml.project.command;
 
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexResult;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
 import net.sourceforge.plantuml.project.GanttDiagram;
 import net.sourceforge.plantuml.project.core.Task;
 import net.sourceforge.plantuml.project.lang.CenterBorderColor;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexResult;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandColorTask extends SingleLineCommand2<GanttDiagram> {
 
@@ -59,11 +60,12 @@ public class CommandColorTask extends SingleLineCommand2<GanttDiagram> {
 				new RegexLeaf("CODE", "\\[([%pLN_.]+)\\]"), //
 				RegexLeaf.spaceOneOrMore(), //
 				new RegexLeaf("COLORS", "#(\\w+)(?:/(#?\\w+))?"), //
-				RegexLeaf.spaceZeroOrMore(), RegexLeaf.end());
+				RegexLeaf.spaceZeroOrMore(), //
+				RegexLeaf.end());
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(GanttDiagram diagram, LineLocation location, RegexResult arg)
+	protected CommandExecutionResult executeArg(GanttDiagram diagram, LineLocation location, RegexResult arg, ParserPass currentPass)
 			throws NoSuchColorException {
 
 		final String code = arg.get("CODE", 0);
@@ -74,10 +76,8 @@ public class CommandColorTask extends SingleLineCommand2<GanttDiagram> {
 
 		final String color1 = arg.get("COLORS", 0);
 		final String color2 = arg.get("COLORS", 1);
-		final HColor col1 = color1 == null ? null
-				: diagram.getIHtmlColorSet().getColor(color1);
-		final HColor col2 = color2 == null ? null
-				: diagram.getIHtmlColorSet().getColor(color2);
+		final HColor col1 = color1 == null ? null : diagram.getIHtmlColorSet().getColor(color1);
+		final HColor col2 = color2 == null ? null : diagram.getIHtmlColorSet().getColor(color2);
 		task.setColors(new CenterBorderColor(col1, col2));
 
 		return CommandExecutionResult.ok();
