@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,17 +35,19 @@
  */
 package net.sourceforge.plantuml.project.command;
 
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexOptional;
-import net.sourceforge.plantuml.command.regex.RegexOr;
-import net.sourceforge.plantuml.command.regex.RegexResult;
 import net.sourceforge.plantuml.project.GanttDiagram;
 import net.sourceforge.plantuml.project.core.PrintScale;
+import net.sourceforge.plantuml.project.draw.WeeklyHeaderStrategy;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexOptional;
+import net.sourceforge.plantuml.regex.RegexOr;
+import net.sourceforge.plantuml.regex.RegexResult;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandPrintScale extends SingleLineCommand2<GanttDiagram> {
 
@@ -67,21 +69,19 @@ public class CommandPrintScale extends SingleLineCommand2<GanttDiagram> {
 						new RegexLeaf("weekly")), //
 				new RegexOptional(new RegexConcat( //
 						RegexLeaf.spaceOneOrMore(), //
-						new RegexLeaf("DATE", "(with)"), //
-						RegexLeaf.spaceOneOrMore(), //
-						new RegexLeaf("calendar"), //
-						RegexLeaf.spaceOneOrMore(), //
-						new RegexLeaf("date"))), //
+						new RegexOr("OPTION", //
+								new RegexLeaf("(with\\s+calendar\\s+date)"),
+								new RegexLeaf("(with\\s+week\\s+numbering\\s+from\\s+1)")))), //
 				new RegexOptional(new RegexConcat( //
 						RegexLeaf.spaceOneOrMore(), //
 						new RegexLeaf("zoom"), //
 						RegexLeaf.spaceOneOrMore(), //
 						new RegexLeaf("ZOOM", "([.\\d]+)"))), //
-				RegexLeaf.end()); //
+				RegexLeaf.end());
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(GanttDiagram diagram, LineLocation location, RegexResult arg) {
+	protected CommandExecutionResult executeArg(GanttDiagram diagram, LineLocation location, RegexResult arg, ParserPass currentPass) {
 		final String scaleString = arg.get("SCALE", 0);
 		final PrintScale scale = PrintScale.fromString(scaleString);
 		diagram.setPrintScale(scale);
@@ -90,9 +90,12 @@ public class CommandPrintScale extends SingleLineCommand2<GanttDiagram> {
 		if (zoom != null)
 			diagram.setFactorScale(Double.parseDouble(zoom));
 
-		final String withCalendarDate = arg.get("DATE", 0);
-		if (withCalendarDate != null)
-			diagram.setWithCalendarDate(true);
+		final String option = arg.get("OPTION", 0);
+		if (option != null)
+			if (option.contains("date"))
+				diagram.setWeeklyHeaderStrategy(WeeklyHeaderStrategy.DAY_OF_MONTH);
+			else if (option.contains("1"))
+				diagram.setWeeklyHeaderStrategy(WeeklyHeaderStrategy.FROM_1);
 
 		return CommandExecutionResult.ok();
 	}
