@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,34 +35,35 @@
  */
 package net.sourceforge.plantuml.project.draw;
 
-import net.sourceforge.plantuml.Direction;
-import net.sourceforge.plantuml.SpriteContainerEmpty;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
+import net.sourceforge.plantuml.klimt.shape.ULine;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
+import net.sourceforge.plantuml.klimt.sprite.SpriteContainerEmpty;
 import net.sourceforge.plantuml.project.LabelStrategy;
+import net.sourceforge.plantuml.project.core.GArrowType;
+import net.sourceforge.plantuml.project.core.GSide;
 import net.sourceforge.plantuml.project.core.Task;
-import net.sourceforge.plantuml.project.core.TaskAttribute;
 import net.sourceforge.plantuml.project.lang.CenterBorderColor;
 import net.sourceforge.plantuml.project.time.Day;
 import net.sourceforge.plantuml.project.timescale.TimeScale;
 import net.sourceforge.plantuml.real.Real;
+import net.sourceforge.plantuml.stereo.Stereotype;
 import net.sourceforge.plantuml.style.ClockwiseTopRightBottomLeft;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
+import net.sourceforge.plantuml.url.Url;
 
 public class TaskDrawSeparator implements TaskDraw {
 
@@ -92,11 +93,11 @@ public class TaskDrawSeparator implements TaskDraw {
 		final double dx = margin.getLeft() + padding.getLeft();
 		final double dy = margin.getTop() + padding.getTop();
 		final double x;
-		if (labelStrategy.titleInFirstColumn()) {
+		if (labelStrategy.titleInFirstColumn())
 			x = colTitles;
-		} else {
+		else
 			x = 0;
-		}
+
 		getTitle().drawU(ug.apply(new UTranslate(x + dx, dy)));
 	}
 
@@ -115,11 +116,11 @@ public class TaskDrawSeparator implements TaskDraw {
 	}
 
 	private TextBlock getTitle() {
-		if (name == null) {
+		if (name == null)
 			return TextBlockUtils.empty(0, 0);
-		}
-		return Display.getWithNewlines(this.name).create(getFontConfiguration(), HorizontalAlignment.LEFT,
-				new SpriteContainerEmpty());
+
+		return Display.getWithNewlines(styleBuilder.getSkinParam().getPragma(), this.name)
+				.create(getFontConfiguration(), HorizontalAlignment.LEFT, new SpriteContainerEmpty());
 	}
 
 	private FontConfiguration getFontConfiguration() {
@@ -138,13 +139,12 @@ public class TaskDrawSeparator implements TaskDraw {
 		final ClockwiseTopRightBottomLeft margin = getStyle().getMargin();
 		ug = ug.apply(new UTranslate(0, margin.getTop()));
 
-		final HColor backColor = getStyle().value(PName.BackGroundColor)
-				.asColor(colorSet);
+		final HColor backColor = getStyle().value(PName.BackGroundColor).asColor(colorSet);
 
 		if (backColor.isTransparent() == false) {
 			final double height = padding.getTop() + getTextHeight(stringBounder) + padding.getBottom();
 			if (height > 0) {
-				final URectangle rect = new URectangle(end - start, height);
+				final URectangle rect = URectangle.build(end - start, height);
 				ug.apply(backColor.bg()).draw(rect);
 			}
 		}
@@ -204,7 +204,8 @@ public class TaskDrawSeparator implements TaskDraw {
 	}
 
 	@Override
-	public void setColorsAndCompletion(CenterBorderColor colors, int completion, Url url, Display note) {
+	public void setColorsAndCompletion(CenterBorderColor colors, int completion, Url url, Display note,
+			Stereotype noteStereotype) {
 	}
 
 	@Override
@@ -213,7 +214,7 @@ public class TaskDrawSeparator implements TaskDraw {
 	}
 
 	@Override
-	public double getY(StringBounder stringBounder, Direction direction) {
+	public double getY(StringBounder stringBounder, GSide side) {
 		throw new UnsupportedOperationException();
 	}
 
@@ -223,12 +224,7 @@ public class TaskDrawSeparator implements TaskDraw {
 	}
 
 	@Override
-	public double getX1(TaskAttribute taskAttribute) {
-		throw new UnsupportedOperationException();
-	}
-
-	@Override
-	public double getX2(TaskAttribute taskAttribute) {
+	public double getX(StringBounder stringBounder, GSide side, GArrowType arrowType) {
 		throw new UnsupportedOperationException();
 	}
 
