@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -49,6 +49,7 @@ import java.io.InputStream;
 import java.io.PrintStream;
 import java.io.PrintWriter;
 import java.io.UnsupportedEncodingException;
+import java.lang.reflect.Method;
 import java.net.URI;
 import java.nio.charset.Charset;
 import java.nio.file.Path;
@@ -58,6 +59,7 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
+import javax.imageio.stream.ImageInputStream;
 import javax.swing.ImageIcon;
 
 import net.sourceforge.plantuml.log.Logme;
@@ -84,13 +86,14 @@ public class SFile implements Comparable<SFile> {
 
 	@Override
 	public String toString() {
-		if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE)
-			try {
-				return internal.getCanonicalPath();
-			} catch (IOException e) {
-				return internal.getAbsolutePath();
-			}
-		return super.toString();
+		if (SecurityUtils.getSecurityProfile() == SecurityProfile.INTERNET
+				|| SecurityUtils.getSecurityProfile() == SecurityProfile.ALLOWLIST)
+			return super.toString();
+		try {
+			return internal.getCanonicalPath();
+		} catch (IOException e) {
+			return internal.getAbsolutePath();
+		}
 	}
 
 	public SFile(String nameOrPath) {
@@ -114,9 +117,9 @@ public class SFile implements Comparable<SFile> {
 	}
 
 	public static SFile fromFile(File internal) {
-		if (internal == null) {
+		if (internal == null)
 			return null;
-		}
+
 		return new SFile(internal);
 	}
 
@@ -184,9 +187,9 @@ public class SFile implements Comparable<SFile> {
 			return Collections.emptyList();
 
 		final List<SFile> result = new ArrayList<>(tmp.length);
-		for (File f : tmp) {
+		for (File f : tmp)
 			result.add(new SFile(f));
-		}
+
 		return Collections.unmodifiableCollection(result);
 	}
 
@@ -254,7 +257,8 @@ public class SFile implements Comparable<SFile> {
 	/**
 	 * Check SecurityProfile to see if this file can be open.
 	 */
-	private boolean isFileOk() {
+	public boolean isFileOk() {
+		// ::comment when __CORE__
 		if (SecurityUtils.getSecurityProfile() == SecurityProfile.SANDBOX)
 			// In SANDBOX, we cannot read any files
 			return false;
@@ -291,17 +295,17 @@ public class SFile implements Comparable<SFile> {
 				return false;
 
 		}
+		// ::done
 		return true;
 	}
 
 	private boolean isInAllowList(List<SFile> allowlist) {
 		final String path = getCleanPathSecure();
-		for (SFile allow : allowlist) {
-			if (path.startsWith(allow.getCleanPathSecure())) {
+		for (SFile allow : allowlist)
+			if (path.startsWith(allow.getCleanPathSecure()))
 				// File directory is in the allowlist
 				return true;
-			}
-		}
+
 		return false;
 	}
 
@@ -312,12 +316,14 @@ public class SFile implements Comparable<SFile> {
 	 * @throws IOException If an I/O error occurs, which is possible because the
 	 *                     check the pathname may require filesystem queries
 	 */
+	// ::comment when __CORE__
 	private boolean isDenied() throws IOException {
 		SFile securityPath = SecurityUtils.getSecurityPath();
 		if (securityPath == null)
 			return false;
 		return getSanitizedPath().startsWith(securityPath.getSanitizedPath());
 	}
+	// ::done
 
 	/**
 	 * Returns a sanitized, canonical and normalized Path to a file.
@@ -348,13 +354,66 @@ public class SFile implements Comparable<SFile> {
 		// https://stackoverflow.com/questions/18743790/can-java-load-images-with-transparency
 		if (isFileOk())
 			try {
-				return SecurityUtils.readRasterImage(new ImageIcon(this.getAbsolutePath()));
+				// ::comment when __CORE__
+				if (internal.getName().endsWith(".webp"))
+					return readWebp();
+				else
+					// ::done
+					return SecurityUtils.readRasterImage(new ImageIcon(this.getAbsolutePath()));
 			} catch (Exception e) {
 				Logme.error(e);
 			}
 		return null;
 	}
 
+	// ::comment when __CORE__
+	private BufferedImage readWebp() throws IOException {
+		try (InputStream is = openFile()) {
+			final int riff = read32(is);
+			if (riff != 0x46464952)
+				return null;
+			final int len1 = read32(is);
+			final int webp = read32(is);
+			if (webp != 0x50424557)
+				return null;
+			final int vp8_ = read32(is);
+			if (vp8_ != 0x20385056)
+				return null;
+			final int len2 = read32(is);
+			if (len1 != len2 + 12)
+				return null;
+
+			return getBufferedImageFromWebpButHeader(is);
+		}
+	}
+
+	private int read32(InputStream is) throws IOException {
+		return (is.read() << 0) + (is.read() << 8) + (is.read() << 16) + (is.read() << 24);
+	}
+
+	public static BufferedImage getBufferedImageFromWebpButHeader(InputStream is) {
+		if (is == null)
+			return null;
+		try {
+			final Class<?> clVP8Decoder = Class.forName("net.sourceforge.plantuml.webp.VP8Decoder");
+			final Object vp8Decoder = clVP8Decoder.getDeclaredConstructor().newInstance();
+			// final VP8Decoder vp8Decoder = new VP8Decoder();
+			final Method decodeFrame = clVP8Decoder.getMethod("decodeFrame", ImageInputStream.class);
+			final ImageInputStream iis = SImageIO.createImageInputStream(is);
+			decodeFrame.invoke(vp8Decoder, iis);
+			// vp8Decoder.decodeFrame(iis);
+			iis.close();
+			final Object frame = clVP8Decoder.getMethod("getFrame").invoke(vp8Decoder);
+			return (BufferedImage) frame.getClass().getMethod("getBufferedImage").invoke(frame);
+			// final VP8Frame frame = vp8Decoder.getFrame();
+			// return frame.getBufferedImage();
+		} catch (Exception e) {
+			Logme.error(e);
+			return null;
+		}
+	}
+	// ::done
+
 	public BufferedReader openBufferedReader() {
 		if (isFileOk()) {
 			try {
@@ -380,6 +439,7 @@ public class SFile implements Comparable<SFile> {
 		return null;
 	}
 
+	// ::comment when __CORE__
 	// Writing
 	public BufferedOutputStream createBufferedOutputStream() throws FileNotFoundException {
 		return new BufferedOutputStream(new FileOutputStream(internal));
@@ -412,5 +472,6 @@ public class SFile implements Comparable<SFile> {
 	public PrintStream createPrintStream(Charset charset) throws FileNotFoundException, UnsupportedEncodingException {
 		return new PrintStream(internal, charset.name());
 	}
+	// ::done
 
 }
