@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -50,14 +50,17 @@ import javax.imageio.stream.ImageOutputStream;
 
 public class SImageIO {
 
+	// ::comment when __CORE__
 	public static ImageOutputStream createImageOutputStream(OutputStream os) throws IOException {
 		return javax.imageio.ImageIO.createImageOutputStream(os);
 	}
+	// ::done
 
 	public static void write(RenderedImage image, String format, OutputStream os) throws IOException {
 		javax.imageio.ImageIO.write(image, format, os);
 	}
 
+	// ::comment when __CORE__
 	public static void write(RenderedImage image, String format, SFile file) throws IOException {
 		javax.imageio.ImageIO.write(image, format, file.conv());
 	}
@@ -69,6 +72,7 @@ public class SImageIO {
 	public static BufferedImage read(SFile file) throws IOException {
 		return javax.imageio.ImageIO.read(file.conv());
 	}
+	// ::done
 
 	public static BufferedImage read(InputStream is) throws IOException {
 		return javax.imageio.ImageIO.read(is);
@@ -78,14 +82,15 @@ public class SImageIO {
 		return javax.imageio.ImageIO.read(new ByteArrayInputStream(bytes));
 	}
 
+	// ::comment when __CORE__
 	public static ImageInputStream createImageInputStream(SFile file) throws IOException {
 		return javax.imageio.ImageIO.createImageInputStream(file.conv());
 	}
 
 	public static ImageInputStream createImageInputStream(Object obj) throws IOException {
-		if (obj instanceof SFile) {
+		if (obj instanceof SFile)
 			obj = ((SFile) obj).conv();
-		}
+
 		return javax.imageio.ImageIO.createImageInputStream(obj);
 	}
 
@@ -100,5 +105,6 @@ public class SImageIO {
 	public static Iterator<ImageWriter> getImageWritersBySuffix(String string) {
 		return javax.imageio.ImageIO.getImageWritersBySuffix(string);
 	}
+	// ::done
 
 }
