@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
+ *
+ * Project Info:  https://plantuml.com
  *
- * Project Info:  http://plantuml.com
- * 
  * If you like this project or if you find it useful, you can support us at:
- * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
- * 
+ *
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,7 +30,7 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.security;
@@ -44,6 +44,8 @@ import java.io.OutputStream;
 import java.net.HttpURLConnection;
 import java.net.MalformedURLException;
 import java.net.Proxy;
+import java.net.URI;
+import java.net.URISyntaxException;
 import java.net.URL;
 import java.net.URLConnection;
 import java.nio.charset.Charset;
@@ -72,6 +74,9 @@ import net.sourceforge.plantuml.log.Logme;
 import net.sourceforge.plantuml.security.authentication.SecurityAccessInterceptor;
 import net.sourceforge.plantuml.security.authentication.SecurityAuthentication;
 import net.sourceforge.plantuml.security.authentication.SecurityCredentials;
+//::uncomment when __CORE__
+//import net.sourceforge.plantuml.FileUtils;
+//::done
 
 /**
  * Secure replacement for java.net.URL.
@@ -84,11 +89,11 @@ import net.sourceforge.plantuml.security.authentication.SecurityCredentials;
  * host.
  * <p>
  * Example:<br/>
- * 
+ *
  * <pre>
  *     SURL url = SURL.create ("https://jenkins-access@jenkins.mycompany.com/api/json")
  * </pre>
- * 
+ *
  * The {@code jenkins-access} will checked against the Security context access
  * token configuration. If a configuration exists for this token name, the token
  * will be removed from the URL and the credentials will be added to the
@@ -108,21 +113,6 @@ public class SURL {
 	 */
 	public static final String WITHOUT_AUTHENTICATION = SecurityUtils.NO_CREDENTIALS;
 
-	/**
-	 * Regex to remove the UserInfo part from a URL.
-	 */
-	private static final Pattern PATTERN_USERINFO = Pattern.compile("(^https?://)([-_0-9a-zA-Z]+@)([^@]*)");
-
-	private static final ExecutorService EXE = Executors.newCachedThreadPool(new ThreadFactory() {
-		public Thread newThread(Runnable r) {
-			final Thread t = Executors.defaultThreadFactory().newThread(r);
-			t.setDaemon(true);
-			return t;
-		}
-	});
-
-	private static final Map<String, Long> BAD_HOSTS = new ConcurrentHashMap<String, Long>();
-
 	/**
 	 * Internal URL, maybe cleaned from user-token.
 	 */
@@ -143,7 +133,7 @@ public class SURL {
 	 * <p>
 	 * The url must be http or https. Return null in case of error or if
 	 * <code>url</code> is null
-	 * 
+	 *
 	 * @param url plain url starting by http:// or https//
 	 * @return the secure URL or null
 	 */
@@ -153,8 +143,8 @@ public class SURL {
 
 		if (url.startsWith("http://") || url.startsWith("https://"))
 			try {
-				return create(new URL(url));
-			} catch (MalformedURLException e) {
+				return create(new URI(url).toURL());
+			} catch (MalformedURLException | URISyntaxException e) {
 				Logme.error(e);
 			}
 		return null;
@@ -164,15 +154,17 @@ public class SURL {
 	 * Create a secure URL from a <code>java.net.URL</code> object.
 	 * <p>
 	 * It takes into account credentials.
-	 * 
+	 *
 	 * @param url
 	 * @return the secure URL
 	 * @throws MalformedURLException if <code>url</code> is null
+	 * @throws URISyntaxException
 	 */
-	public static SURL create(URL url) throws MalformedURLException {
+	public static SURL create(URL url) throws MalformedURLException, URISyntaxException {
 		if (url == null)
 			throw new MalformedURLException("URL cannot be null");
 
+		// ::comment when __CORE__
 		final String credentialId = url.getUserInfo();
 
 		if (credentialId == null || credentialId.indexOf(':') > 0)
@@ -183,17 +175,108 @@ public class SURL {
 			// Given userInfo, but without a password. We try to find SecurityCredentials
 			return new SURL(removeUserInfo(url), credentialId);
 		else
+			// ::done
 			return new SURL(url, WITHOUT_AUTHENTICATION);
 	}
 
+	// ::uncomment when __CORE__
+//	public InputStream openStream() {
+//	try {
+//		return internal.openStream();
+//	} catch (IOException e) {
+//		System.err.println("SURL::openStream " + e);
+//		return null;
+//	}
+//}
+//public byte[] getBytes() {
+//	final InputStream is = openStream();
+//	if (is != null)
+//		try {
+//			final ByteArrayOutputStream baos = new ByteArrayOutputStream();
+//			FileUtils.copyInternal(is, baos, true);
+//			return baos.toByteArray();
+//		} catch (IOException e) {
+//			System.err.println("SURL::getBytes " + e);
+//		}
+//	return null;
+//}
+	// ::done
+
+	public BufferedImage readRasterImageFromURL() {
+		if (isUrlOk())
+			try {
+				final byte[] bytes = getBytes();
+				if (bytes == null || bytes.length == 0)
+					return null;
+				final ImageIcon tmp = new ImageIcon(bytes);
+				return SecurityUtils.readRasterImage(tmp);
+			} catch (Exception e) {
+				Logme.error(e);
+			}
+		return null;
+	}
+
+	/**
+	 * Check SecurityProfile to see if this URL can be opened.
+	 */
+	public boolean isUrlOk() {
+		// ::comment when __CORE__
+		if (SecurityUtils.getSecurityProfile() == SecurityProfile.SANDBOX)
+			// In SANDBOX, we cannot read any URL
+			return false;
+
+		if (isInUrlAllowList())
+			// ::done
+			return true;
+		// ::comment when __CORE__
+
+		if (SecurityUtils.getSecurityProfile() == SecurityProfile.LEGACY) {
+			if (URLCheck.isURLforbidden(cleanPath(internal.toString())))
+				return false;
+			return true;
+		}
+
+		if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE)
+			// We are UNSECURE anyway
+			return true;
+
+		if (SecurityUtils.getSecurityProfile() == SecurityProfile.INTERNET) {
+			if (URLCheck.isURLforbidden(cleanPath(internal.toString())))
+				return false;
+
+			final int port = internal.getPort();
+			// Using INTERNET profile, port 80 and 443 are ok
+			return port == 80 || port == 443 || port == -1;
+		}
+		return false;
+		// ::done
+	}
+
+	// ::comment when __CORE__
+	/**
+	 * Regex to remove the UserInfo part from a URL.
+	 */
+	private static final Pattern PATTERN_USERINFO = Pattern.compile("(^https?://)([-_0-9a-zA-Z]+@)([^@]*)$");
+
+	private static final ExecutorService EXE = Executors.newCachedThreadPool(new ThreadFactory() {
+		public Thread newThread(Runnable r) {
+			final Thread t = Executors.defaultThreadFactory().newThread(r);
+			t.setDaemon(true);
+			return t;
+		}
+	});
+
+	private static final Map<String, Long> BAD_HOSTS = new ConcurrentHashMap<String, Long>();
+
 	/**
 	 * Creates a URL without UserInfo part and without SecurityCredentials.
 	 *
 	 * @param url plain URL
 	 * @return SURL without any user credential information.
 	 * @throws MalformedURLException
+	 * @throws URISyntaxException
 	 */
-	static SURL createWithoutUser(URL url) throws MalformedURLException {
+	static SURL createWithoutUser(URL url) throws MalformedURLException, URISyntaxException {
 		return new SURL(removeUserInfo(url), WITHOUT_AUTHENTICATION);
 	}
 
@@ -215,45 +298,11 @@ public class SURL {
 		return internal.toString();
 	}
 
-	/**
-	 * Check SecurityProfile to see if this URL can be opened.
-	 */
-	private boolean isUrlOk() {
-		if (SecurityUtils.getSecurityProfile() == SecurityProfile.SANDBOX)
-			// In SANDBOX, we cannot read any URL
-			return false;
-
-		if (SecurityUtils.getSecurityProfile() == SecurityProfile.LEGACY)
-			return true;
-
-		if (SecurityUtils.getSecurityProfile() == SecurityProfile.UNSECURE)
-			// We are UNSECURE anyway
-			return true;
-
-		if (isInUrlAllowList())
-			return true;
-
-		if (SecurityUtils.getSecurityProfile() == SecurityProfile.INTERNET) {
-			if (forbiddenURL(cleanPath(internal.toString())))
-				return false;
-
-			final int port = internal.getPort();
-			// Using INTERNET profile, port 80 and 443 are ok
-			return port == 80 || port == 443 || port == -1;
-		}
-		return false;
-	}
-
-	private boolean forbiddenURL(String full) {
-		if (full.matches("^https?://[-#.0-9:\\[\\]+]+/.*"))
-			return true;
-		if (full.matches("^https?://[^.]+/.*"))
-			return true;
-		return false;
-	}
-
 	private boolean isInUrlAllowList() {
 		final String full = cleanPath(internal.toString());
+		// Thanks to Agasthya Kasturi
+		if (full.contains("@"))
+			return false;
 		for (String allow : getUrlAllowList())
 			if (full.startsWith(cleanPath(allow)))
 				return true;
@@ -398,9 +447,32 @@ public class SURL {
 		}
 	}
 
+    /**
+     * Configures the specified {@link URLConnection} with security-related settings.
+     * <p>
+     * This method disables user interactions for the connection and, if the connection 
+     * is an instance of {@link HttpURLConnection}, it also disables automatic 
+     * following of HTTP redirects, unless the security profile is set to 
+     * {@link SecurityProfile#UNSECURE}.
+     * </p>
+     *
+     * @param connection the {@link URLConnection} to be configured
+     *
+     * @see URLConnection#setAllowUserInteraction(boolean)
+     * @see HttpURLConnection#setInstanceFollowRedirects(boolean)
+     * @see SecurityUtils#getSecurityProfile()
+     * @see SecurityProfile
+     */
+	protected static void configure(URLConnection connection) {
+		connection.setAllowUserInteraction(false);
+
+		if (SecurityUtils.getSecurityProfile() != SecurityProfile.UNSECURE && connection instanceof HttpURLConnection)
+			((HttpURLConnection) connection).setInstanceFollowRedirects(false);
+	}
+
 	/**
 	 * Creates a GET request and response handler
-	 * 
+	 *
 	 * @param url            URL to request
 	 * @param proxy          proxy to apply
 	 * @param authentication the authentication to use
@@ -416,6 +488,7 @@ public class SURL {
 				final URLConnection connection = proxy == null ? url.openConnection() : url.openConnection(proxy);
 				if (connection == null)
 					return null;
+				configure(connection);
 
 				final HttpURLConnection http = (HttpURLConnection) connection;
 
@@ -424,15 +497,15 @@ public class SURL {
 				return http;
 			}
 
-			public byte[] call() throws IOException {
-				HttpURLConnection http = openConnection(url);
-				final int responseCode = http.getResponseCode();
+			public byte[] call() throws IOException, URISyntaxException {
+				final HttpURLConnection http = openConnection(url);
+				// final int responseCode = http.getResponseCode();
 
-				if (responseCode == HttpURLConnection.HTTP_MOVED_TEMP
-						|| responseCode == HttpURLConnection.HTTP_MOVED_PERM) {
-					final String newUrl = http.getHeaderField("Location");
-					http = openConnection(new URL(newUrl));
-				}
+//				if (responseCode == HttpURLConnection.HTTP_MOVED_TEMP
+//						|| responseCode == HttpURLConnection.HTTP_MOVED_PERM) {
+//					final String newUrl = http.getHeaderField("Location");
+//					http = openConnection(new URI(newUrl).toURL());
+//				}
 
 				return retrieveResponseAsBytes(http);
 			}
@@ -444,7 +517,7 @@ public class SURL {
 	 * content will be identified as form or JSON data. The charset encoding can be
 	 * set by header parameters or will be set to UTF-8. The method to some fancy
 	 * logic to simplify it for the user.
-	 * 
+	 *
 	 * @param url            URL to request via POST method
 	 * @param proxy          proxy to apply
 	 * @param authentication the authentication to use
@@ -460,6 +533,7 @@ public class SURL {
 				if (connection == null)
 					return null;
 
+				configure(connection);
 				final boolean withContent = StringUtils.isNotEmpty(data);
 
 				final HttpURLConnection http = (HttpURLConnection) connection;
@@ -520,7 +594,7 @@ public class SURL {
 
 	/**
 	 * Reads data in a byte[] array.
-	 * 
+	 *
 	 * @param input input stream
 	 * @return byte data
 	 * @throws IOException if something went wrong
@@ -538,7 +612,7 @@ public class SURL {
 
 	/**
 	 * Sends a request content payload to an endpoint.
-	 * 
+	 *
 	 * @param connection HTTP connection
 	 * @param data       data as byte array
 	 * @throws IOException if something went wrong
@@ -560,20 +634,6 @@ public class SURL {
 		return null;
 	}
 
-	public BufferedImage readRasterImageFromURL() {
-		if (isUrlOk())
-			try {
-				final byte[] bytes = getBytes();
-				if (bytes == null || bytes.length == 0)
-					return null;
-				final ImageIcon tmp = new ImageIcon(bytes);
-				return SecurityUtils.readRasterImage(tmp);
-			} catch (Exception e) {
-				Logme.error(e);
-			}
-		return null;
-	}
-
 	/**
 	 * Informs, if SecurityCredentials are configured for this connection.
 	 *
@@ -610,7 +670,7 @@ public class SURL {
 
 	/**
 	 * Set the headers for a URL connection
-	 * 
+	 *
 	 * @param headers map Keys with values (can be String or list of String)
 	 */
 	private static void applyAdditionalHeaders(URLConnection http, Map<String, Object> headers) {
@@ -632,19 +692,20 @@ public class SURL {
 	/**
 	 * Removes the userInfo part from the URL, because we want to use the
 	 * SecurityCredentials instead.
-	 * 
+	 *
 	 * @param url URL with UserInfo part
 	 * @return url without UserInfo part
 	 * @throws MalformedURLException
+	 * @throws URISyntaxException
 	 */
-	private static URL removeUserInfo(URL url) throws MalformedURLException {
-		return new URL(removeUserInfoFromUrlPath(url.toExternalForm()));
+	private static URL removeUserInfo(URL url) throws MalformedURLException, URISyntaxException {
+		return new URI(removeUserInfoFromUrlPath(url.toExternalForm())).toURL();
 	}
 
 	/**
 	 * Removes the userInfo part from the URL, because we want to use the
 	 * SecurityCredentials instead.
-	 * 
+	 *
 	 * @param url URL with UserInfo part
 	 * @return url without UserInfo part
 	 */
@@ -656,4 +717,5 @@ public class SURL {
 
 		return url;
 	}
+	// ::done
 }
