@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -37,13 +37,14 @@ package net.sourceforge.plantuml.sequencediagram;
 
 import java.util.ArrayList;
 import java.util.List;
+import java.util.Map;
 import java.util.Objects;
 
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.PaddingParam;
-import net.sourceforge.plantuml.SkinParamBackcolored;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
 import net.sourceforge.plantuml.real.Real;
 import net.sourceforge.plantuml.sequencediagram.teoz.LivingSpace;
 import net.sourceforge.plantuml.sequencediagram.teoz.TileArguments;
@@ -51,30 +52,34 @@ import net.sourceforge.plantuml.skin.Area;
 import net.sourceforge.plantuml.skin.Component;
 import net.sourceforge.plantuml.skin.ComponentType;
 import net.sourceforge.plantuml.skin.Context2D;
+import net.sourceforge.plantuml.skin.PaddingParam;
+import net.sourceforge.plantuml.skin.SkinParamBackcolored;
 import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.style.WithStyle;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class Doll implements WithStyle {
 
 	final private List<Participant> participants = new ArrayList<>();
+	// alls is only used for Teoz: refactor needed after puma will be removed
+	final private Map<ParticipantEnglober, Doll> alls;
 	final private ParticipantEnglober englober;
 	final private StyleBuilder styleBuilder;
 	final private TileArguments tileArguments;
 
 	public static Doll createPuma(ParticipantEnglober englober, Participant first, ISkinParam skinParam, Rose skin,
 			StringBounder stringBounder, StyleBuilder styleBuilder) {
-		return new Doll(englober, convertFunctionToBeRemoved(skinParam, skin, stringBounder), styleBuilder, first);
+		return new Doll(englober, convertFunctionToBeRemoved(skinParam, skin, stringBounder), styleBuilder, first,
+				null);
 	}
 
-	public static Doll createTeoz(ParticipantEnglober englober, TileArguments tileArguments) {
-		return new Doll(englober, tileArguments, tileArguments.getSkinParam().getCurrentStyleBuilder(), null);
+	public static Doll createTeoz(ParticipantEnglober englober, TileArguments tileArguments,
+			Map<ParticipantEnglober, Doll> alls) {
+		return new Doll(englober, tileArguments, tileArguments.getSkinParam().getCurrentStyleBuilder(), null, alls);
 	}
 
 	private static TileArguments convertFunctionToBeRemoved(ISkinParam skinParam, Rose skin,
@@ -83,10 +88,11 @@ public class Doll implements WithStyle {
 	}
 
 	private Doll(ParticipantEnglober englober, TileArguments tileArguments, StyleBuilder styleBuilder,
-			Participant first) {
+			Participant first, Map<ParticipantEnglober, Doll> alls) {
 		this.englober = Objects.requireNonNull(englober);
 		this.styleBuilder = styleBuilder;
 		this.tileArguments = Objects.requireNonNull(tileArguments);
+		this.alls = alls;
 
 		if (first != null)
 			this.participants.add(first);
@@ -186,8 +192,8 @@ public class Doll implements WithStyle {
 		final double x1 = getPosA(stringBounder).getCurrentValue() - 4;
 		final double x2 = getPosE(stringBounder).getCurrentValue() + 4;
 
-		if (group != null) {
-			final double titlePreferredHeight = group.getTitlePreferredHeight();
+		for (Doll current = group; current != null; current = current.getParent()) {
+			final double titlePreferredHeight = current.getTitlePreferredHeight();
 			ug = ug.apply(UTranslate.dy(titlePreferredHeight));
 			height -= titlePreferredHeight;
 		}
@@ -196,6 +202,13 @@ public class Doll implements WithStyle {
 		getComponent().drawU(ug.apply(new UTranslate(x1, 1)), new Area(dim), context);
 	}
 
+	public Doll getParent() {
+		final ParticipantEnglober parent = getParticipantEnglober().getParent();
+		if (parent == null)
+			return null;
+		return alls.get(parent);
+	}
+
 	public void addInternalConstraints(StringBounder stringBounder) {
 		final double titleWidth = getTitleWidth();
 		final double x1 = getPosB(stringBounder).getCurrentValue();
