@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,15 +35,15 @@
  */
 package net.sourceforge.plantuml.sequencediagram;
 
-import net.sourceforge.plantuml.graphic.SymbolContext;
+import net.sourceforge.plantuml.klimt.Fashion;
 
 public class LifeEvent extends AbstractEvent implements Event {
 
 	private final Participant p;
 	private final LifeEventType type;
-	private final SymbolContext backcolor;
+	private final Fashion backcolor;
 
-	public LifeEvent(Participant p, LifeEventType type, SymbolContext backcolor) {
+	public LifeEvent(Participant p, LifeEventType type, Fashion backcolor) {
 		this.p = p;
 		this.type = type;
 		this.backcolor = backcolor;
@@ -62,7 +62,7 @@ public class LifeEvent extends AbstractEvent implements Event {
 		return type;
 	}
 
-	public SymbolContext getSpecificColors() {
+	public Fashion getSpecificColors() {
 		return backcolor;
 	}
 
