@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -37,16 +37,16 @@ package net.sourceforge.plantuml.sequencediagram;
 
 import java.util.List;
 
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.SpecificBackcolorable;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.abel.SpecificBackcolorable;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.style.WithStyle;
+import net.sourceforge.plantuml.url.Url;
 
 final public class Note extends AbstractEvent implements Event, SpecificBackcolorable, WithStyle {
 
@@ -58,9 +58,9 @@ final public class Note extends AbstractEvent implements Event, SpecificBackcolo
 	private/* final */NotePosition position;
 
 	public void temporaryProtectedUntilTeozIsStandard() {
-		if (position == NotePosition.BOTTOM || position == NotePosition.TOP) {
+		if (position == NotePosition.BOTTOM || position == NotePosition.TOP)
 			position = NotePosition.LEFT;
-		}
+
 	}
 
 	private final StyleBuilder styleBuilder;
@@ -129,7 +129,7 @@ final public class Note extends AbstractEvent implements Event, SpecificBackcolo
 		return p2;
 	}
 
-	public Display getStrings() {
+	public Display getDisplay() {
 		return strings;
 	}
 
