@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
+ *
+ * Project Info:  https://plantuml.com
  *
- * Project Info:  http://plantuml.com
- * 
  * If you like this project or if you find it useful, you can support us at:
- * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
- * 
+ *
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -48,29 +48,35 @@ import java.util.Objects;
 import java.util.Set;
 import java.util.Stack;
 
-import net.sourceforge.plantuml.ColorParam;
+import net.atmp.ImageBuilder;
 import net.sourceforge.plantuml.FileFormat;
 import net.sourceforge.plantuml.FileFormatOption;
 import net.sourceforge.plantuml.OptionFlags;
+import net.sourceforge.plantuml.Previous;
 import net.sourceforge.plantuml.UmlDiagram;
-import net.sourceforge.plantuml.UmlDiagramType;
+import net.sourceforge.plantuml.abel.EntityPortion;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
 import net.sourceforge.plantuml.core.DiagramDescription;
 import net.sourceforge.plantuml.core.ImageData;
 import net.sourceforge.plantuml.core.UmlSource;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.graphic.SymbolContext;
+import net.sourceforge.plantuml.klimt.Fashion;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
 import net.sourceforge.plantuml.log.Logme;
+import net.sourceforge.plantuml.preproc.PreprocessingArtifact;
 import net.sourceforge.plantuml.sequencediagram.graphic.FileMaker;
 import net.sourceforge.plantuml.sequencediagram.graphic.SequenceDiagramFileMakerPuma2;
 import net.sourceforge.plantuml.sequencediagram.graphic.SequenceDiagramTxtMaker;
 import net.sourceforge.plantuml.sequencediagram.teoz.SequenceDiagramFileMakerTeoz;
+import net.sourceforge.plantuml.skin.ColorParam;
+import net.sourceforge.plantuml.skin.PragmaKey;
+import net.sourceforge.plantuml.skin.UmlDiagramType;
 import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.stereo.Stereotype;
 import net.sourceforge.plantuml.style.ClockwiseTopRightBottomLeft;
-import net.sourceforge.plantuml.ugraphic.ImageBuilder;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.utils.LineLocation;
 import net.sourceforge.plantuml.xmi.SequenceDiagramXmiMaker;
 
 public class SequenceDiagram extends UmlDiagram {
@@ -93,19 +99,19 @@ public class SequenceDiagram extends UmlDiagram {
 
 	private final Rose skin2 = new Rose();
 
-	public SequenceDiagram(UmlSource source, Map<String, String> skinParam) {
-		super(source, UmlDiagramType.SEQUENCE, skinParam);
+	public SequenceDiagram(UmlSource source, Previous previous, PreprocessingArtifact preprocessing) {
+		super(source, UmlDiagramType.SEQUENCE, previous, preprocessing);
 	}
 
 	@Deprecated
-	public Participant getOrCreateParticipant(String code) {
-		return getOrCreateParticipant(code, Display.getWithNewlines(code));
+	public Participant getOrCreateParticipant(LineLocation location, String code) {
+		return getOrCreateParticipant(location, code, Display.getWithNewlines(getPragma(), code));
 	}
 
-	public Participant getOrCreateParticipant(String code, Display display) {
+	public Participant getOrCreateParticipant(LineLocation location, String code, Display display) {
 		Participant result = participantsget(code);
 		if (result == null) {
-			result = new Participant(ParticipantType.PARTICIPANT, code, display, hiddenPortions, 0,
+			result = new Participant(location, ParticipantType.PARTICIPANT, code, display, hiddenPortions, 0,
 					getSkinParam().getCurrentStyleBuilder());
 			addWithOrder(result);
 			participantEnglobers2.put(result, participantEnglober);
@@ -124,18 +130,28 @@ public class SequenceDiagram extends UmlDiagram {
 	private EventWithDeactivate lastEventWithDeactivate;
 
 	public EventWithDeactivate getLastEventWithDeactivate() {
-		return lastEventWithDeactivate;
+		for (int i = events.size() - 1; i >= 0; i--)
+			if (events.get(i) instanceof EventWithDeactivate)
+				return (EventWithDeactivate) events.get(i);
+		return null;
 	}
 
-	public Participant createNewParticipant(ParticipantType type, String code, Display display, int order) {
-		if (participantsget(code) != null) {
+	public EventWithNote getLastEventWithNote() {
+		for (int i = events.size() - 1; i >= 0; i--)
+			if (events.get(i) instanceof EventWithNote)
+				return (EventWithNote) events.get(i);
+		return null;
+	}
+
+	public Participant createNewParticipant(LineLocation location, ParticipantType type, String code, Display display, int order) {
+		if (participantsget(code) != null)
 			throw new IllegalArgumentException();
-		}
+
 		if (Display.isNull(display)) {
 			// display = Arrays.asList(code);
-			display = Display.getWithNewlines(code);
+			display = Display.getWithNewlines(getPragma(), code);
 		}
-		final Participant result = new Participant(type, code, display, hiddenPortions, order,
+		final Participant result = new Participant(location, type, code, display, hiddenPortions, order,
 				getSkinParam().getCurrentStyleBuilder());
 		addWithOrder(result);
 		participantEnglobers2.put(result, participantEnglober);
@@ -179,7 +195,7 @@ public class SequenceDiagram extends UmlDiagram {
 	}
 
 	private AbstractMessage getLastAbstractMessage() {
-		for (int i = events.size() - 1; i > 0; i--)
+		for (int i = events.size() - 1; i >= 0; i--)
 			if (events.get(i) instanceof AbstractMessage)
 				return (AbstractMessage) events.get(i);
 
@@ -253,12 +269,13 @@ public class SequenceDiagram extends UmlDiagram {
 	private FileMaker getSequenceDiagramPngMaker(int index, FileFormatOption fileFormatOption) {
 
 		final FileFormat fileFormat = fileFormatOption.getFileFormat();
-
+		// ::comment when __CORE__
 		if (fileFormat == FileFormat.ATXT || fileFormat == FileFormat.UTXT)
 			return new SequenceDiagramTxtMaker(this, fileFormat);
 
 		if (fileFormat.name().startsWith("XMI"))
 			return new SequenceDiagramXmiMaker(this, fileFormat);
+		// ::done
 
 		if (modeTeoz())
 			return new SequenceDiagramFileMakerTeoz(this, skin2, fileFormatOption, index);
@@ -267,12 +284,14 @@ public class SequenceDiagram extends UmlDiagram {
 	}
 
 	private boolean modeTeoz() {
-		return OptionFlags.FORCE_TEOZ || getPragma().useTeozLayout();
+		return OptionFlags.FORCE_TEOZ || getPragma().isTrue(PragmaKey.TEOZ);
 	}
 
+
+	@Override
 	public ImageBuilder createImageBuilder(FileFormatOption fileFormatOption) throws IOException {
-		return super.createImageBuilder(fileFormatOption).annotations(false); // they are managed in the
-																				// SequenceDiagramFileMaker* classes
+		return super.createImageBuilder(fileFormatOption).annotations(false);
+		// they are managed in the SequenceDiagramFileMaker* classes
 	}
 
 	@Override
@@ -282,6 +301,17 @@ public class SequenceDiagram extends UmlDiagram {
 		return sequenceDiagramPngMaker.createOne(os, index, fileFormat.isWithMetadata());
 	}
 
+	@Override
+	final public void exportDiagramGraphic(UGraphic ug, FileFormatOption fileFormatOption) {
+		final FileMaker sequenceDiagramPngMaker = getSequenceDiagramPngMaker(0, fileFormatOption);
+		sequenceDiagramPngMaker.createOneGraphic(ug);
+	}
+
+	@Override
+	final protected TextBlock getTextMainBlock(FileFormatOption fileFormatOption) {
+		throw new UnsupportedOperationException();
+	}
+
 	// support for CommandReturn
 	private final Stack<AbstractMessage> activationState = new Stack<>();
 
@@ -302,7 +332,7 @@ public class SequenceDiagram extends UmlDiagram {
 		if (lastDelay != null)
 			return "You cannot Activate/Deactivate just after a ...";
 
-		final LifeEvent lifeEvent = new LifeEvent(p, lifeEventType, new SymbolContext(backcolor, linecolor));
+		final LifeEvent lifeEvent = new LifeEvent(p, lifeEventType, new Fashion(backcolor, linecolor));
 		events.add(lifeEvent);
 		if (lifeEventType == LifeEventType.CREATE) {
 			pendingCreate = lifeEvent;
@@ -310,7 +340,7 @@ public class SequenceDiagram extends UmlDiagram {
 		}
 		if (lastEventWithDeactivate == null) {
 			if (lifeEventType == LifeEventType.ACTIVATE) {
-				p.incInitialLife(new SymbolContext(backcolor, linecolor));
+				p.incInitialLife(new Fashion(backcolor, linecolor));
 				return null;
 			}
 			if (p.getInitialLife() == 0)
@@ -440,13 +470,17 @@ public class SequenceDiagram extends UmlDiagram {
 
 	@Override
 	public int getNbImages() {
+		// ::comment when __CORE__
 		try {
 			// The DEBUG StringBounder is ok just to compute the number of pages here.
 			return getSequenceDiagramPngMaker(1, new FileFormatOption(FileFormat.DEBUG)).getNbPages();
 		} catch (Throwable t) {
 			Logme.error(t);
+			// ::done
 			return 1;
+			// ::comment when __CORE__
 		}
+		// ::done
 	}
 
 	public void removeHiddenParticipants() {
