@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -40,23 +40,22 @@ import java.util.Collections;
 import java.util.List;
 import java.util.StringTokenizer;
 
-import net.sourceforge.plantuml.LineLocation;
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.UrlBuilder;
-import net.sourceforge.plantuml.UrlMode;
 import net.sourceforge.plantuml.classdiagram.command.CommandLinkClass;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexOptional;
-import net.sourceforge.plantuml.command.regex.RegexOr;
-import net.sourceforge.plantuml.command.regex.RegexResult;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
 import net.sourceforge.plantuml.descdiagram.command.CommandLinkElement;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.color.NoSuchColorException;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexOptional;
+import net.sourceforge.plantuml.regex.RegexOr;
+import net.sourceforge.plantuml.regex.RegexResult;
 import net.sourceforge.plantuml.sequencediagram.LifeEventType;
 import net.sourceforge.plantuml.sequencediagram.Message;
 import net.sourceforge.plantuml.sequencediagram.Participant;
@@ -66,9 +65,12 @@ import net.sourceforge.plantuml.skin.ArrowConfiguration;
 import net.sourceforge.plantuml.skin.ArrowDecoration;
 import net.sourceforge.plantuml.skin.ArrowHead;
 import net.sourceforge.plantuml.skin.ArrowPart;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
-import net.sourceforge.plantuml.ugraphic.color.NoSuchColorException;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.stereo.StereotypePattern;
+import net.sourceforge.plantuml.url.Url;
+import net.sourceforge.plantuml.url.UrlBuilder;
+import net.sourceforge.plantuml.url.UrlMode;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 
@@ -123,16 +125,14 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 				new RegexLeaf("ACTIVATION", "(?:(\\+\\+|\\*\\*|!!|--|--\\+\\+|\\+\\+--)?)"), //
 				RegexLeaf.spaceZeroOrMore(), //
 				new RegexLeaf("LIFECOLOR", "(?:(#\\w+)?)"), //
-				RegexLeaf.spaceZeroOrMore(), //
-				new RegexLeaf("STEREOTYPE", "(\\<\\<.*\\>\\>)?"), //
-				RegexLeaf.spaceZeroOrMore(), //
-				new RegexLeaf("URL", "(" + UrlBuilder.getRegexp() + ")?"), //
+				StereotypePattern.optional("STEREOTYPE"), //
+				UrlBuilder.OPTIONAL, //
 				RegexLeaf.spaceZeroOrMore(), //
 				new RegexLeaf("MESSAGE", "(?::[%s]*(.*))?"), //
 				RegexLeaf.end()).protectSize(2000);
 	}
 
-	private List<Participant> getMulticasts(SequenceDiagram system, RegexResult arg2) {
+	private List<Participant> getMulticasts(LineLocation location, SequenceDiagram system, RegexResult arg2) {
 		final String multicast = arg2.get("MULTICAST", 0);
 		if (multicast != null) {
 			final List<Participant> result = new ArrayList<>();
@@ -141,7 +141,7 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 				if (s.length() == 0)
 					continue;
 
-				final Participant participant = system.getOrCreateParticipant(s);
+				final Participant participant = system.getOrCreateParticipant(location, s);
 				if (participant != null)
 					result.add(participant);
 
@@ -151,26 +151,26 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 		return Collections.emptyList();
 	}
 
-	private Participant getOrCreateParticipant(SequenceDiagram system, RegexResult arg2, String n) {
+	private Participant getOrCreateParticipant(LineLocation location, SequenceDiagram system, RegexResult arg2, String n) {
 		final String code;
 		final Display display;
 		if (arg2.get(n + "CODE", 0) != null) {
 			code = arg2.get(n + "CODE", 0);
-			display = Display.getWithNewlines(code);
+			display = Display.getWithNewlines(system.getPragma(), code);
 		} else if (arg2.get(n + "LONG", 0) != null) {
 			code = arg2.get(n + "LONG", 0);
-			display = Display.getWithNewlines(code);
+			display = Display.getWithNewlines(system.getPragma(), code);
 		} else if (arg2.get(n + "LONGCODE", 0) != null) {
-			display = Display.getWithNewlines(arg2.get(n + "LONGCODE", 0));
+			display = Display.getWithNewlines(system.getPragma(), arg2.get(n + "LONGCODE", 0));
 			code = arg2.get(n + "LONGCODE", 1);
 		} else if (arg2.get(n + "CODELONG", 0) != null) {
 			code = arg2.get(n + "CODELONG", 0);
-			display = Display.getWithNewlines(arg2.get(n + "CODELONG", 1));
-			return system.getOrCreateParticipant(code, display);
+			display = Display.getWithNewlines(system.getPragma(), arg2.get(n + "CODELONG", 1));
+			return system.getOrCreateParticipant(location, code, display);
 		} else {
 			throw new IllegalStateException();
 		}
-		return system.getOrCreateParticipant(code, display);
+		return system.getOrCreateParticipant(location, code, display);
 	}
 
 	private boolean contains(String string, String... totest) {
@@ -201,41 +201,53 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(SequenceDiagram diagram, LineLocation location, RegexResult arg)
+	protected CommandExecutionResult executeArg(SequenceDiagram diagram, LineLocation location, RegexResult arg, ParserPass currentPass)
 			throws NoSuchColorException {
 
-		Participant p1;
-		Participant p2;
-
 		final String dressing1 = getDressing(arg, "ARROW_DRESSING1");
 		final String dressing2 = getDressing(arg, "ARROW_DRESSING2");
 		final int inclination1 = getInclination(arg.get("ARROW_DRESSING1", 0));
 		final int inclination2 = getInclination(arg.get("ARROW_DRESSING2", 0));
 
-		final boolean circleAtStart;
-		final boolean circleAtEnd;
-
-		final boolean hasDressing2 = contains(dressing2, ">", "\\", "/", "x");
-		final boolean hasDressing1 = contains(dressing1, "x", "<", "\\", "/");
+		// Sorry, this code is note very clear
+		final boolean hasDressing1butx = contains(dressing1, "<", "\\", "/");
+		final boolean xInDressing1 = dressing1.contains("x");
+		final boolean hasDressing2butx = contains(dressing2, ">", "\\", "/");
+		final boolean xInDressing2 = dressing2.contains("x");
 		final boolean reverseDefine;
-		if (hasDressing2) {
-			p1 = getOrCreateParticipant(diagram, arg, "PART1");
-			p2 = getOrCreateParticipant(diagram, arg, "PART2");
-			circleAtStart = dressing1.contains("o");
-			circleAtEnd = dressing2.contains("o");
+		if (hasDressing2butx || (xInDressing1 && xInDressing2))
 			reverseDefine = false;
-		} else if (hasDressing1) {
-			p2 = getOrCreateParticipant(diagram, arg, "PART1");
-			p1 = getOrCreateParticipant(diagram, arg, "PART2");
-			circleAtStart = dressing2.contains("o");
-			circleAtEnd = dressing1.contains("o");
+		else if (hasDressing1butx)
 			reverseDefine = true;
-		} else {
+		else if (xInDressing1 || xInDressing2)
+			reverseDefine = false;
+		else
 			return CommandExecutionResult.error("Illegal sequence arrow");
 
+		final Participant p1;
+		final Participant p2;
+		final boolean circleAtStart;
+		final boolean circleAtEnd;
+		final boolean sync1;
+		final boolean sync2;
+		if (reverseDefine) {
+			// Keep the order
+			// See https://github.com/plantuml/plantuml/issues/1819#issuecomment-2158524871
+			p2 = getOrCreateParticipant(location, diagram, arg, "PART1");
+			p1 = getOrCreateParticipant(location, diagram, arg, "PART2");
+			circleAtStart = dressing2.contains("o");
+			circleAtEnd = dressing1.contains("o");
+			sync2 = contains(dressing1, "<<", "\\\\", "//");
+			sync1 = contains(dressing2, ">>", "\\\\", "//");
+		} else {
+			p1 = getOrCreateParticipant(location, diagram, arg, "PART1");
+			p2 = getOrCreateParticipant(location, diagram, arg, "PART2");
+			circleAtStart = dressing1.contains("o");
+			circleAtEnd = dressing2.contains("o");
+			sync1 = contains(dressing1, "<<", "\\\\", "//");
+			sync2 = contains(dressing2, ">>", "\\\\", "//");
 		}
 
-		final boolean sync = contains(dressing1, "<<", "\\\\", "//") || contains(dressing2, ">>", "\\\\", "//");
 
 		final boolean dotted = getLength(arg) > 1;
 
@@ -245,16 +257,18 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 		} else {
 			// final String message = UrlBuilder.multilineTooltip(arg.get("MESSAGE", 0));
 			final String message = arg.get("MESSAGE", 0);
-			labels = Display.getWithNewlines(message);
+			labels = Display.getWithNewlines(diagram.getPragma(), message);
 		}
 
-		ArrowConfiguration config = hasDressing1 && hasDressing2 ? ArrowConfiguration.withDirectionBoth()
+		ArrowConfiguration config = hasDressing1butx && hasDressing2butx ? ArrowConfiguration.withDirectionBoth()
 				: ArrowConfiguration.withDirectionNormal();
 		if (dotted)
 			config = config.withBody(ArrowBody.DOTTED);
 
-		if (sync)
-			config = config.withHead(ArrowHead.ASYNC);
+		if (sync1)
+			config = config.withHead1(ArrowHead.ASYNC);
+		if (sync2)
+			config = config.withHead2(ArrowHead.ASYNC);
 
 		if (dressing2.contains("\\") || dressing1.contains("/"))
 			config = config.withPart(ArrowPart.TOP_PART);
@@ -269,17 +283,17 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 			config = config.withDecoration1(ArrowDecoration.CIRCLE);
 
 		if (reverseDefine) {
-			if (dressing1.contains("x"))
+			if (xInDressing1)
 				config = config.withHead2(ArrowHead.CROSSX);
 
-			if (dressing2.contains("x"))
+			if (xInDressing2)
 				config = config.withHead1(ArrowHead.CROSSX);
 
 		} else {
-			if (dressing1.contains("x"))
+			if (xInDressing1)
 				config = config.withHead1(ArrowHead.CROSSX);
 
-			if (dressing2.contains("x"))
+			if (xInDressing2)
 				config = config.withHead2(ArrowHead.CROSSX);
 
 		}
@@ -298,7 +312,7 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 		final String messageNumber = diagram.getNextMessageNumber();
 		final Message msg = new Message(diagram.getSkinParam().getCurrentStyleBuilder(), p1, p2,
 				diagram.manageVariable(labels), config, messageNumber);
-		msg.setMulticast(getMulticasts(diagram, arg));
+		msg.setMulticast(getMulticasts(location, diagram, arg));
 		final String url = arg.get("URL", 0);
 		if (url != null) {
 			final UrlBuilder urlBuilder = new UrlBuilder(diagram.getSkinParam().getValue("topurl"), UrlMode.STRICT);
@@ -325,8 +339,7 @@ public class CommandArrow extends SingleLineCommand2<SequenceDiagram> {
 
 		final String s = arg.get("LIFECOLOR", 0);
 
-		final HColor activationColor = s == null ? null
-				: diagram.getSkinParam().getIHtmlColorSet().getColor(s);
+		final HColor activationColor = s == null ? null : diagram.getSkinParam().getIHtmlColorSet().getColor(s);
 
 		if (activationSpec != null)
 			return manageActivations(activationSpec, diagram, p1, p2, activationColor);
