@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,13 +35,17 @@
  */
 package net.sourceforge.plantuml.sequencediagram.graphic;
 
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.graphic.StringBounder;
+import java.util.EnumMap;
+import java.util.Map;
+
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
 import net.sourceforge.plantuml.sequencediagram.InGroupable;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.skin.ArrowComponent;
 import net.sourceforge.plantuml.skin.rose.Rose;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
+import net.sourceforge.plantuml.url.Url;
 
 abstract class Arrow extends GraphicalElement implements InGroupable {
 
@@ -52,9 +56,9 @@ abstract class Arrow extends GraphicalElement implements InGroupable {
 	private final Url url;
 
 	public void setMaxX(double m) {
-		if (maxX != 0) {
+		if (maxX != 0)
 			throw new IllegalStateException();
-		}
+
 		this.maxX = m;
 	}
 
@@ -78,16 +82,28 @@ abstract class Arrow extends GraphicalElement implements InGroupable {
 		return url;
 	}
 
+	protected final void startGroup(UGraphic ug) {
+		final Map<UGroupType, String> typeIdents = new EnumMap<>(UGroupType.class);
+		typeIdents.put(UGroupType.CLASS, "message");
+		typeIdents.put(UGroupType.DATA_PARTICIPANT_1, getParticipant1Code());
+		typeIdents.put(UGroupType.DATA_PARTICIPANT_2, getParticipant2Code());
+		ug.startGroup(typeIdents);
+	}
+
+	protected final void endGroup(UGraphic ug) {
+		ug.closeGroup();
+	}
+
 	protected final void startUrl(UGraphic ug) {
-		if (url != null) {
+		if (url != null)
 			ug.startUrl(url);
-		}
+
 	}
 
 	protected final void endUrl(UGraphic ug) {
-		if (url != null) {
+		if (url != null)
 			ug.closeUrl();
-		}
+
 	}
 
 	public abstract int getDirection(StringBounder stringBounder);
@@ -110,6 +126,10 @@ abstract class Arrow extends GraphicalElement implements InGroupable {
 
 	public abstract LivingParticipantBox getParticipantAt(StringBounder stringBounder, NotePosition position);
 
+	protected abstract String getParticipant1Code();
+
+	protected abstract String getParticipant2Code();
+
 	protected final double getPaddingArrowHead() {
 		return paddingArrowHead;
 	}
