@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,12 +35,12 @@
  */
 package net.sourceforge.plantuml.sequencediagram.graphic;
 
-import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
 import net.sourceforge.plantuml.sequencediagram.InGroupable;
 import net.sourceforge.plantuml.sequencediagram.NotePosition;
 import net.sourceforge.plantuml.skin.Context2D;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
 
 class ArrowAndParticipant extends Arrow implements InGroupable {
 
@@ -88,6 +88,16 @@ class ArrowAndParticipant extends Arrow implements InGroupable {
 		return arrow.getParticipantAt(stringBounder, position);
 	}
 
+	@Override
+	protected String getParticipant1Code() {
+		return arrow.getParticipant1Code();
+	}
+
+	@Override
+	protected String getParticipant2Code() {
+		return arrow.getParticipant2Code();
+	}
+
 	@Override
 	protected void drawInternalU(final UGraphic ug, double maxX, Context2D context) {
 		final double participantBoxStartingX = participantBox.getStartingX();
