@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,29 +35,37 @@
  */
 package net.sourceforge.plantuml.skin.rose;
 
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.SymbolContext;
+import net.sourceforge.plantuml.klimt.Fashion;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.ULine;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
 import net.sourceforge.plantuml.skin.AbstractComponent;
 import net.sourceforge.plantuml.skin.Area;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
+
+import static java.util.Collections.singletonMap;
 
 public class ComponentRoseActiveLine extends AbstractComponent {
 
-	private final SymbolContext symbolContext;
+	private final Fashion symbolContext;
 	private final boolean closeUp;
 	private final boolean closeDown;
+    private final Display stringsToDisplay;
 
-	public ComponentRoseActiveLine(Style style, boolean closeUp, boolean closeDown, HColorSet set) {
+    public ComponentRoseActiveLine(Style style, boolean closeUp, boolean closeDown, HColorSet set, Display stringsToDisplay) {
 		super(style);
-		this.symbolContext = style.getSymbolContext(set);
+        this.symbolContext = style.getSymbolContext(set);
 		this.closeUp = closeUp;
 		this.closeDown = closeDown;
+		// Ideally, stringsToDisplay should never be null. However, as a safeguard, 
+		// we default to Display.NULL when it is null.
+		this.stringsToDisplay = stringsToDisplay == null ? Display.NULL : stringsToDisplay;
 	}
 
 	protected void drawInternalU(UGraphic ug, Area area) {
@@ -69,29 +77,33 @@ public class ComponentRoseActiveLine extends AbstractComponent {
 			return;
 		}
 
-		final URectangle rect = new URectangle(getPreferredWidth(stringBounder), dimensionToUse.getHeight());
+		ug.startGroup(singletonMap(UGroupType.TITLE, stringsToDisplay.toTooltipText()));
+
+		final URectangle rect = URectangle.build(getPreferredWidth(stringBounder), dimensionToUse.getHeight());
 		if (symbolContext.isShadowing()) {
 			rect.setDeltaShadow(1);
 		}
 		ug = ug.apply(symbolContext.getForeColor());
 		if (closeUp && closeDown) {
 			ug.apply(symbolContext.getBackColor().bg()).apply(UTranslate.dx(x)).draw(rect);
-			return;
-		}
-		ug.apply(symbolContext.getBackColor().bg()).apply(symbolContext.getBackColor()).apply(UTranslate.dx(x))
-				.draw(rect);
+		} else {
+			ug.apply(symbolContext.getBackColor().bg()).apply(symbolContext.getBackColor()).apply(UTranslate.dx(x))
+					.draw(rect);
 
-		final ULine vline = ULine.vline(dimensionToUse.getHeight());
-		ug.apply(UTranslate.dx(x)).draw(vline);
-		ug.apply(UTranslate.dx(x + getPreferredWidth(stringBounder))).draw(vline);
+			final ULine vline = ULine.vline(dimensionToUse.getHeight());
+			ug.apply(UTranslate.dx(x)).draw(vline);
+			ug.apply(UTranslate.dx(x + getPreferredWidth(stringBounder))).draw(vline);
 
-		final ULine hline = ULine.hline(getPreferredWidth(stringBounder));
-		if (closeUp) {
-			ug.apply(UTranslate.dx(x)).draw(hline);
-		}
-		if (closeDown) {
-			ug.apply(new UTranslate(x, dimensionToUse.getHeight())).draw(hline);
+			final ULine hline = ULine.hline(getPreferredWidth(stringBounder));
+			if (closeUp) {
+				ug.apply(UTranslate.dx(x)).draw(hline);
+			}
+			if (closeDown) {
+				ug.apply(new UTranslate(x, dimensionToUse.getHeight())).draw(hline);
+			}
 		}
+
+		ug.closeGroup();
 	}
 
 	@Override
