@@ -2,15 +2,15 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
+ *
+ * Project Info:  https://plantuml.com
  *
- * Project Info:  http://plantuml.com
- * 
  * If you like this project or if you find it useful, you can support us at:
- * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
- * 
+ *
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
+ *
  * This file is part of PlantUML.
  *
  * PlantUML is free software; you can redistribute it and/or modify it
@@ -30,18 +30,23 @@
  *
  *
  * Original Author:  Arnaud Roques
- * 
+ *
  *
  */
 package net.sourceforge.plantuml.skin.rose;
 
-import net.sourceforge.plantuml.ISkinSimple;
-import net.sourceforge.plantuml.LineBreakStrategy;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.klimt.LineBreakStrategy;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.UEllipse;
+import net.sourceforge.plantuml.klimt.shape.ULine;
+import net.sourceforge.plantuml.klimt.shape.UPolygon;
 import net.sourceforge.plantuml.skin.Area;
 import net.sourceforge.plantuml.skin.ArrowConfiguration;
 import net.sourceforge.plantuml.skin.ArrowDecoration;
@@ -49,13 +54,8 @@ import net.sourceforge.plantuml.skin.ArrowDirection;
 import net.sourceforge.plantuml.skin.ArrowDressing;
 import net.sourceforge.plantuml.skin.ArrowHead;
 import net.sourceforge.plantuml.skin.ArrowPart;
+import net.sourceforge.plantuml.style.ISkinSimple;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.ugraphic.UEllipse;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.UPolygon;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
 
 public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 
@@ -100,21 +100,27 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 		final double pos1 = start + 1;
 		final double pos2 = len - 1;
 
-		if (arrowConfiguration.getDecoration2() == ArrowDecoration.CIRCLE && dressing2.getHead() == ArrowHead.NONE)
-			len -= diamCircle / 2;
+		if (arrowConfiguration.getDecoration2() == ArrowDecoration.CIRCLE) {
+			if (dressing2.getHead() == ArrowHead.NONE)
+				len -= diamCircle / 2;
 
-		if (arrowConfiguration.getDecoration2() == ArrowDecoration.CIRCLE && dressing2.getHead() != ArrowHead.NONE)
-			len -= diamCircle / 2 + thinCircle;
-
-		if (arrowConfiguration.getDecoration1() == ArrowDecoration.CIRCLE
-				&& dressing1.getHead() == ArrowHead.NONE) {
-			start += diamCircle / 2;
-			len -= diamCircle / 2;
+			if (dressing2.getHead() != ArrowHead.NONE)
+				len -= diamCircle / 2 + thinCircle;
 		}
-		if (arrowConfiguration.getDecoration1() == ArrowDecoration.CIRCLE
-				&& dressing1.getHead() == ArrowHead.NORMAL) {
-			start += diamCircle + thinCircle;
-			len -= diamCircle + thinCircle;
+
+		if (arrowConfiguration.getDecoration1() == ArrowDecoration.CIRCLE) {
+			if (dressing1.getHead() == ArrowHead.NONE) {
+				start += diamCircle / 2;
+				len -= diamCircle / 2;
+			}
+			if (dressing1.getHead() == ArrowHead.ASYNC) {
+				start += diamCircle / 2 + thinCircle;
+				len -= diamCircle / 2 + thinCircle;
+			}
+			if (dressing1.getHead() == ArrowHead.NORMAL) {
+				start += diamCircle / 2 + thinCircle;
+				len -= diamCircle / 2 + thinCircle;
+			}
 		}
 
 		if (dressing2.getPart() == ArrowPart.FULL && dressing2.getHead() == ArrowHead.NORMAL)
@@ -149,20 +155,20 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 				arrowConfiguration.getDecoration2(), lenFull);
 
 		if (inclination1 == 0 && inclination2 == 0)
-			arrowConfiguration.applyStroke(ug).apply(new UTranslate(start, posArrow)).draw(new ULine(len, 0));
+			arrowConfiguration.applyStroke(ug, getStyle()).apply(new UTranslate(start, posArrow)).draw(new ULine(len, 0));
 		else if (inclination1 != 0)
-			drawLine(arrowConfiguration.applyStroke(ug), start + len, posArrow, 0, posArrow + inclination1);
+			drawLine(arrowConfiguration.applyStroke(ug, getStyle()), start + len, posArrow, 0, posArrow + inclination1);
 		else if (inclination2 != 0)
-			drawLine(arrowConfiguration.applyStroke(ug), start, posArrow, pos2, posArrow + inclination2);
+			drawLine(arrowConfiguration.applyStroke(ug, getStyle()), start, posArrow, pos2, posArrow + inclination2);
 
 		final ArrowDirection direction2 = getDirection2();
 		final double textPos;
 		if (messagePosition == HorizontalAlignment.CENTER) {
 			final double textWidth = getTextBlock().calculateDimension(stringBounder).getWidth();
-			textPos = (dimensionToUse.getWidth() - textWidth) / 2;
+			textPos = (dimensionToUse.getWidth() - Math.abs(area.getTextDeltaX()) - textWidth) / 2;
 		} else if (messagePosition == HorizontalAlignment.RIGHT) {
 			final double textWidth = getTextBlock().calculateDimension(stringBounder).getWidth();
-			textPos = dimensionToUse.getWidth() - textWidth - getMarginX2()
+			textPos = dimensionToUse.getWidth() - Math.abs(area.getTextDeltaX()) - textWidth - getMarginX2()
 					- (direction2 == ArrowDirection.LEFT_TO_RIGHT_NORMAL ? getArrowDeltaX() : 0);
 		} else {
 			textPos = getMarginX1()
@@ -170,7 +176,7 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 							? getArrowDeltaX()
 							: 0);
 		}
-		getTextBlock().drawU(ug.apply(new UTranslate(textPos, yText)));
+		getTextBlock().drawU(ug.apply(new UTranslate(textPos + Math.max(0, area.getTextDeltaX()), yText)));
 	}
 
 	private void drawLine(UGraphic ug, double x1, double y1, double x2, double y2) {
@@ -187,14 +193,14 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 	}
 
 	private boolean isBelowForResponse() {
-		return belowForResponse && getDirection2() == ArrowDirection.RIGHT_TO_LEFT_REVERSE;
+		return belowForResponse && getArrowConfiguration().isReverseDefine();
 	}
 
 	private void drawDressing1(UGraphic ug, ArrowDressing dressing, ArrowDecoration decoration, double lenFull) {
 
 		if (decoration == ArrowDecoration.CIRCLE) {
-			final UEllipse circle = new UEllipse(diamCircle, diamCircle);
-			ug.apply(new UStroke(thinCircle)).apply(getForegroundColor())
+			final UEllipse circle = UEllipse.build(diamCircle, diamCircle);
+			ug.apply(UStroke.withThickness(thinCircle)).apply(getForegroundColor()).apply(getBackgroundColor().bg())
 					.apply(new UTranslate(-diamCircle / 2 - thinCircle, -diamCircle / 2 - thinCircle / 2)).draw(circle);
 			if (dressing.getHead() != ArrowHead.CROSSX)
 				ug = ug.apply(UTranslate.dx(diamCircle / 2 + thinCircle));
@@ -210,7 +216,7 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 						.draw(new ULine(getArrowDeltaX(), getArrowDeltaY()).rotate(Math.atan2(-inclination1, lenFull)));
 
 		} else if (dressing.getHead() == ArrowHead.CROSSX) {
-			ug = ug.apply(new UStroke(2));
+			ug = ug.apply(UStroke.withThickness(2));
 			ug.apply(new UTranslate(spaceCrossX, -getArrowDeltaX() / 2))
 					.draw(new ULine(getArrowDeltaX(), getArrowDeltaX()));
 			ug.apply(new UTranslate(spaceCrossX, getArrowDeltaX() / 2))
@@ -229,10 +235,11 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 	private void drawDressing2(UGraphic ug, ArrowDressing dressing, ArrowDecoration decoration, double lenFull) {
 
 		if (decoration == ArrowDecoration.CIRCLE) {
-			ug = ug.apply(new UStroke(thinCircle)).apply(getForegroundColor());
-			final UEllipse circle = new UEllipse(diamCircle, diamCircle);
+			ug = ug.apply(UStroke.withThickness(thinCircle)).apply(getForegroundColor())
+					.apply(getBackgroundColor().bg());
+			final UEllipse circle = UEllipse.build(diamCircle, diamCircle);
 			ug.apply(new UTranslate(-diamCircle / 2 + thinCircle, -diamCircle / 2 - thinCircle / 2)).draw(circle);
-			ug = ug.apply(new UStroke());
+			ug = ug.apply(UStroke.simple());
 			ug = ug.apply(UTranslate.dx(-diamCircle / 2 - thinCircle));
 		}
 
@@ -246,7 +253,7 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 						.draw(new ULine(-getArrowDeltaX(), getArrowDeltaY()).rotate(Math.atan2(inclination2, lenFull)));
 
 		} else if (dressing.getHead() == ArrowHead.CROSSX) {
-			ug = ug.apply(new UStroke(2));
+			ug = ug.apply(UStroke.withThickness(2));
 			ug.apply(new UTranslate(-spaceCrossX - getArrowDeltaX(), -getArrowDeltaX() / 2))
 					.draw(new ULine(getArrowDeltaX(), getArrowDeltaX()));
 			ug.apply(new UTranslate(-spaceCrossX - getArrowDeltaX(), getArrowDeltaX() / 2))
@@ -269,9 +276,9 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 			polygon.addPoint(0, 0);
 			polygon.addPoint(-getArrowDeltaX(), 0);
 		} else if (part == ArrowPart.BOTTOM_PART) {
-			polygon.addPoint(-getArrowDeltaX(), 1);
-			polygon.addPoint(0, 1);
-			polygon.addPoint(-getArrowDeltaX(), getArrowDeltaY() + 1);
+			polygon.addPoint(-getArrowDeltaX(), 0);
+			polygon.addPoint(0, 0);
+			polygon.addPoint(-getArrowDeltaX(), getArrowDeltaY());
 		} else {
 			polygon.addPoint(-getArrowDeltaX(), -getArrowDeltaY());
 			polygon.addPoint(0, 0);
@@ -289,9 +296,9 @@ public class ComponentRoseArrow extends AbstractComponentRoseArrow {
 			polygon.addPoint(0, 0);
 			polygon.addPoint(getArrowDeltaX(), 0);
 		} else if (part == ArrowPart.BOTTOM_PART) {
-			polygon.addPoint(getArrowDeltaX(), 1);
-			polygon.addPoint(0, 1);
-			polygon.addPoint(getArrowDeltaX(), getArrowDeltaY() + 1);
+			polygon.addPoint(getArrowDeltaX(), 0);
+			polygon.addPoint(0, 0);
+			polygon.addPoint(getArrowDeltaX(), getArrowDeltaY());
 		} else {
 			polygon.addPoint(getArrowDeltaX(), -getArrowDeltaY());
 			polygon.addPoint(0, 0);
