@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2025, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,30 +35,41 @@
  */
 package net.sourceforge.plantuml.skin.rose;
 
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.graphic.StringBounder;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.color.HColors;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.ULine;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
 import net.sourceforge.plantuml.skin.AbstractComponent;
 import net.sourceforge.plantuml.skin.Area;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
+
+import static java.util.Collections.singletonMap;
+import static net.sourceforge.plantuml.klimt.color.HColor.TransparentFillBehavior.WITH_FILL_OPACITY;
 
 public class ComponentRoseLine extends AbstractComponent {
 
 	private final HColor color;
 	private final boolean continueLine;
 	private final UStroke stroke;
+	private final Display stringsToDisplay;
 
-	public ComponentRoseLine(Style style, boolean continueLine, HColorSet set) {
+	public ComponentRoseLine(Style style, boolean continueLine, HColorSet set, Display stringsToDisplay) {
 		super(style);
 		this.color = style.value(PName.LineColor).asColor(set);
 		this.stroke = style.getStroke();
 		this.continueLine = continueLine;
+		// Ideally, stringsToDisplay should never be null. However, as a safeguard, 
+		// we default to Display.NULL when it is null.
+		this.stringsToDisplay = stringsToDisplay == null ? Display.NULL : stringsToDisplay;
 	}
 
 	@Override
@@ -67,10 +78,14 @@ public class ComponentRoseLine extends AbstractComponent {
 		ug = ug.apply(color);
 		ug = ug.apply(stroke);
 //		if (continueLine)
-//			ug = ug.apply(new UStroke());
+//			ug = ug.apply(UStroke.simple());
+
+		ug.startGroup(singletonMap(UGroupType.TITLE, stringsToDisplay.toTooltipText()));
+		drawTitleHoverTargetRect(ug, dimensionToUse);
 
 		final int x = (int) (dimensionToUse.getWidth() / 2);
 		ug.apply(UTranslate.dx(x)).draw(ULine.vline(dimensionToUse.getHeight()));
+		ug.closeGroup();
 	}
 
 	@Override
@@ -83,4 +98,14 @@ public class ComponentRoseLine extends AbstractComponent {
 		return 1;
 	}
 
+	private void drawTitleHoverTargetRect(UGraphic ug, XDimension2D dimensionToUse) {
+		if (dimensionToUse.getHeight() > 0) {
+			final double hoverTargetWidth = 8;
+			ug = ug.apply(UStroke.withThickness(0));
+			ug = ug.apply(HColors.transparent());
+			ug = ug.apply(HColors.transparent(WITH_FILL_OPACITY).bg());
+			ug = ug.apply(UTranslate.dx((dimensionToUse.getWidth() - hoverTargetWidth) / 2));
+			ug.draw(URectangle.build(hoverTargetWidth, dimensionToUse.getHeight()));
+		}
+	}
 }
