@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,22 +35,22 @@
  */
 package net.sourceforge.plantuml.skin.rose;
 
-import net.sourceforge.plantuml.ISkinSimple;
-import net.sourceforge.plantuml.LineBreakStrategy;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.SymbolContext;
-import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.klimt.Fashion;
+import net.sourceforge.plantuml.klimt.LineBreakStrategy;
+import net.sourceforge.plantuml.klimt.Shadowable;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
 import net.sourceforge.plantuml.skin.AbstractTextualComponent;
 import net.sourceforge.plantuml.skin.Area;
+import net.sourceforge.plantuml.style.ISkinSimple;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.ugraphic.Shadowable;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
 
 public class ComponentRoseParticipant extends AbstractTextualComponent {
 
@@ -68,9 +68,9 @@ public class ComponentRoseParticipant extends AbstractTextualComponent {
 			double minWidth, boolean collections, double padding) {
 		super(style, stereo, LineBreakStrategy.NONE, 7, 7, 7, spriteContainer, stringsToDisplay, false);
 
-		this.roundCorner = style.value(PName.RoundCorner).asInt();
-		this.diagonalCorner = style.value(PName.DiagonalCorner).asInt();
-		final SymbolContext biColor = style.getSymbolContext(getIHtmlColorSet());
+		this.roundCorner = style.value(PName.RoundCorner).asInt(false);
+		this.diagonalCorner = style.value(PName.DiagonalCorner).asInt(false);
+		final Fashion biColor = style.getSymbolContext(getIHtmlColorSet());
 		this.stroke = style.getStroke();
 
 		this.padding = padding;
@@ -90,7 +90,7 @@ public class ComponentRoseParticipant extends AbstractTextualComponent {
 		if (back != null)
 			ug = ug.apply(back.bg());
 		ug = ug.apply(stroke);
-		final Shadowable rect = new URectangle(getTextWidth(stringBounder), getTextHeight(stringBounder))
+		final Shadowable rect = URectangle.build(getTextWidth(stringBounder), getTextHeight(stringBounder))
 				.rounded(roundCorner).diagonalCorner(diagonalCorner);
 		rect.setDeltaShadow(deltaShadow);
 		if (collections) {
@@ -98,7 +98,7 @@ public class ComponentRoseParticipant extends AbstractTextualComponent {
 			ug = ug.apply(UTranslate.dy(getDeltaCollection()));
 		}
 		ug.draw(rect);
-		ug = ug.apply(new UStroke());
+		ug = ug.apply(UStroke.simple());
 		final TextBlock textBlock = getTextBlock();
 		textBlock.drawU(ug.apply(new UTranslate(getMarginX1() + suppWidth(stringBounder) / 2, getMarginY())));
 	}
