@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,15 +35,16 @@
  */
 package net.sourceforge.plantuml.statediagram.command;
 
-import net.sourceforge.plantuml.LineLocation;
+import net.sourceforge.plantuml.abel.Entity;
 import net.sourceforge.plantuml.command.CommandExecutionResult;
+import net.sourceforge.plantuml.command.ParserPass;
 import net.sourceforge.plantuml.command.SingleLineCommand2;
-import net.sourceforge.plantuml.command.regex.IRegex;
-import net.sourceforge.plantuml.command.regex.RegexConcat;
-import net.sourceforge.plantuml.command.regex.RegexLeaf;
-import net.sourceforge.plantuml.command.regex.RegexResult;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
+import net.sourceforge.plantuml.regex.IRegex;
+import net.sourceforge.plantuml.regex.RegexConcat;
+import net.sourceforge.plantuml.regex.RegexLeaf;
+import net.sourceforge.plantuml.regex.RegexResult;
 import net.sourceforge.plantuml.statediagram.StateDiagram;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class CommandEndState extends SingleLineCommand2<StateDiagram> {
 
@@ -51,6 +52,11 @@ public class CommandEndState extends SingleLineCommand2<StateDiagram> {
 		super(getRegexConcat());
 	}
 
+	@Override
+	public boolean isEligibleFor(ParserPass pass) {
+		return pass == ParserPass.ONE || pass == ParserPass.TWO || pass == ParserPass.THREE;
+	}
+
 	static IRegex getRegexConcat() {
 		return RegexConcat.build(CommandEndState.class.getName(), RegexLeaf.start(), //
 				new RegexLeaf("(end[%s]?state|\\})"), //
@@ -58,11 +64,12 @@ public class CommandEndState extends SingleLineCommand2<StateDiagram> {
 	}
 
 	@Override
-	protected CommandExecutionResult executeArg(StateDiagram diagram, LineLocation location, RegexResult arg) {
-		final IEntity currentPackage = diagram.getCurrentGroup();
-		if (currentPackage == null) {
+	protected CommandExecutionResult executeArg(StateDiagram diagram, LineLocation location, RegexResult arg,
+			ParserPass currentPass) {
+		final Entity currentPackage = diagram.getCurrentGroup();
+		if (currentPackage == null || currentPackage.isRoot())
 			return CommandExecutionResult.error("No inner state defined");
-		}
+
 		diagram.endGroup();
 		return CommandExecutionResult.ok();
 	}
