@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -36,6 +36,7 @@
 package net.sourceforge.plantuml.style;
 
 public enum SName {
+	action, //
 	activity, //
 	activityBar, //
 	activityDiagram, //
@@ -49,8 +50,10 @@ public enum SName {
 	boundary, //
 	box, //
 	boxless, //
+	business, //
 	caption, //
 	card, //
+	cardinality, //
 	circle, //
 	classDiagram, //
 	class_, //
@@ -62,12 +65,17 @@ public enum SName {
 	component, //
 	composite, //
 	robust, //
+	chenAttribute, //
+	chenEerDiagram, //
+	chenEntity, //
+	chenRelationship, //
 	concise, //
 	clock, //
 	componentDiagram, //
 	constraintArrow, //
 	control, //
 	database, //
+	day, //
 	delay, //
 	destroy, //
 	diamond, //
@@ -79,17 +87,19 @@ public enum SName {
 	start, //
 	stop, //
 	file, //
+	filesDiagram, //
 	folder, //
 	footer, //
 	frame, //
 	ganttDiagram, //
+	generic, //
 	group, //
 	groupHeader, //
 	header, //
 	hexagon, //
 	highlight, //
 	interface_, //
-	json,
+	json, // 
 	jsonDiagram, //
 	gitDiagram, //
 	label, //
@@ -100,6 +110,7 @@ public enum SName {
 	map, //
 	milestone, //
 	mindmapDiagram, //
+	month, //
 	network, //
 	node, //
 	note, //
@@ -111,10 +122,13 @@ public enum SName {
 	partition, //
 	person, //
 	port, //
+	process, //
+	qualified, //
 	queue, //
 	rectangle, //
 	reference, //
 	referenceHeader, //
+	regex, //
 	requirement, //
 	root, //
 	rootNode, //
@@ -130,13 +144,16 @@ public enum SName {
 	storage, //
 	swimlane, //
 	task, //
+	timegrid, //
 	timeline, //
 	timingDiagram, //
 	title, //
 	undone, //
 	unstarted, //
 	usecase, //
-
+	verticalSeparator, //
+	year, //
+	
 	visibilityIcon, //
 	private_, //
 	protected_, //
