@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -39,38 +39,51 @@ package net.sourceforge.plantuml.svek;
 import java.util.ArrayList;
 import java.util.Collection;
 import java.util.Collections;
+import java.util.EnumMap;
 import java.util.EnumSet;
 import java.util.HashMap;
 import java.util.HashSet;
 import java.util.Iterator;
+import java.util.LinkedHashSet;
 import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 
-import net.sourceforge.plantuml.AlignmentParam;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.UmlDiagramType;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
-import net.sourceforge.plantuml.command.Position;
-import net.sourceforge.plantuml.cucadiagram.CucaDiagram;
-import net.sourceforge.plantuml.cucadiagram.CucaNote;
-import net.sourceforge.plantuml.cucadiagram.EntityPosition;
-import net.sourceforge.plantuml.cucadiagram.EntityUtils;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
-import net.sourceforge.plantuml.cucadiagram.IGroup;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.cucadiagram.dot.GraphvizVersion;
-import net.sourceforge.plantuml.cucadiagram.entity.EntityImpl;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.USymbol;
-import net.sourceforge.plantuml.graphic.USymbols;
-import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
-import net.sourceforge.plantuml.posimo.Moveable;
+import net.atmp.CucaDiagram;
+import net.sourceforge.plantuml.abel.CucaNote;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.EntityPosition;
+import net.sourceforge.plantuml.abel.GroupType;
+import net.sourceforge.plantuml.abel.Together;
+import net.sourceforge.plantuml.decoration.symbol.USymbol;
+import net.sourceforge.plantuml.decoration.symbol.USymbols;
+import net.sourceforge.plantuml.dot.GraphvizVersion;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColorSet;
+import net.sourceforge.plantuml.klimt.color.HColors;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.MagneticBorder;
+import net.sourceforge.plantuml.klimt.geom.MagneticBorderNone;
+import net.sourceforge.plantuml.klimt.geom.Moveable;
+import net.sourceforge.plantuml.klimt.geom.RectangleArea;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.UComment;
+import net.sourceforge.plantuml.klimt.shape.ULine;
+import net.sourceforge.plantuml.skin.AlignmentParam;
+import net.sourceforge.plantuml.skin.PragmaKey;
+import net.sourceforge.plantuml.skin.UmlDiagramType;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -79,15 +92,9 @@ import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.image.EntityImageNoteLink;
 import net.sourceforge.plantuml.svek.image.EntityImageState;
 import net.sourceforge.plantuml.svek.image.EntityImageStateCommon;
-import net.sourceforge.plantuml.ugraphic.UComment;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UGroupType;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColorSet;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
+import net.sourceforge.plantuml.url.Url;
+import net.sourceforge.plantuml.utils.LineLocation;
+import net.sourceforge.plantuml.utils.Position;
 
 public class Cluster implements Moveable {
 
@@ -97,7 +104,7 @@ public class Cluster implements Moveable {
 	public final static String CENTER_ID = "za";
 
 	private final Cluster parentCluster;
-	private final IGroup group;
+	private final Entity group;
 	private final List<SvekNode> nodes = new ArrayList<>();
 	private final List<Cluster> children = new ArrayList<>();
 	private final int color;
@@ -114,17 +121,18 @@ public class Cluster implements Moveable {
 	private XPoint2D xyNoteTop;
 	private XPoint2D xyNoteBottom;
 
-	private ClusterPosition clusterPosition;
+	private RectangleArea rectangleArea;
+	private final LineLocation location;
 
-	public void moveSvek(double deltaX, double deltaY) {
+	public void moveDelta(double deltaX, double deltaY) {
 		if (this.xyNoteTop != null)
 			this.xyNoteTop = this.xyNoteTop.move(deltaX, deltaY);
 		if (this.xyNoteBottom != null)
 			this.xyNoteBottom = this.xyNoteBottom.move(deltaX, deltaY);
 		if (this.xyTitle != null)
 			this.xyTitle = this.xyTitle.move(deltaX, deltaY);
-		if (this.clusterPosition != null)
-			this.clusterPosition = this.clusterPosition.move(deltaX, deltaY);
+		if (this.rectangleArea != null)
+			this.rectangleArea = this.rectangleArea.move(deltaX, deltaY);
 
 	}
 
@@ -137,15 +145,15 @@ public class Cluster implements Moveable {
 		return Collections.unmodifiableSet(result);
 	}
 
-	public Cluster(CucaDiagram diagram, ColorSequence colorSequence, ISkinParam skinParam, IGroup root) {
-		this(diagram, null, colorSequence, skinParam, root);
+	public Cluster(LineLocation location, CucaDiagram diagram, ColorSequence colorSequence, Entity root) {
+		this(location, diagram, null, colorSequence, root);
 	}
 
-	private Cluster(CucaDiagram diagram, Cluster parentCluster, ColorSequence colorSequence, ISkinParam skinParam,
-			IGroup group) {
+	private Cluster(LineLocation location, CucaDiagram diagram, Cluster parentCluster, ColorSequence colorSequence, Entity group) {
 		if (group == null)
 			throw new IllegalStateException();
-
+		
+		this.location = location;
 		this.parentCluster = parentCluster;
 		this.group = group;
 		this.diagram = diagram;
@@ -154,7 +162,7 @@ public class Cluster implements Moveable {
 		this.colorTitle = colorSequence.getValue();
 		this.colorNoteTop = colorSequence.getValue();
 		this.colorNoteBottom = colorSequence.getValue();
-		this.skinParam = group.getColors().mute(skinParam);
+		this.skinParam = group.getColors().mute(diagram.getSkinParam());
 	}
 
 	@Override
@@ -183,7 +191,7 @@ public class Cluster implements Moveable {
 		return Collections.unmodifiableList(result);
 	}
 
-	private List<SvekNode> getNodesOrderedTop(Collection<SvekLine> lines) {
+	private List<SvekNode> getNodesOrderedTop(Collection<SvekEdge> lines) {
 		final List<SvekNode> firsts = new ArrayList<>();
 		final Map<String, SvekNode> shs = new HashMap<String, SvekNode>();
 
@@ -192,37 +200,39 @@ public class Cluster implements Moveable {
 			shs.put(node.getUid(), node);
 		}
 
-		for (SvekLine l : lines) {
+		for (SvekEdge l : lines)
 			if (l.isInverted()) {
 				final SvekNode sh = shs.get(l.getStartUidPrefix());
-				if (sh != null && sh.getEntityPosition() == EntityPosition.NORMAL)
+				if (sh != null && isNormalPosition(sh))
 					firsts.add(0, sh);
 			}
-		}
 
 		return firsts;
 	}
 
-	private List<SvekNode> getNodesOrderedWithoutTop(Collection<SvekLine> lines) {
+	private boolean isNormalPosition(final SvekNode sh) {
+		return sh.getEntityPosition() == EntityPosition.NORMAL;
+	}
+
+	private List<SvekNode> getNodesOrderedWithoutTop(Collection<SvekEdge> lines) {
 		final List<SvekNode> all = new ArrayList<>(nodes);
 		final Map<String, SvekNode> shs = new HashMap<String, SvekNode>();
 
 		for (final Iterator<SvekNode> it = all.iterator(); it.hasNext();) {
 			final SvekNode sh = it.next();
-			if (sh.getEntityPosition() != EntityPosition.NORMAL) {
+			if (isNormalPosition(sh) == false) {
 				it.remove();
 				continue;
 			}
 			shs.put(sh.getUid(), sh);
 		}
 
-		for (SvekLine l : lines) {
+		for (SvekEdge l : lines)
 			if (l.isInverted()) {
 				final SvekNode sh = shs.get(l.getStartUidPrefix());
 				if (sh != null)
 					all.remove(sh);
 			}
-		}
 
 		return all;
 	}
@@ -231,32 +241,32 @@ public class Cluster implements Moveable {
 		return Collections.unmodifiableList(children);
 	}
 
-	public Cluster createChild(ClusterHeader clusterHeader, ColorSequence colorSequence, ISkinParam skinParam,
-			IGroup g) {
-		final Cluster child = new Cluster(diagram, this, colorSequence, skinParam, g);
+	public Cluster createChild(LineLocation location, ClusterHeader clusterHeader, ColorSequence colorSequence, Entity g) {
+		final Cluster child = new Cluster(location, diagram, this, colorSequence, g);
 		child.clusterHeader = clusterHeader;
 		this.children.add(child);
 		return child;
 	}
 
-	public final Set<IGroup> getGroups() {
+	public final Set<Entity> getGroups() {
 		return Collections.singleton(group);
 	}
 
-	final IGroup getGroup() {
+	final Entity getGroup() {
 		return group;
 	}
 
 	public final int getTitleAndAttributeWidth() {
-		return clusterHeader.getTitleAndAttributeWidth();
+		final double minimumWidth = getStyle().value(PName.MinimumWidth).asDouble();
+		return Math.max(clusterHeader.getTitleAndAttributeWidth(), (int) Math.ceil(minimumWidth));
 	}
 
 	public final int getTitleAndAttributeHeight() {
 		return clusterHeader.getTitleAndAttributeHeight();
 	}
 
-	public ClusterPosition getClusterPosition() {
-		return clusterPosition;
+	public RectangleArea getRectangleArea() {
+		return rectangleArea;
 	}
 
 	public void setTitlePosition(XPoint2D pos) {
@@ -271,42 +281,60 @@ public class Cluster implements Moveable {
 		this.xyNoteBottom = pos;
 	}
 
-	static public StyleSignatureBasic getDefaultStyleDefinition(SName diagramStyleName, USymbol symbol) {
+	static public StyleSignatureBasic getDefaultStyleDefinition(SName diagramStyleName, USymbol symbol,
+			GroupType groupType) {
 		if (diagramStyleName == SName.stateDiagram)
 			return StyleSignatureBasic.of(SName.root, SName.element, SName.stateDiagram, SName.state, SName.group);
-		if (symbol == null)
-			return StyleSignatureBasic.of(SName.root, SName.element, diagramStyleName, SName.group);
-		return StyleSignatureBasic.of(SName.root, SName.element, diagramStyleName, SName.group, symbol.getSName());
+		if (symbol != null)
+			return StyleSignatureBasic.of(SName.root, SName.element, diagramStyleName, SName.group, symbol.getSName());
+		if (groupType == GroupType.PACKAGE)
+			return StyleSignatureBasic.of(SName.root, SName.element, diagramStyleName, SName.package_, SName.group);
+
+		return StyleSignatureBasic.of(SName.root, SName.element, diagramStyleName, SName.group);
 	}
 
-	public void drawU(UGraphic ug, UmlDiagramType umlDiagramType, ISkinParam skinParam2unused) {
+	public void drawU(UGraphic ug) {
 		if (group.isHidden())
 			return;
 
-		if (diagram.getPragma().useKermor()) {
+		if (diagram.getPragma().isTrue(PragmaKey.KERMOR)) {
 			if (xyNoteTop != null)
-				getCucaNote(Position.TOP).drawU(ug.apply(new UTranslate(xyNoteTop)));
+				getCucaNote(Position.TOP).drawU(ug.apply(UTranslate.point(xyNoteTop)));
 			if (xyNoteBottom != null)
-				getCucaNote(Position.BOTTOM).drawU(ug.apply(new UTranslate(xyNoteBottom)));
+				getCucaNote(Position.BOTTOM).drawU(ug.apply(UTranslate.point(xyNoteBottom)));
 		}
 
-		final String fullName = group.getCodeGetName();
+		final String fullName = group.getName();
 		if (fullName.startsWith("##") == false)
 			ug.draw(new UComment("cluster " + fullName));
 
-		final USymbol uSymbol = group.getUSymbol() == null ? USymbols.PACKAGE : group.getUSymbol();
-		Style style = getDefaultStyleDefinition(umlDiagramType.getStyleName(), uSymbol)
-				.withTOBECHANGED(group.getStereotype()).getMergedStyle(skinParam.getCurrentStyleBuilder());
-		final double shadowing = style.value(PName.Shadowing).asDouble();
+		final UmlDiagramType umlDiagramType = diagram.getUmlDiagramType();
+		final Style style = getStyle();
+		final double shadowing = style.getShadowing();
 		HColor borderColor;
 		if (group.getColors().getColor(ColorType.LINE) != null)
 			borderColor = group.getColors().getColor(ColorType.LINE);
 		else
 			borderColor = style.value(PName.LineColor).asColor(skinParam.getIHtmlColorSet());
-		final double rounded = style.value(PName.RoundCorner).asDouble();
+		double rounded = style.value(PName.RoundCorner).asDouble();
+
+		if (skinParam.strictUmlStyle())
+			rounded = 0;
+
 		final double diagonalCorner = style.value(PName.DiagonalCorner).asDouble();
 
-		ug.startGroup(Collections.singletonMap(UGroupType.ID, "cluster_" + fullName));
+		// ug.startGroup(Collections.singletonMap(UGroupType.ID, "cluster_" + fullName));
+		
+		final Map<UGroupType, String> typeIDent = new EnumMap<>(UGroupType.class);
+		typeIDent.put(UGroupType.CLASS, "cluster");
+		typeIDent.put(UGroupType.ID, "cluster_" + fullName);
+		typeIDent.put(UGroupType.DATA_ENTITY, group.getName());
+		typeIDent.put(UGroupType.DATA_UID, group.getUid());
+		typeIDent.put(UGroupType.DATA_QUALIFIED_NAME, group.getQuark().getQualifiedName());
+		if (group.getLocation() != null)
+			typeIDent.put(UGroupType.DATA_SOURCE_LINE, "" + group.getLocation().getPosition());
+		ug.startGroup(typeIDent);
+		
 
 		final Url url = group.getUrl99();
 		if (url != null)
@@ -334,12 +362,16 @@ public class Cluster implements Moveable {
 
 			HColor backColor = getBackColor(umlDiagramType, style);
 			backColor = getBackColor(backColor, group.getStereotype(), umlDiagramType.getStyleName(),
-					group.getUSymbol(), skinParam.getCurrentStyleBuilder(), skinParam.getIHtmlColorSet());
+					group.getUSymbol(), skinParam.getCurrentStyleBuilder(), skinParam.getIHtmlColorSet(),
+					group.getGroupType());
 
 			final ClusterDecoration decoration = new ClusterDecoration(packageStyle, group.getUSymbol(),
-					clusterHeader.getTitle(), clusterHeader.getStereo(), clusterPosition, stroke);
-			decoration.drawU(ug, backColor, borderColor, shadowing, rounded,
-					skinParam.getHorizontalAlignment(AlignmentParam.packageTitleAlignment, null, false, null),
+					clusterHeader.getTitle(), clusterHeader.getStereo(), rectangleArea, stroke);
+//			final HorizontalAlignment horizontalAlignment = skinParam
+//			.getHorizontalAlignment(AlignmentParam.packageTitleAlignment, null, false, null);
+			final HorizontalAlignment horizontalAlignment = clusterHeader.getTitleHorizontalAlignment();
+
+			decoration.drawU(ug, backColor, borderColor, shadowing, rounded, horizontalAlignment,
 					skinParam.getStereotypeAlignment(), diagonalCorner);
 
 		} catch (Exception e) {
@@ -351,6 +383,14 @@ public class Cluster implements Moveable {
 		}
 	}
 
+	private Style getStyle() {
+		final UmlDiagramType umlDiagramType = diagram.getUmlDiagramType();
+		final USymbol uSymbol = group.getUSymbol() == null ? USymbols.PACKAGE : group.getUSymbol();
+		final Style style = getDefaultStyleDefinition(umlDiagramType.getStyleName(), uSymbol, group.getGroupType())
+				.withTOBECHANGED(group.getStereotype()).getMergedStyle(skinParam.getCurrentStyleBuilder());
+		return style;
+	}
+
 	EntityImageNoteLink getCucaNote(Position position) {
 		final List<CucaNote> notes = getGroup().getNotes(position);
 		if (notes.size() == 0)
@@ -360,7 +400,7 @@ public class Cluster implements Moveable {
 				skinParam.getCurrentStyleBuilder());
 	}
 
-	static public UStroke getStrokeInternal(IGroup group, Style style) {
+	static public UStroke getStrokeInternal(Entity group, Style style) {
 		final Colors colors = group.getColors();
 		if (colors.getSpecificLineStroke() != null)
 			return colors.getSpecificLineStroke();
@@ -369,43 +409,46 @@ public class Cluster implements Moveable {
 	}
 
 	void manageEntryExitPoint(StringBounder stringBounder) {
-		final Collection<ClusterPosition> insides = new ArrayList<>();
+		final Collection<RectangleArea> insides = new ArrayList<>();
 		final List<XPoint2D> points = new ArrayList<>();
 		for (SvekNode sh : nodes)
-			if (sh.getEntityPosition() == EntityPosition.NORMAL)
-				insides.add(sh.getClusterPosition());
+			if (isNormalPosition(sh))
+				insides.add(sh.getRectangleArea());
 			else
-				points.add(sh.getClusterPosition().getPointCenter());
+				points.add(sh.getRectangleArea().getPointCenter());
 
 		for (Cluster in : children)
-			insides.add(in.getClusterPosition());
+			if (in.getRectangleArea() == null)
+				System.err.println("Frontier null for " + in);
+			else
+				insides.add(in.getRectangleArea());
 
-		final FrontierCalculator frontierCalculator = new FrontierCalculator(getClusterPosition(), insides, points);
+		final FrontierCalculator frontierCalculator = new FrontierCalculator(getRectangleArea(), insides, points,
+				skinParam.getRankdir());
 		if (getTitleAndAttributeWidth() > 0 && getTitleAndAttributeHeight() > 0)
 			frontierCalculator.ensureMinWidth(getTitleAndAttributeWidth() + 10);
 
-		this.clusterPosition = frontierCalculator.getSuggestedPosition();
+		this.rectangleArea = frontierCalculator.getSuggestedPosition();
 
 		final double widthTitle = clusterHeader.getTitle().calculateDimension(stringBounder).getWidth();
-		final double minX = clusterPosition.getMinX();
-		final double minY = clusterPosition.getMinY();
-		this.xyTitle = new XPoint2D(minX + ((clusterPosition.getWidth() - widthTitle) / 2), minY + IEntityImage.MARGIN);
+		final double minX = rectangleArea.getMinX();
+		final double minY = rectangleArea.getMinY();
+		this.xyTitle = new XPoint2D(minX + ((rectangleArea.getWidth() - widthTitle) / 2), minY + IEntityImage.MARGIN);
 	}
 
 	private void drawSwinLinesState(UGraphic ug, HColor borderColor) {
 		clusterHeader.getTitle().drawU(ug.apply(UTranslate.dx(xyTitle.x)));
 
-		final ULine line = ULine.vline(clusterPosition.getHeight());
+		final ULine line = ULine.vline(rectangleArea.getHeight());
 		ug = ug.apply(borderColor);
-		ug.apply(UTranslate.dx(clusterPosition.getMinX())).draw(line);
-		ug.apply(UTranslate.dx(clusterPosition.getMaxX())).draw(line);
+		ug.apply(UTranslate.dx(rectangleArea.getMinX())).draw(line);
+		ug.apply(UTranslate.dx(rectangleArea.getMaxX())).draw(line);
 
 	}
 
 	// GroupPngMakerState
 
 	private void drawUState(UGraphic ug, UmlDiagramType umlDiagramType, double rounded, double shadowing) {
-		final XDimension2D total = clusterPosition.getDimension();
 		final double suppY = clusterHeader.getTitle().calculateDimension(ug.getStringBounder()).getHeight()
 				+ IEntityImage.MARGIN;
 
@@ -422,9 +465,9 @@ public class Cluster implements Moveable {
 		final HColor imgBackcolor = EntityImageStateCommon.getStyleStateBody(group, skinParam)
 				.value(PName.BackGroundColor).asColor(skinParam.getIHtmlColorSet());
 
-		final TextBlock attribute = ((EntityImpl) group).getStateHeader(skinParam);
+		final TextBlock attribute = ((Entity) group).getStateHeader(skinParam);
 		final double attributeHeight = attribute.calculateDimension(ug.getStringBounder()).getHeight();
-		if (total.getWidth() == 0) {
+		if (rectangleArea.getDimension().getWidth() == 0) {
 			System.err.println("Cluster::drawUState issue");
 			return;
 		}
@@ -433,88 +476,141 @@ public class Cluster implements Moveable {
 		if (stroke == null)
 			stroke = EntityImageStateCommon.getStyleState(group, skinParam).getStroke();
 
-		final RoundedContainer r = new RoundedContainer(total, suppY,
+		final RoundedContainer r = new RoundedContainer(rectangleArea.getDimension(), suppY,
 				attributeHeight + (attributeHeight > 0 ? IEntityImage.MARGIN : 0), borderColor, backColor, imgBackcolor,
 				stroke, rounded, shadowing);
-		r.drawU(ug.apply(clusterPosition.getPosition()));
+		r.drawU(ug.apply(rectangleArea.getPosition()));
 
-		clusterHeader.getTitle().drawU(ug.apply(new UTranslate(xyTitle)));
+		clusterHeader.getTitleHorizontalAlignment().draw(
+				ug.apply(new UTranslate(rectangleArea.getMinX(), xyTitle.getY())), clusterHeader.getTitle(),
+				IEntityImage.MARGIN, 0, rectangleArea.getWidth());
 
 		if (attributeHeight > 0)
-			attribute.drawU(ug.apply(new UTranslate(clusterPosition.getMinX() + IEntityImage.MARGIN,
-					clusterPosition.getMinY() + suppY + IEntityImage.MARGIN / 2.0)));
+			attribute.drawU(ug.apply(new UTranslate(rectangleArea.getMinX() + IEntityImage.MARGIN,
+					rectangleArea.getMinY() + suppY + IEntityImage.MARGIN / 2.0)));
 
 		final Stereotype stereotype = group.getStereotype();
 		final boolean withSymbol = stereotype != null && stereotype.isWithOOSymbol();
 		if (withSymbol)
-			EntityImageState.drawSymbol(ug.apply(borderColor), clusterPosition.getMaxX(), clusterPosition.getMaxY());
+			EntityImageState.drawSymbol(ug.apply(borderColor), rectangleArea.getMaxX(), rectangleArea.getMaxY());
 
 	}
 
 	public void setPosition(XPoint2D min, XPoint2D max) {
-		this.clusterPosition = new ClusterPosition(min, max);
+		this.rectangleArea = RectangleArea.build(min, max);
 	}
 
-	public boolean printCluster1(StringBuilder sb, Collection<SvekLine> lines, StringBounder stringBounder) {
+	// ::comment when __CORE__
+	public boolean printCluster1(StringBuilder sb, Collection<SvekEdge> lines, StringBounder stringBounder) {
 		final List<SvekNode> tmp = getNodesOrderedTop(lines);
 		if (tmp.size() == 0)
 			return false;
 		for (SvekNode node : tmp)
 			node.appendShape(sb, stringBounder);
+
 		return true;
 
 	}
 
-	public SvekNode printCluster2(StringBuilder sb, Collection<SvekLine> lines, StringBounder stringBounder,
+	private int togetherCounter = 0;
+
+	private void printTogether(Together together, Collection<Together> otherTogethers, StringBuilder sb,
+			List<SvekNode> nodesOrderedWithoutTop, StringBounder stringBounder, Collection<SvekEdge> lines,
+			DotMode dotMode, GraphvizVersion graphvizVersion, UmlDiagramType type) {
+		sb.append("subgraph " + getClusterId() + "t" + togetherCounter + " {\n");
+		for (SvekNode node : nodesOrderedWithoutTop)
+			if (node.getTogether() == together)
+				node.appendShape(sb, stringBounder);
+
+		for (Cluster child : children)
+			if (child.group.getTogether() == together)
+				child.printInternal(sb, lines, stringBounder, dotMode, graphvizVersion, type);
+
+		for (Together otherTogether : otherTogethers)
+			if (otherTogether.getParent() == together)
+				printTogether(otherTogether, otherTogethers, sb, nodesOrderedWithoutTop, stringBounder, lines, dotMode,
+						graphvizVersion, type);
+
+		sb.append("}\n");
+		togetherCounter++;
+
+	}
+
+	public SvekNode printCluster2(StringBuilder sb, Collection<SvekEdge> lines, StringBounder stringBounder,
 			DotMode dotMode, GraphvizVersion graphvizVersion, UmlDiagramType type) {
 
 		SvekNode added = null;
-		for (SvekNode node : getNodesOrderedWithoutTop(lines)) {
-			node.appendShape(sb, stringBounder);
+		final Collection<Together> togethers = new LinkedHashSet<>();
+		final List<SvekNode> nodesOrderedWithoutTop = getNodesOrderedWithoutTop(lines);
+		for (SvekNode node : nodesOrderedWithoutTop) {
+			final Together together = node.getTogether();
+			if (together == null)
+				node.appendShape(sb, stringBounder);
+			else
+				addTogetherWithParents(togethers, together);
+
 			added = node;
 		}
+		for (Cluster child : children)
+			if (child.group.getTogether() != null)
+				addTogetherWithParents(togethers, child.group.getTogether());
+
+		for (Together together : togethers)
+			if (together.getParent() == null)
+				printTogether(together, togethers, sb, nodesOrderedWithoutTop, stringBounder, lines, dotMode,
+						graphvizVersion, type);
 
 		if (skinParam.useRankSame() && dotMode != DotMode.NO_LEFT_RIGHT_AND_XLABEL
 				&& graphvizVersion.ignoreHorizontalLinks() == false)
 			appendRankSame(sb, lines);
 
-		for (Cluster child : getChildren())
-			child.printInternal(sb, lines, stringBounder, dotMode, graphvizVersion, type);
+		for (Cluster child : children)
+			if (child.group.getTogether() == null)
+				child.printInternal(sb, lines, stringBounder, dotMode, graphvizVersion, type);
 
 		return added;
 	}
 
-	public void printCluster3_forKermor(StringBuilder sb, Collection<SvekLine> lines, StringBounder stringBounder,
+	private static void addTogetherWithParents(Collection<Together> collection, Together together) {
+		Together t = together;
+		while (t != null) {
+			collection.add(t);
+			t = t.getParent();
+		}
+	}
+
+	public void printCluster3_forKermor(StringBuilder sb, Collection<SvekEdge> lines, StringBounder stringBounder,
 			DotMode dotMode, GraphvizVersion graphvizVersion, UmlDiagramType type) {
 		final List<SvekNode> tmp = getNodes(EntityPosition.getNormals());
 
 		if (tmp.size() == 0) {
 			sb.append(getClusterId() + "empty [shape=point,label=\"\"];");
 			SvekUtils.println(sb);
-		} else
-			for (SvekNode node : tmp) {
+		} else {
+			for (SvekNode node : tmp)
 				node.appendShape(sb, stringBounder);
-			}
+		}
 
 		for (Cluster child : getChildren())
 			child.printInternal(sb, lines, stringBounder, dotMode, graphvizVersion, type);
 	}
 
-	private void printInternal(StringBuilder sb, Collection<SvekLine> lines, StringBounder stringBounder,
+	private void printInternal(StringBuilder sb, Collection<SvekEdge> lines, StringBounder stringBounder,
 			DotMode dotMode, GraphvizVersion graphvizVersion, UmlDiagramType type) {
 		new ClusterDotString(this, skinParam).printInternal(sb, lines, stringBounder, dotMode, graphvizVersion, type);
 	}
 
-	private void appendRankSame(StringBuilder sb, Collection<SvekLine> lines) {
+	private void appendRankSame(StringBuilder sb, Collection<SvekEdge> lines) {
 		for (String same : getRankSame(lines)) {
 			sb.append(same);
 			SvekUtils.println(sb);
 		}
 	}
+	// ::done
 
-	private Set<String> getRankSame(Collection<SvekLine> lines) {
+	private Set<String> getRankSame(Collection<SvekEdge> lines) {
 		final Set<String> rankSame = new HashSet<>();
-		for (SvekLine l : lines) {
+		for (SvekEdge l : lines) {
 			if (l.hasEntryPoint())
 				continue;
 
@@ -542,7 +638,7 @@ public class Cluster implements Moveable {
 		return "cluster" + color;
 	}
 
-	static String getSpecialPointId(IEntity group) {
+	static String getSpecialPointId(Entity group) {
 		return CENTER_ID + group.getUid();
 	}
 
@@ -561,7 +657,7 @@ public class Cluster implements Moveable {
 	}
 
 	public boolean isLabel() {
-		return getTitleAndAttributeHeight() > 0 && getTitleAndAttributeWidth() > 0;
+		return getTitleAndAttributeHeight() > 0 || getTitleAndAttributeWidth() > 0;
 	}
 
 	int getColor() {
@@ -573,31 +669,17 @@ public class Cluster implements Moveable {
 	}
 
 	private final HColor getBackColor(UmlDiagramType umlDiagramType, Style style) {
-		if (EntityUtils.groupRoot(group))
+		if (group.isRoot())
 			return null;
 
 		final HColor result = group.getColors().getColor(ColorType.BACK);
 		if (result != null)
 			return result;
 
-		final Stereotype stereo = group.getStereotype();
-
 		return style.value(PName.BackGroundColor).asColor(skinParam.getIHtmlColorSet());
-
-//		final USymbol sym = group.getUSymbol() == null ? USymbols.PACKAGE : group.getUSymbol();
-//		final ColorParam backparam = umlDiagramType == UmlDiagramType.ACTIVITY ? ColorParam.partitionBackground
-//				: sym.getColorParamBack();
-//		final HColor c1 = skinParam.getHtmlColor(backparam, stereo, false);
-//		if (c1 != null)
-//			return c1;
-//
-//		if (parentCluster == null)
-//			return null;
-//
-//		return parentCluster.getBackColor(umlDiagramType, style);
 	}
 
-	boolean isClusterOf(IEntity ent) {
+	boolean isClusterOf(Entity ent) {
 		if (ent.isGroup() == false)
 			return false;
 
@@ -605,9 +687,9 @@ public class Cluster implements Moveable {
 	}
 
 	public static HColor getBackColor(HColor backColor, Stereotype stereotype, SName styleName, USymbol symbol,
-			StyleBuilder styleBuilder, HColorSet colorSet) {
+			StyleBuilder styleBuilder, HColorSet colorSet, GroupType groupType) {
 
-		final Style style = getDefaultStyleDefinition(styleName, symbol).getMergedStyle(styleBuilder);
+		final Style style = getDefaultStyleDefinition(styleName, symbol, groupType).getMergedStyle(styleBuilder);
 		if (backColor == null)
 			backColor = style.value(PName.BackGroundColor).asColor(colorSet);
 
@@ -617,18 +699,18 @@ public class Cluster implements Moveable {
 		return backColor;
 	}
 
-	double checkFolderPosition(XPoint2D pt, StringBounder stringBounder) {
-		if (getClusterPosition().isPointJustUpper(pt)) {
-
-			final XDimension2D dimTitle = clusterHeader.getTitle().calculateDimension(stringBounder);
-
-			if (pt.getX() < getClusterPosition().getMinX() + dimTitle.getWidth())
-				return 0;
-
-			return getClusterPosition().getMinY() - pt.getY() + dimTitle.getHeight();
-		}
-		return 0;
-	}
+//	double checkFolderPosition(XPoint2D pt, StringBounder stringBounder) {
+//		if (getClusterPosition().isPointJustUpper(pt)) {
+//
+//			final XDimension2D dimTitle = clusterHeader.getTitle().calculateDimension(stringBounder);
+//
+//			if (pt.getX() < getClusterPosition().getMinX() + dimTitle.getWidth())
+//				return 0;
+//
+//			return getClusterPosition().getMinY() - pt.getY() + dimTitle.getHeight();
+//		}
+//		return 0;
+//	}
 
 	public final int getColorNoteTop() {
 		return colorNoteTop;
@@ -642,6 +724,40 @@ public class Cluster implements Moveable {
 		return clusterHeader.getTitle().calculateDimension(stringBounder);
 	}
 
+	public MagneticBorder getMagneticBorder() {
+
+		if (group.getUSymbol() == null && group.getGroupType() != GroupType.PACKAGE)
+			return new MagneticBorderNone();
+
+		final USymbol uSymbol = group.getUSymbol();
+		PackageStyle packageStyle = group.getPackageStyle();
+		if (packageStyle == null)
+			packageStyle = skinParam.packageStyle();
+
+		final UmlDiagramType umlDiagramType = UmlDiagramType.CLASS;
+
+		final Style style = getDefaultStyleDefinition(umlDiagramType.getStyleName(), uSymbol, group.getGroupType())
+				.withTOBECHANGED(group.getStereotype()).getMergedStyle(skinParam.getCurrentStyleBuilder());
+
+		final UStroke stroke = getStrokeInternal(group, style);
+
+		final ClusterDecoration decoration = new ClusterDecoration(packageStyle, group.getUSymbol(),
+				clusterHeader.getTitle(), clusterHeader.getStereo(), rectangleArea, stroke);
+
+		final TextBlock textBlock = decoration.getTextBlock(HColors.BLACK, HColors.BLACK, 0, 0,
+				skinParam.getHorizontalAlignment(AlignmentParam.packageTitleAlignment, null, false, null),
+				skinParam.getStereotypeAlignment(), 0);
+
+		final MagneticBorder orig = textBlock.getMagneticBorder();
+
+		return new MagneticBorder() {
+			public UTranslate getForceAt(StringBounder stringBounder, XPoint2D position) {
+				return orig.getForceAt(stringBounder,
+						position.move(-rectangleArea.getMinX(), -rectangleArea.getMinY()));
+			}
+		};
+	}
+
 	// public XPoint2D projection(double x, double y) {
 	// final double v1 = Math.abs(minX - x);
 	// final double v2 = Math.abs(maxX - x);
