@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -38,22 +38,27 @@ package net.sourceforge.plantuml.svek.image;
 import java.util.EnumMap;
 import java.util.Map;
 
-import net.sourceforge.plantuml.Direction;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.LineConfigurable;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XRectangle2D;
-import net.sourceforge.plantuml.creole.Stencil;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
+import net.atmp.InnerStrategy;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.EntityPortion;
+import net.sourceforge.plantuml.abel.LineConfigurable;
 import net.sourceforge.plantuml.cucadiagram.PortionShower;
-import net.sourceforge.plantuml.cucadiagram.entity.EntityImpl;
-import net.sourceforge.plantuml.graphic.InnerStrategy;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.color.ColorType;
+import net.sourceforge.plantuml.klimt.Shadowable;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.color.HColors;
+import net.sourceforge.plantuml.klimt.creole.Stencil;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.drawing.UGraphicStencil;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XRectangle2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.UComment;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -64,16 +69,9 @@ import net.sourceforge.plantuml.svek.Margins;
 import net.sourceforge.plantuml.svek.Ports;
 import net.sourceforge.plantuml.svek.ShapeType;
 import net.sourceforge.plantuml.svek.WithPorts;
-import net.sourceforge.plantuml.ugraphic.Shadowable;
-import net.sourceforge.plantuml.ugraphic.UComment;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UGraphicStencil;
-import net.sourceforge.plantuml.ugraphic.UGroupType;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
-import net.sourceforge.plantuml.ugraphic.color.HColors;
+import net.sourceforge.plantuml.url.Url;
+import net.sourceforge.plantuml.utils.Direction;
+import net.sourceforge.plantuml.utils.LineLocation;
 
 public class EntityImageClass extends AbstractEntityImage implements Stencil, WithPorts {
 
@@ -82,13 +80,11 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 	final private EntityImageClassHeader header;
 	final private Url url;
 	final private double roundCorner;
-	final private LeafType leafType;
 
 	final private LineConfigurable lineConfig;
 
-	public EntityImageClass(ILeaf entity, ISkinParam skinParam, PortionShower portionShower) {
-		super(entity, entity.getColors().mute(skinParam));
-		this.leafType = entity.getLeafType();
+	public EntityImageClass(Entity entity, PortionShower portionShower) {
+		super(entity);
 		this.lineConfig = entity;
 
 		this.roundCorner = getStyle().value(PName.RoundCorner).asDouble();
@@ -98,7 +94,7 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 		this.body = entity.getBodier().getBody(getSkinParam(), showMethods, showFields, entity.getStereotype(),
 				getStyle(), null);
 
-		this.header = new EntityImageClassHeader(entity, getSkinParam(), portionShower);
+		this.header = new EntityImageClassHeader(entity, portionShower);
 		this.url = entity.getUrl99();
 	}
 
@@ -122,10 +118,10 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 	private double getKalWidth() {
 		double widthUp = 0;
 		double widthDown = 0;
-		for (Kal kal : ((EntityImpl) getEntity()).getKals(Direction.UP))
+		for (Kal kal : ((Entity) getEntity()).getKals(Direction.UP))
 			widthUp += kal.getDimension().getWidth();
 
-		for (Kal kal : ((EntityImpl) getEntity()).getKals(Direction.DOWN))
+		for (Kal kal : ((Entity) getEntity()).getKals(Direction.DOWN))
 			widthDown += kal.getDimension().getWidth();
 
 		return Math.max(widthUp, widthDown);
@@ -144,13 +140,18 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 	}
 
 	final public void drawU(UGraphic ug) {
-		ug.draw(new UComment("class " + getEntity().getCodeGetName()));
+		ug.draw(new UComment("class " + getEntity().getName()));
 		if (url != null)
 			ug.startUrl(url);
 
 		final Map<UGroupType, String> typeIDent = new EnumMap<>(UGroupType.class);
-		typeIDent.put(UGroupType.CLASS, "elem " + getEntity().getCode() + " selected");
-		typeIDent.put(UGroupType.ID, "elem_" + getEntity().getCode());
+		typeIDent.put(UGroupType.CLASS, "entity");
+		typeIDent.put(UGroupType.ID, "entity_" + getEntity().getName());
+		typeIDent.put(UGroupType.DATA_ENTITY, getEntity().getName());
+		typeIDent.put(UGroupType.DATA_UID, getEntity().getUid());
+		typeIDent.put(UGroupType.DATA_QUALIFIED_NAME, getEntity().getQuark().getQualifiedName());
+		if (getEntity().getLocation() != null)
+			typeIDent.put(UGroupType.DATA_SOURCE_LINE, "" + getEntity().getLocation().getPosition());
 		ug.startGroup(typeIDent);
 		drawInternal(ug);
 		ug.closeGroup();
@@ -181,8 +182,9 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 
 		final double widthTotal = dimTotal.getWidth();
 		final double heightTotal = dimTotal.getHeight();
-		final Shadowable rect = new URectangle(widthTotal, heightTotal).rounded(roundCorner)
-				.withCommentAndCodeLine(getEntity().getCodeGetName(), getEntity().getCodeLine());
+		final LineLocation location = getEntity().getLocation();
+		final Shadowable rect = URectangle.build(widthTotal, heightTotal).rounded(roundCorner)
+				.withCommentAndCodeLine(getEntity().getName(), location == null ? null : "" + location);
 
 		double shadow = 0;
 
@@ -190,7 +192,7 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 		HColor headerBackcolor = getEntity().getColors().getColor(ColorType.HEADER);
 		HColor backcolor = getEntity().getColors().getColor(ColorType.BACK);
 
-		shadow = getStyle().value(PName.Shadowing).asDouble();
+		shadow = getStyle().getShadowing();
 
 		if (borderColor == null)
 			borderColor = getStyle().value(PName.LineColor).asColor(getSkinParam().getIHtmlColorSet());
@@ -213,14 +215,14 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 		UGraphic ugHeader = ug;
 		if (roundCorner == 0 && headerBackcolor != null && backcolor.equals(headerBackcolor) == false) {
 			ug.apply(stroke).draw(rect);
-			final Shadowable rect2 = new URectangle(widthTotal, dimHeader.getHeight());
+			final Shadowable rect2 = URectangle.build(widthTotal, dimHeader.getHeight());
 			rect2.setDeltaShadow(0);
 			ugHeader = ugHeader.apply(headerBackcolor.bg());
 			ugHeader.apply(stroke).draw(rect2);
 		} else if (roundCorner != 0 && headerBackcolor != null && backcolor.equals(headerBackcolor) == false) {
 			ug.apply(stroke).draw(rect);
-			final Shadowable rect2 = new URectangle(widthTotal, dimHeader.getHeight()).rounded(roundCorner);
-			final URectangle rect3 = new URectangle(widthTotal, roundCorner / 2);
+			final Shadowable rect2 = URectangle.build(widthTotal, dimHeader.getHeight()).rounded(roundCorner);
+			final URectangle rect3 = URectangle.build(widthTotal, roundCorner / 2);
 			rect2.setDeltaShadow(0);
 			rect3.setDeltaShadow(0);
 			ugHeader = ugHeader.apply(headerBackcolor.bg()).apply(headerBackcolor);
@@ -249,7 +251,7 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 	}
 
 	public ShapeType getShapeType() {
-		if (((ILeaf) getEntity()).getPortShortNames().size() > 0)
+		if (getEntity().getPortShortNames().size() > 0)
 			return ShapeType.RECTANGLE_HTML_FOR_PORTS;
 
 		return ShapeType.RECTANGLE;
@@ -257,7 +259,7 @@ public class EntityImageClass extends AbstractEntityImage implements Stencil, Wi
 
 	@Override
 	public Margins getShield(StringBounder stringBounder) {
-		return ((ILeaf) getEntity()).getMargins();
+		return getEntity().getMargins();
 	}
 
 	public double getStartingX(StringBounder stringBounder, double y) {
