@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -35,27 +35,30 @@
  */
 package net.sourceforge.plantuml.svek.image;
 
-import net.sourceforge.plantuml.FontParam;
-import net.sourceforge.plantuml.Guillemet;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.SkinParamUtils;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.EntityPortion;
+import net.sourceforge.plantuml.abel.LeafType;
 import net.sourceforge.plantuml.cucadiagram.PortionShower;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.graphic.CircledCharacter;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockGeneric;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.CreoleMode;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.FontParam;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.font.UFont;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.VerticalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.CircledCharacter;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockGeneric;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
+import net.sourceforge.plantuml.skin.SkinParamUtils;
 import net.sourceforge.plantuml.skin.VisibilityModifier;
 import net.sourceforge.plantuml.skin.rose.Rose;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -63,31 +66,31 @@ import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.AbstractEntityImage;
 import net.sourceforge.plantuml.svek.HeaderLayout;
 import net.sourceforge.plantuml.svek.ShapeType;
-import net.sourceforge.plantuml.ugraphic.UFont;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.text.Guillemet;
+
+import java.util.List;
 
 public class EntityImageClassHeader extends AbstractEntityImage {
 
 	final private HeaderLayout headerLayout;
 
-	public EntityImageClassHeader(ILeaf entity, ISkinParam skinParam, PortionShower portionShower) {
-		super(entity, skinParam);
+	public EntityImageClassHeader(Entity entity, PortionShower portionShower) {
+		super(entity);
 
 		final boolean italic = entity.getLeafType() == LeafType.ABSTRACT_CLASS
 				|| entity.getLeafType() == LeafType.INTERFACE;
 
 		final Stereotype stereotype = entity.getStereotype();
-		final boolean displayGenericWithOldFashion = skinParam.displayGenericWithOldFashion();
+		final boolean displayGenericWithOldFashion = getSkinParam().displayGenericWithOldFashion();
 		final String generic = displayGenericWithOldFashion ? null : entity.getGeneric();
 
-		final Style style = StyleSignatureBasic
+		final Style styleHeader = StyleSignatureBasic
 				.of(SName.root, SName.element, SName.classDiagram, SName.class_, SName.header) //
 				.withTOBECHANGED(stereotype) //
 				.with(entity.getStereostyles()) //
-				.getMergedStyle(skinParam.getCurrentStyleBuilder());
-		FontConfiguration fontConfigurationName = FontConfiguration.create(skinParam, style, entity.getColors());
-
+				.getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+		
+		FontConfiguration fontConfigurationName = FontConfiguration.create(getSkinParam(), styleHeader, entity.getColors());
 		if (italic)
 			fontConfigurationName = fontConfigurationName.italic();
 
@@ -95,61 +98,63 @@ public class EntityImageClassHeader extends AbstractEntityImage {
 		if (displayGenericWithOldFashion && entity.getGeneric() != null)
 			display = display.addGeneric(entity.getGeneric());
 
-		TextBlock name = display.createWithNiceCreoleMode(fontConfigurationName, HorizontalAlignment.CENTER, skinParam);
+		TextBlock name = display.create8(fontConfigurationName, HorizontalAlignment.CENTER, getSkinParam(),
+				CreoleMode.FULL_BUT_UNDERSCORE, styleHeader.wrapWidth());
 		final VisibilityModifier modifier = entity.getVisibilityModifier();
 		if (modifier == null) {
 			name = TextBlockUtils.withMargin(name, 3, 3, 0, 0);
 		} else {
 			final Rose rose = new Rose();
-			final HColor back = rose.getHtmlColor(skinParam, modifier.getBackground());
-			final HColor fore = rose.getHtmlColor(skinParam, modifier.getForeground());
+			final HColor back = rose.getHtmlColor(getSkinParam(), modifier.getBackground());
+			final HColor fore = rose.getHtmlColor(getSkinParam(), modifier.getForeground());
 
-			final TextBlock uBlock = modifier.getUBlock(skinParam.classAttributeIconSize(), fore, back, false);
+			final TextBlock uBlock = modifier.getUBlock(getSkinParam().classAttributeIconSize(), fore, back, false);
 			name = TextBlockUtils.mergeLR(uBlock, name, VerticalAlignment.CENTER);
 			name = TextBlockUtils.withMargin(name, 3, 3, 0, 0);
 		}
 
 		final TextBlock stereo;
+		final List<String> stereotypeLabels = portionShower.getVisibleStereotypeLabels(entity);
 		if (stereotype == null || stereotype.getLabel(Guillemet.DOUBLE_COMPARATOR) == null
-				|| portionShower.showPortion(EntityPortion.STEREOTYPE, entity) == false)
+				|| stereotypeLabels.isEmpty())
 			stereo = null;
 		else
-			stereo = TextBlockUtils.withMargin(Display.create(stereotype.getLabels(skinParam.guillemet())).create(
+			stereo = TextBlockUtils.withMargin(Display.create(stereotypeLabels).create(
 					FontConfiguration.create(getSkinParam(), FontParam.CLASS_STEREOTYPE, stereotype),
-					HorizontalAlignment.CENTER, skinParam), 1, 0);
+					HorizontalAlignment.CENTER, getSkinParam()), 1, 0);
 
 		TextBlock genericBlock;
 		if (generic == null) {
 			genericBlock = null;
-		} else {
-			genericBlock = Display.getWithNewlines(generic).create(
+		} else {			
+			final Style styleGeneric = StyleSignatureBasic
+					.of(SName.root, SName.element, SName.classDiagram, SName.class_, SName.generic) //
+					.withTOBECHANGED(stereotype) //
+					.with(entity.getStereostyles()) //
+					.getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+
+			genericBlock = Display.getWithNewlines(getSkinParam().getPragma(), generic).create(
 					FontConfiguration.create(getSkinParam(), FontParam.CLASS_STEREOTYPE, stereotype),
-					HorizontalAlignment.CENTER, skinParam);
+					HorizontalAlignment.CENTER, getSkinParam());
 			genericBlock = TextBlockUtils.withMargin(genericBlock, 1, 1);
 
-//			final HColor classBackground = SkinParamUtils.getColor(getSkinParam(), stereotype, ColorParam.background);
-//			final HColor classBorder = SkinParamUtils.getFontColor(getSkinParam(), FontParam.CLASS_STEREOTYPE,
-//					stereotype);
-
-//			final HColor classBackground = style.value(PName.BackGroundColor).asColor(skinParam.getThemeStyle(),
-//					skinParam.getIHtmlColorSet());
-			final HColor classBackground = skinParam.getBackgroundColor();
-			final HColor classBorder = style.value(PName.LineColor).asColor(skinParam.getIHtmlColorSet());
+			final HColor classBackground = styleGeneric.value(PName.BackGroundColor).asColor(getSkinParam().getIHtmlColorSet());
+			final HColor classBorder = styleGeneric.value(PName.LineColor).asColor(getSkinParam().getIHtmlColorSet());
 
 			genericBlock = new TextBlockGeneric(genericBlock, classBackground, classBorder);
 			genericBlock = TextBlockUtils.withMargin(genericBlock, 1, 1);
 		}
 
 		final TextBlock circledCharacter;
-		if (portionShower.showPortion(EntityPortion.CIRCLED_CHARACTER, (ILeaf) getEntity()))
-			circledCharacter = TextBlockUtils.withMargin(getCircledCharacter(entity, skinParam), 4, 0, 5, 5);
+		if (portionShower.showPortion(EntityPortion.CIRCLED_CHARACTER, (Entity) getEntity()))
+			circledCharacter = TextBlockUtils.withMargin(getCircledCharacter(entity, getSkinParam()), 4, 0, 5, 5);
 		else
 			circledCharacter = null;
 
 		this.headerLayout = new HeaderLayout(circledCharacter, stereo, name, genericBlock);
 	}
 
-	private TextBlock getCircledCharacter(ILeaf entity, ISkinParam skinParam) {
+	private TextBlock getCircledCharacter(Entity entity, ISkinParam skinParam) {
 		final Stereotype stereotype = entity.getStereotype();
 		if (stereotype != null && stereotype.getSprite(skinParam) != null)
 			return stereotype.getSprite(skinParam);
@@ -166,7 +171,8 @@ public class EntityImageClassHeader extends AbstractEntityImage {
 
 		if (stereotype != null && stereotype.getCharacter() != 0)
 			return new CircledCharacter(stereotype.getCharacter(), getSkinParam().getCircledCharacterRadius(), font,
-					stereotype.getHtmlColor(), spotBorder, fontColor);
+					stereotype.getHtmlColor() == null ? spotBackColor : stereotype.getHtmlColor(), spotBorder,
+					fontColor);
 
 		char circledChar = 0;
 		if (stereotype != null)
