@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -39,32 +39,39 @@ package net.sourceforge.plantuml.svek.image;
 import java.util.Collection;
 import java.util.EnumMap;
 import java.util.HashSet;
+import java.util.List;
 import java.util.Map;
 import java.util.Objects;
 import java.util.Set;
 
-import net.sourceforge.plantuml.Guillemet;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.Link;
 import net.sourceforge.plantuml.cucadiagram.BodyFactory;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
-import net.sourceforge.plantuml.cucadiagram.IEntity;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.Link;
 import net.sourceforge.plantuml.cucadiagram.PortionShower;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.SymbolContext;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.USymbol;
-import net.sourceforge.plantuml.graphic.USymbols;
-import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.decoration.symbol.USymbol;
+import net.sourceforge.plantuml.decoration.symbol.USymbolActorBusiness;
+import net.sourceforge.plantuml.decoration.symbol.USymbols;
+import net.sourceforge.plantuml.klimt.Fashion;
+import net.sourceforge.plantuml.klimt.Shadowable;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.drawing.UGraphicStencil;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.MagneticBorder;
+import net.sourceforge.plantuml.klimt.geom.MagneticBorderNone;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
+import net.sourceforge.plantuml.klimt.shape.UComment;
+import net.sourceforge.plantuml.stereo.Stereotype;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -74,14 +81,8 @@ import net.sourceforge.plantuml.svek.Bibliotekon;
 import net.sourceforge.plantuml.svek.Margins;
 import net.sourceforge.plantuml.svek.ShapeType;
 import net.sourceforge.plantuml.svek.SvekNode;
-import net.sourceforge.plantuml.ugraphic.Shadowable;
-import net.sourceforge.plantuml.ugraphic.UComment;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UGraphicStencil;
-import net.sourceforge.plantuml.ugraphic.UGroupType;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.text.Guillemet;
+import net.sourceforge.plantuml.url.Url;
 import net.sourceforge.plantuml.utils.MathUtils;
 
 public class EntityImageDescription extends AbstractEntityImage {
@@ -102,18 +103,18 @@ public class EntityImageDescription extends AbstractEntityImage {
 	private final boolean useRankSame;
 	private final boolean fixCircleLabelOverlapping;
 	private final Bibliotekon bibliotekon;
-	private final SymbolContext ctx;
+	private final Fashion ctx;
 
-	public EntityImageDescription(ILeaf entity, ISkinParam skinParam2, PortionShower portionShower,
-			Collection<Link> links, SName styleName, Bibliotekon bibliotekon) {
-		super(entity, entity.getColors().mute(skinParam2));
+	public EntityImageDescription(Entity entity, PortionShower portionShower, Collection<Link> links,
+			Bibliotekon bibliotekon) {
+		super(entity);
 		this.useRankSame = getSkinParam().useRankSame();
 		this.bibliotekon = bibliotekon;
 		this.fixCircleLabelOverlapping = getSkinParam().fixCircleLabelOverlapping();
 
 		this.links = links;
 		USymbol symbol = getUSymbol(entity);
-		if (symbol == USymbols.FOLDER)
+		if (symbol == USymbols.FOLDER || symbol == USymbols.PACKAGE)
 			this.shapeType = ShapeType.FOLDER;
 		else if (symbol == USymbols.HEXAGON)
 			this.shapeType = ShapeType.HEXAGON;
@@ -129,18 +130,26 @@ public class EntityImageDescription extends AbstractEntityImage {
 
 		final Colors colors = entity.getColors();
 
-		final StyleSignatureBasic tmp = StyleSignatureBasic.of(SName.root, SName.element, styleName, symbol.getSName(),
-				SName.title);
+		final StyleSignatureBasic signatureTitle;
+		if (symbol instanceof USymbolActorBusiness)
+			signatureTitle = StyleSignatureBasic.of(SName.root, SName.element, getStyleName(), SName.actor,
+					SName.business, SName.title);
+		else
+			signatureTitle = StyleSignatureBasic.of(SName.root, SName.element, getStyleName(), symbol.getSName(),
+					SName.title);
+
 		final Stereotype stereotype = entity.getStereotype();
-		final Style styleTitle = tmp.withTOBECHANGED(stereotype).getMergedStyle(getSkinParam().getCurrentStyleBuilder())
-				.eventuallyOverride(colors);
+		final Style styleTitle = signatureTitle.withTOBECHANGED(stereotype)
+				.getMergedStyle(getSkinParam().getCurrentStyleBuilder()).eventuallyOverride(colors);
 
-		final Style styleStereo = tmp.forStereotypeItself(stereotype)
-				.getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+		final Style styleStereo = StyleSignatureBasic
+				.of(SName.root, SName.element, getStyleName(), symbol.getSName(), SName.stereotype)
+				.forStereotypeItself(stereotype).getMergedStyle(getSkinParam().getCurrentStyleBuilder());
 
-		final Style style = StyleSignatureBasic.of(SName.root, SName.element, styleName, symbol.getSName())
-				.withTOBECHANGED(stereotype).getMergedStyle(getSkinParam().getCurrentStyleBuilder())
-				.eventuallyOverride(colors);
+		final StyleSignatureBasic signature = StyleSignatureBasic.of(SName.root, SName.element, getStyleName(),
+				symbol.getSName());
+		final Style style = signature.withTOBECHANGED(stereotype)
+				.getMergedStyle(getSkinParam().getCurrentStyleBuilder()).eventuallyOverride(colors);
 
 		final HColor forecolor = styleTitle.value(PName.LineColor).asColor(getSkinParam().getIHtmlColorSet());
 
@@ -150,48 +159,58 @@ public class EntityImageDescription extends AbstractEntityImage {
 
 		final double roundCorner = styleTitle.value(PName.RoundCorner).asDouble();
 		final double diagonalCorner = styleTitle.value(PName.DiagonalCorner).asDouble();
-		final double deltaShadow = styleTitle.value(PName.Shadowing).asDouble();
+		final double deltaShadow = styleTitle.getShadowing();
 		final UStroke stroke = styleTitle.getStroke(colors);
 		final FontConfiguration fcTitle = styleTitle.getFontConfiguration(getSkinParam().getIHtmlColorSet());
+		final FontConfiguration fc = style.getFontConfiguration(getSkinParam().getIHtmlColorSet());
 		final FontConfiguration fcStereo = styleStereo.getFontConfiguration(getSkinParam().getIHtmlColorSet());
 		final HorizontalAlignment defaultAlign = styleTitle.getHorizontalAlignment();
 
 		assert getStereo() == stereotype;
 
-		ctx = new SymbolContext(backcolor, forecolor).withStroke(stroke).withShadow(deltaShadow).withCorner(roundCorner,
+		ctx = new Fashion(backcolor, forecolor).withStroke(stroke).withShadow(deltaShadow).withCorner(roundCorner,
 				diagonalCorner);
 
-		final Display codeDisplay = Display.getWithNewlines(entity.getCodeGetName());
-		if ((entity.getDisplay().equals(codeDisplay) && symbol.getSName() == SName.package_)
+		final Display codeDisplay = Display.getWithNewlines(getSkinParam().getPragma(), entity.getName());
+		if ((entity.getDisplay().equalsLike(codeDisplay) && symbol.getSName() == SName.package_)
 				|| entity.getDisplay().isWhite())
 			desc = TextBlockUtils.empty(style.value(PName.MinimumWidth).asDouble(), 0);
+		else if (entity.getDisplay().equalsLike(codeDisplay))
+			desc = BodyFactory.create3(entity.getDisplay(), getSkinParam(), defaultAlign, fcTitle, style.wrapWidth(),
+					styleTitle);
 		else
-			desc = BodyFactory.create3(entity.getDisplay(), getSkinParam(), defaultAlign, fcTitle,
-					getSkinParam().wrapWidth(), styleTitle);
-
-		stereo = TextBlockUtils.empty(0, 0);
+			desc = BodyFactory.create3(entity.getDisplay(), getSkinParam(), defaultAlign, fc, style.wrapWidth(), style);
 
+		final List<String> stereotypeLabels = portionShower.getVisibleStereotypeLabels(entity);
 		if (stereotype != null && stereotype.getSprite(getSkinParam()) != null)
 			stereo = stereotype.getSprite(getSkinParam());
-		else if (stereotype != null && stereotype.getLabel(Guillemet.DOUBLE_COMPARATOR) != null
-				&& portionShower.showPortion(EntityPortion.STEREOTYPE, entity))
-			stereo = Display.getWithNewlines(stereotype.getLabel(getSkinParam().guillemet())).create(fcStereo,
-					HorizontalAlignment.CENTER, getSkinParam());
+		else if (stereotype == null || stereotype.getLabel(Guillemet.DOUBLE_COMPARATOR) == null
+				|| stereotypeLabels.isEmpty())
+			stereo = TextBlockUtils.empty(0, 0);
+		else
+			stereo = TextBlockUtils.withMargin(
+					Display.create(stereotypeLabels).create(fcStereo, HorizontalAlignment.CENTER, getSkinParam()), 1,
+					0);
 
 		name = BodyFactory.create2(getSkinParam().getDefaultTextAlignment(HorizontalAlignment.CENTER), codeDisplay,
 				getSkinParam(), stereotype, entity, styleTitle);
 
+		final HorizontalAlignment stereotypeAlignment = styleStereo.getHorizontalAlignment();
+
 		if (hideText)
 			asSmall = symbol.asSmall(TextBlockUtils.empty(0, 0), TextBlockUtils.empty(0, 0), TextBlockUtils.empty(0, 0),
-					ctx, getSkinParam().getStereotypeAlignment());
+					ctx, stereotypeAlignment);
 		else
-			asSmall = symbol.asSmall(name, desc, stereo, ctx, getSkinParam().getStereotypeAlignment());
+			asSmall = symbol.asSmall(name, desc, stereo, ctx, stereotypeAlignment);
 
 	}
 
-	private USymbol getUSymbol(ILeaf entity) {
-		final USymbol result = entity.getUSymbol() == null ? getSkinParam().componentStyle().toUSymbol()
-				: entity.getUSymbol();
+	private USymbol getUSymbol(Entity entity) {
+		final USymbol result;
+		if (entity.getUSymbol() == null)
+			result = getSkinParam().componentStyle().toUSymbol();
+		else
+			result = entity.getUSymbol();
 		return Objects.requireNonNull(result);
 	}
 
@@ -211,13 +230,13 @@ public class EntityImageDescription extends AbstractEntityImage {
 		if (hideText == false)
 			return Margins.NONE;
 
-		if (isThereADoubleLink((ILeaf) getEntity(), links))
+		if (isThereADoubleLink((Entity) getEntity(), links))
 			return Margins.NONE;
 
-		if (fixCircleLabelOverlapping == false && hasSomeHorizontalLinkVisible((ILeaf) getEntity(), links))
+		if (fixCircleLabelOverlapping == false && hasSomeHorizontalLinkVisible((Entity) getEntity(), links))
 			return Margins.NONE;
 
-		if (hasSomeHorizontalLinkDoubleDecorated((ILeaf) getEntity(), links))
+		if (hasSomeHorizontalLinkDoubleDecorated((Entity) getEntity(), links))
 			return Margins.NONE;
 
 		final XDimension2D dimStereo = stereo.calculateDimension(stringBounder);
@@ -232,7 +251,7 @@ public class EntityImageDescription extends AbstractEntityImage {
 		return new Margins(suppX / 2, suppX / 2, y, y);
 	}
 
-	private boolean hasSomeHorizontalLinkVisible(ILeaf leaf, Collection<Link> links) {
+	private boolean hasSomeHorizontalLinkVisible(Entity leaf, Collection<Link> links) {
 		for (Link link : links)
 			if (link.getLength() == 1 && link.contains(leaf) && link.isInvis() == false)
 				return true;
@@ -240,11 +259,11 @@ public class EntityImageDescription extends AbstractEntityImage {
 		return false;
 	}
 
-	private boolean isThereADoubleLink(ILeaf leaf, Collection<Link> links) {
-		final Set<IEntity> others = new HashSet<>();
+	private boolean isThereADoubleLink(Entity leaf, Collection<Link> links) {
+		final Set<Entity> others = new HashSet<>();
 		for (Link link : links) {
 			if (link.contains(leaf)) {
-				final IEntity other = link.getOther(leaf);
+				final Entity other = link.getOther(leaf);
 				final boolean changed = others.add(other);
 				if (changed == false)
 					return true;
@@ -254,7 +273,7 @@ public class EntityImageDescription extends AbstractEntityImage {
 		return false;
 	}
 
-	private boolean hasSomeHorizontalLinkDoubleDecorated(ILeaf leaf, Collection<Link> links) {
+	private boolean hasSomeHorizontalLinkDoubleDecorated(Entity leaf, Collection<Link> links) {
 		for (Link link : links)
 			if (link.getLength() == 1 && link.contains(leaf) && link.getType().isDoubleDecorated())
 				return true;
@@ -263,10 +282,15 @@ public class EntityImageDescription extends AbstractEntityImage {
 	}
 
 	final public void drawU(UGraphic ug) {
-		ug.draw(new UComment("entity " + getEntity().getCodeGetName()));
+		ug.draw(new UComment("entity " + getEntity().getName()));
 		final Map<UGroupType, String> typeIDent = new EnumMap<>(UGroupType.class);
-		typeIDent.put(UGroupType.CLASS, "elem " + getEntity().getCode() + " selected");
-		typeIDent.put(UGroupType.ID, "elem_" + getEntity().getCode());
+		typeIDent.put(UGroupType.CLASS, "entity");
+		typeIDent.put(UGroupType.ID, "entity_" + getEntity().getName());
+		typeIDent.put(UGroupType.DATA_ENTITY, getEntity().getName());
+		typeIDent.put(UGroupType.DATA_UID, getEntity().getUid());
+		typeIDent.put(UGroupType.DATA_QUALIFIED_NAME, getEntity().getQuark().getQualifiedName());
+		if (getEntity().getLocation() != null)
+			typeIDent.put(UGroupType.DATA_SOURCE_LINE, "" + getEntity().getLocation().getPosition());
 		ug.startGroup(typeIDent);
 
 		if (url != null)
@@ -326,4 +350,26 @@ public class EntityImageDescription extends AbstractEntityImage {
 		}
 		return 0;
 	}
+
+	@Override
+	public MagneticBorder getMagneticBorder() {
+		if (shapeType == ShapeType.FOLDER)
+			return asSmall.getMagneticBorder();
+//			return new MagneticBorder() {
+//
+//				@Override
+//				public UTranslate getForceAt(StringBounder stringBounder, XPoint2D pt) {
+//					if ((pt.getX() >= 0 && pt.getX() <= 0 + calculateDimension(stringBounder).getWidth()
+//							&& pt.getY() <= 0)) {
+//						final XDimension2D dimName = getNameDimension(stringBounder);
+//						if (pt.getX() < 0 + dimName.getWidth())
+//							return UTranslate.none();
+//
+//						return new UTranslate(0, dimName.getHeight() + 4);
+//					}
+//					return UTranslate.none();
+//				}
+//			};
+		return new MagneticBorderNone();
+	}
 }
