@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -38,15 +38,19 @@ package net.sourceforge.plantuml.svek.image;
 import java.util.EnumMap;
 import java.util.Map;
 
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.LeafType;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.UEllipse;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -54,37 +58,31 @@ import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.AbstractEntityImage;
 import net.sourceforge.plantuml.svek.ShapeType;
-import net.sourceforge.plantuml.ugraphic.UEllipse;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UGroupType;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.url.Url;
 
 public class EntityImageLollipopInterface extends AbstractEntityImage {
+    // ::remove folder when __HAXE__
 
 	private static final int SIZE = 10;
 
 	private final TextBlock desc;
-	private final SName sname;
 	private final Url url;
 
 	public StyleSignature getSignature() {
-		return StyleSignatureBasic.of(SName.root, SName.element, sname, SName.circle).withTOBECHANGED(getStereo());
+		return StyleSignatureBasic.of(SName.root, SName.element, getStyleName(), SName.circle).withTOBECHANGED(getStereo());
 	}
 
 	private UStroke getUStroke() {
-		return new UStroke(1.5);
+		return UStroke.withThickness(1.5);
 	}
 
-	public EntityImageLollipopInterface(ILeaf entity, ISkinParam skinParam, SName sname) {
-		super(entity, skinParam);
-		this.sname = sname;
+	public EntityImageLollipopInterface(Entity entity) {
+		super(entity);
 
 		final FontConfiguration fc = FontConfiguration.create(getSkinParam(),
-				getSignature().getMergedStyle(skinParam.getCurrentStyleBuilder()));
+				getSignature().getMergedStyle(getSkinParam().getCurrentStyleBuilder()));
 
-		this.desc = entity.getDisplay().create(fc, HorizontalAlignment.CENTER, skinParam);
+		this.desc = entity.getDisplay().create(fc, HorizontalAlignment.CENTER, getSkinParam());
 		this.url = entity.getUrl99();
 
 	}
@@ -98,13 +96,13 @@ public class EntityImageLollipopInterface extends AbstractEntityImage {
 		final Style style = getSignature().getMergedStyle(getSkinParam().getCurrentStyleBuilder());
 		final HColor backgroundColor = style.value(PName.BackGroundColor).asColor(getSkinParam().getIHtmlColorSet());
 		final HColor borderColor = style.value(PName.LineColor).asColor(getSkinParam().getIHtmlColorSet());
-		final double shadow = style.value(PName.Shadowing).asDouble();
+		final double shadow = style.getShadowing();
 
 		final UEllipse circle;
 		if (getEntity().getLeafType() == LeafType.LOLLIPOP_HALF) {
 			circle = new UEllipse(SIZE, SIZE, angle - 90, 180);
 		} else {
-			circle = new UEllipse(SIZE, SIZE);
+			circle = UEllipse.build(SIZE, SIZE);
 			if (getSkinParam().shadowing(getEntity().getStereotype()))
 				circle.setDeltaShadow(shadow);
 		}
@@ -114,8 +112,13 @@ public class EntityImageLollipopInterface extends AbstractEntityImage {
 			ug.startUrl(url);
 
 		final Map<UGroupType, String> typeIDent = new EnumMap<>(UGroupType.class);
-		typeIDent.put(UGroupType.CLASS, "elem " + getEntity().getCode() + " selected");
-		typeIDent.put(UGroupType.ID, "elem_" + getEntity().getCode());
+		typeIDent.put(UGroupType.CLASS, "entity");
+		typeIDent.put(UGroupType.ID, "entity_" + getEntity().getName());
+		typeIDent.put(UGroupType.DATA_ENTITY, getEntity().getName());
+		typeIDent.put(UGroupType.DATA_UID, getEntity().getUid());
+		typeIDent.put(UGroupType.DATA_QUALIFIED_NAME, getEntity().getQuark().getQualifiedName());
+		if (getEntity().getLocation() != null)
+			typeIDent.put(UGroupType.DATA_SOURCE_LINE, "" + getEntity().getLocation().getPosition());
 		ug.startGroup(typeIDent);
 		ug.apply(getUStroke()).draw(circle);
 		ug.closeGroup();
