@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -36,45 +36,46 @@
 
 package net.sourceforge.plantuml.svek.image;
 
-import net.sourceforge.plantuml.FontParam;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
-import net.sourceforge.plantuml.cucadiagram.EntityPosition;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.color.ColorType;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.EntityPosition;
+import net.sourceforge.plantuml.klimt.Shadowable;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontParam;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.URectangle;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
-import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.Bibliotekon;
 import net.sourceforge.plantuml.svek.Cluster;
 import net.sourceforge.plantuml.svek.ShapeType;
 import net.sourceforge.plantuml.svek.SvekNode;
-import net.sourceforge.plantuml.ugraphic.Shadowable;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.URectangle;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+
+import java.util.EnumMap;
+import java.util.Map;
 
 public class EntityImagePort extends AbstractEntityImageBorder {
 
-	private final SName sname;
-
-	public EntityImagePort(ILeaf leaf, ISkinParam skinParam, Cluster parent, Bibliotekon bibliotekon, SName sname) {
-		super(leaf, skinParam, parent, bibliotekon, FontParam.BOUNDARY);
-		this.sname = sname;
+	public EntityImagePort(Entity leaf, Cluster parent, Bibliotekon bibliotekon) {
+		super(leaf, parent, bibliotekon, FontParam.BOUNDARY);
 	}
 
-	private StyleSignature getSignature() {
-		return StyleSignatureBasic.of(SName.root, SName.element, sname, SName.port).withTOBECHANGED(getStereo());
+	@Override
+	protected StyleSignatureBasic getSignature() {
+		return StyleSignatureBasic.of(SName.root, SName.element, getStyleName(), SName.port);
 	}
 
 	private boolean upPosition() {
-		final XPoint2D clusterCenter = parent.getClusterPosition().getPointCenter();
+		final XPoint2D clusterCenter = parent.getRectangleArea().getPointCenter();
 		final SvekNode node = bibliotekon.getNode(getEntity());
 		return node.getMinY() < clusterCenter.getY();
 	}
@@ -85,16 +86,18 @@ public class EntityImagePort extends AbstractEntityImageBorder {
 	}
 
 	public double getMaxWidthFromLabelForEntryExit(StringBounder stringBounder) {
+		final TextBlock desc = getDesc();
 		final XDimension2D dimDesc = desc.calculateDimension(stringBounder);
 		return dimDesc.getWidth();
 	}
 
 	private void drawSymbol(UGraphic ug) {
-		final Shadowable rect = new URectangle(EntityPosition.RADIUS * 2, EntityPosition.RADIUS * 2);
+		final Shadowable rect = URectangle.build(EntityPosition.RADIUS * 2, EntityPosition.RADIUS * 2);
 		ug.draw(rect);
 	}
 
 	final public void drawU(UGraphic ug) {
+		final TextBlock desc = getDesc();
 		double y = 0;
 		final XDimension2D dimDesc = desc.calculateDimension(ug.getStringBounder());
 		final double x = 0 - (dimDesc.getWidth() - 2 * EntityPosition.RADIUS) / 2;
@@ -104,9 +107,19 @@ public class EntityImagePort extends AbstractEntityImageBorder {
 		else
 			y += 2 * EntityPosition.RADIUS;
 
+		final Map<UGroupType, String> typeIDent = new EnumMap<>(UGroupType.class);
+		typeIDent.put(UGroupType.CLASS, "entity");
+		typeIDent.put(UGroupType.ID, "entity_" + getEntity().getName());
+		typeIDent.put(UGroupType.DATA_ENTITY, getEntity().getName());
+		typeIDent.put(UGroupType.DATA_UID, getEntity().getUid());
+		typeIDent.put(UGroupType.DATA_QUALIFIED_NAME, getEntity().getQuark().getQualifiedName());
+		if (getEntity().getLocation() != null)
+			typeIDent.put(UGroupType.DATA_SOURCE_LINE, "" + getEntity().getLocation().getPosition());
+		ug.startGroup(typeIDent);
+
 		desc.drawU(ug.apply(new UTranslate(x, y)));
 
-		final Style style = getSignature().getMergedStyle(getSkinParam().getCurrentStyleBuilder());
+		final Style style = getStyle();
 
 		HColor backcolor = getEntity().getColors().getColor(ColorType.BACK);
 		HColor borderColor = getEntity().getColors().getColor(ColorType.LINE);
@@ -121,10 +134,12 @@ public class EntityImagePort extends AbstractEntityImageBorder {
 		ug = ug.apply(getUStroke()).apply(backcolor.bg());
 
 		drawSymbol(ug);
+
+		ug.closeGroup();
 	}
 
 	private UStroke getUStroke() {
-		return new UStroke(1.5);
+		return UStroke.withThickness(1.5);
 	}
 
 	public ShapeType getShapeType() {
