@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -36,29 +36,36 @@
 package net.sourceforge.plantuml.svek.image;
 
 import java.util.EnumMap;
+import java.util.List;
 import java.util.Map;
 
-import net.sourceforge.plantuml.FontParam;
-import net.sourceforge.plantuml.Guillemet;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.Url;
-import net.sourceforge.plantuml.awt.geom.XDimension2D;
-import net.sourceforge.plantuml.awt.geom.XPoint2D;
-import net.sourceforge.plantuml.creole.Stencil;
+import net.sourceforge.plantuml.abel.Entity;
+import net.sourceforge.plantuml.abel.LeafType;
 import net.sourceforge.plantuml.cucadiagram.BodyFactory;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.cucadiagram.EntityPortion;
-import net.sourceforge.plantuml.cucadiagram.ILeaf;
-import net.sourceforge.plantuml.cucadiagram.LeafType;
 import net.sourceforge.plantuml.cucadiagram.PortionShower;
-import net.sourceforge.plantuml.cucadiagram.Stereotype;
-import net.sourceforge.plantuml.graphic.FontConfiguration;
-import net.sourceforge.plantuml.graphic.HorizontalAlignment;
-import net.sourceforge.plantuml.graphic.StringBounder;
-import net.sourceforge.plantuml.graphic.TextBlock;
-import net.sourceforge.plantuml.graphic.TextBlockUtils;
-import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.klimt.UGroupType;
+import net.sourceforge.plantuml.klimt.UStroke;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.creole.Stencil;
+import net.sourceforge.plantuml.klimt.drawing.AbstractUGraphicHorizontalLine;
+import net.sourceforge.plantuml.klimt.drawing.UGraphic;
+import net.sourceforge.plantuml.klimt.font.FontConfiguration;
+import net.sourceforge.plantuml.klimt.font.FontParam;
+import net.sourceforge.plantuml.klimt.font.StringBounder;
+import net.sourceforge.plantuml.klimt.geom.HorizontalAlignment;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
+import net.sourceforge.plantuml.klimt.geom.XPoint2D;
+import net.sourceforge.plantuml.klimt.shape.TextBlock;
+import net.sourceforge.plantuml.klimt.shape.TextBlockInEllipse;
+import net.sourceforge.plantuml.klimt.shape.TextBlockUtils;
+import net.sourceforge.plantuml.klimt.shape.UEllipse;
+import net.sourceforge.plantuml.klimt.shape.UHorizontalLine;
+import net.sourceforge.plantuml.klimt.shape.ULine;
+import net.sourceforge.plantuml.stereo.Stereotype;
 import net.sourceforge.plantuml.style.PName;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
@@ -66,16 +73,8 @@ import net.sourceforge.plantuml.style.StyleSignature;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
 import net.sourceforge.plantuml.svek.AbstractEntityImage;
 import net.sourceforge.plantuml.svek.ShapeType;
-import net.sourceforge.plantuml.ugraphic.AbstractUGraphicHorizontalLine;
-import net.sourceforge.plantuml.ugraphic.TextBlockInEllipse;
-import net.sourceforge.plantuml.ugraphic.UEllipse;
-import net.sourceforge.plantuml.ugraphic.UGraphic;
-import net.sourceforge.plantuml.ugraphic.UGroupType;
-import net.sourceforge.plantuml.ugraphic.UHorizontalLine;
-import net.sourceforge.plantuml.ugraphic.ULine;
-import net.sourceforge.plantuml.ugraphic.UStroke;
-import net.sourceforge.plantuml.ugraphic.UTranslate;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.text.Guillemet;
+import net.sourceforge.plantuml.url.Url;
 
 public class EntityImageUseCase extends AbstractEntityImage {
 
@@ -83,8 +82,8 @@ public class EntityImageUseCase extends AbstractEntityImage {
 
 	final private Url url;
 
-	public EntityImageUseCase(ILeaf entity, ISkinParam skinParam2, PortionShower portionShower) {
-		super(entity, entity.getColors().mute(skinParam2));
+	public EntityImageUseCase(Entity entity, PortionShower portionShower) {
+		super(entity);
 		final Stereotype stereotype = entity.getStereotype();
 
 		final Style style = getStyle();
@@ -93,20 +92,21 @@ public class EntityImageUseCase extends AbstractEntityImage {
 		final TextBlock tmp = BodyFactory.create2(getSkinParam().getDefaultTextAlignment(align), entity.getDisplay(),
 				getSkinParam(), stereotype, entity, getStyle());
 
-		if (stereotype == null || stereotype.getLabel(Guillemet.DOUBLE_COMPARATOR) == null
-				|| portionShower.showPortion(EntityPortion.STEREOTYPE, entity) == false) {
-			this.desc = tmp;
-		} else {
-			final TextBlock stereo;
-			if (stereotype.getSprite(getSkinParam()) != null) {
-				stereo = stereotype.getSprite(getSkinParam());
-			} else {
-				stereo = Display.getWithNewlines(stereotype.getLabel(getSkinParam().guillemet())).create(
-						FontConfiguration.create(getSkinParam(), FontParam.USECASE_STEREOTYPE, stereotype),
-						HorizontalAlignment.CENTER, getSkinParam());
-			}
-			this.desc = TextBlockUtils.mergeTB(stereo, tmp, HorizontalAlignment.CENTER);
+		final TextBlock stereo;
+		final List<String> stereotypeLabels = portionShower.getVisibleStereotypeLabels(entity);
+		if (stereotype != null && stereotype.getSprite(getSkinParam()) != null)
+			stereo = stereotype.getSprite(getSkinParam());
+		else if (stereotype == null || stereotype.getLabel(Guillemet.DOUBLE_COMPARATOR) == null
+				|| stereotypeLabels.isEmpty())
+			stereo = TextBlockUtils.EMPTY_TEXT_BLOCK;
+		else {
+			final FontConfiguration fcStereo = FontConfiguration.create(getSkinParam(), FontParam.USECASE_STEREOTYPE,
+					stereotype);
+			final Display display = Display.create(stereotypeLabels);
+			stereo = display.create(fcStereo, HorizontalAlignment.CENTER, getSkinParam());
 		}
+		this.desc = TextBlockUtils.mergeTB(stereo, tmp, HorizontalAlignment.CENTER);
+
 		this.url = entity.getUrl99();
 
 	}
@@ -119,7 +119,7 @@ public class EntityImageUseCase extends AbstractEntityImage {
 		final StringBounder stringBounder = ug.getStringBounder();
 
 		final Style style = getStyle();
-		final double shadow = style.value(PName.Shadowing).asDouble();
+		final double shadow = style.getShadowing();
 
 		final TextBlockInEllipse ellipse = new TextBlockInEllipse(desc, stringBounder);
 		ellipse.setDeltaShadow(shadow);
@@ -135,8 +135,13 @@ public class EntityImageUseCase extends AbstractEntityImage {
 		final UGraphic ug2 = new MyUGraphicEllipse(ug, 0, 0, ellipse.getUEllipse());
 
 		final Map<UGroupType, String> typeIDent = new EnumMap<>(UGroupType.class);
-		typeIDent.put(UGroupType.CLASS, "elem " + getEntity().getCode() + " selected");
-		typeIDent.put(UGroupType.ID, "elem_" + getEntity().getCode());
+		typeIDent.put(UGroupType.CLASS, "entity");
+		typeIDent.put(UGroupType.ID, "entity_" + getEntity().getName());
+		typeIDent.put(UGroupType.DATA_ENTITY, getEntity().getName());
+		typeIDent.put(UGroupType.DATA_UID, getEntity().getUid());
+		typeIDent.put(UGroupType.DATA_QUALIFIED_NAME, getEntity().getQuark().getQualifiedName());
+		if (getEntity().getLocation() != null)
+			typeIDent.put(UGroupType.DATA_SOURCE_LINE, "" + getEntity().getLocation().getPosition());
 		ug.startGroup(typeIDent);
 		ellipse.drawU(ug2);
 		ug2.closeGroup();
@@ -170,7 +175,7 @@ public class EntityImageUseCase extends AbstractEntityImage {
 	}
 
 	private void drawLine(UGraphic ug, final XPoint2D p1, final XPoint2D p2) {
-		ug = ug.apply(new UTranslate(p1));
+		ug = ug.apply(UTranslate.point(p1));
 		ug.draw(new ULine(p2.getX() - p1.getX(), p2.getY() - p1.getY()));
 	}
 
@@ -194,6 +199,11 @@ public class EntityImageUseCase extends AbstractEntityImage {
 	}
 
 	private StyleSignature getDefaultStyleDefinition() {
+		final LeafType type = getEntity().getLeafType();
+		if (type == LeafType.USECASE_BUSINESS)
+			return StyleSignatureBasic
+					.of(SName.root, SName.element, SName.componentDiagram, SName.usecase, SName.business)
+					.withTOBECHANGED(getStereo());
 		return StyleSignatureBasic.of(SName.root, SName.element, SName.componentDiagram, SName.usecase)
 				.withTOBECHANGED(getStereo());
 	}
@@ -264,7 +274,7 @@ public class EntityImageUseCase extends AbstractEntityImage {
 
 		@Override
 		protected void drawHline(UGraphic ug, UHorizontalLine line, UTranslate translate) {
-			final UStroke stroke = new UStroke(1.5);
+			final UStroke stroke = UStroke.withThickness(1.5);
 			line.drawLineInternal(ug.apply(translate), getStencil2(translate), 0, stroke);
 		}
 
