@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  *
  * If you like this project or if you find it useful, you can support us at:
  *
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  *
  * This file is part of PlantUML.
  *
@@ -34,7 +34,6 @@
  */
 package net.sourceforge.plantuml.tim.expression;
 
-
 //https://en.cppreference.com/w/c/language/operator_precedence
 
 public enum TokenOperator {
@@ -53,7 +52,7 @@ public enum TokenOperator {
 			return v1.add(v2);
 		}
 	},
-	SUBSTRACTION(100 - 4, "-") {
+	SUBSTRACTION(100 - 4, "" + TokenType.COMMERCIAL_MINUS_SIGN) {
 		public TValue operate(TValue v1, TValue v2) {
 			return v1.minus(v2);
 		}
@@ -97,8 +96,7 @@ public enum TokenOperator {
 		public TValue operate(TValue v1, TValue v2) {
 			return v1.logicalOr(v2);
 		}
-	},
-	;
+	};
 
 	private final int precedence;
 	private final String display;
@@ -113,16 +111,14 @@ public enum TokenOperator {
 	}
 
 	public static TokenOperator getTokenOperator(char ch, char ch2) {
-		for (TokenOperator op : TokenOperator.values()) {
-			if (op.display.length() == 2 && op.display.charAt(0) == ch && op.display.charAt(1) == ch2) {
+		for (TokenOperator op : TokenOperator.values())
+			if (op.display.length() == 2 && op.display.charAt(0) == ch && op.display.charAt(1) == ch2)
 				return op;
-			}
-		}
-		for (TokenOperator op : TokenOperator.values()) {
-			if (op.display.length() == 1 && op.display.charAt(0) == ch) {
+
+		for (TokenOperator op : TokenOperator.values())
+			if (op.display.length() == 1 && op.display.charAt(0) == ch)
 				return op;
-			}
-		}
+
 		return null;
 	}
 
