@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -35,14 +35,15 @@
  */
 package net.sourceforge.plantuml.utils;
 
-import net.sourceforge.plantuml.StringLocated;
 import net.sourceforge.plantuml.StringUtils;
-import net.sourceforge.plantuml.command.regex.Matcher2;
-import net.sourceforge.plantuml.command.regex.MyPattern;
-import net.sourceforge.plantuml.command.regex.Pattern2;
 import net.sourceforge.plantuml.core.DiagramType;
+import net.sourceforge.plantuml.regex.Matcher2;
+import net.sourceforge.plantuml.regex.MyPattern;
+import net.sourceforge.plantuml.regex.Pattern2;
+import net.sourceforge.plantuml.text.StringLocated;
 
 public class StartUtils {
+	// ::remove file when __HAXE__
 
 	public static final Pattern2 patternFilename = MyPattern
 			.cmpile("^[@\\\\]start[^%s{}%g]+[%s{][%s%g]*([^%g]*?)[%s}%g]*$");
@@ -54,14 +55,14 @@ public class StartUtils {
 		boolean inside = false;
 		for (int i = 0; i < s.length(); i++) {
 			final String tmp = s.substring(i, s.length());
-			if (startsWithSymbolAnd("start", tmp)) {
+			if (startsWithSymbolAnd("start", tmp))
 				return s.substring(0, i);
-			}
+
 			final String single = s.substring(i, i + 1);
 			if (inside) {
-				if (single.equals(">")) {
+				if (single.equals(">"))
 					inside = false;
-				}
+
 				continue;
 			}
 			if (single.equals("<")) {
@@ -80,9 +81,9 @@ public class StartUtils {
 
 	public static boolean isArobaseStartDiagram(String s) {
 		final String s2 = StringUtils.trinNoTrace(s);
-		if (s2.startsWith("@") == false && s2.startsWith("\\") == false) {
+		if (s2.startsWith("@") == false && s2.startsWith("\\") == false)
 			return false;
-		}
+
 		return DiagramType.getTypeFromArobaseStart(s2) != DiagramType.UNKNOWN;
 	}
 
@@ -96,9 +97,9 @@ public class StartUtils {
 
 	public static boolean startOrEnd(final StringLocated s) {
 		final String s2 = StringUtils.trinNoTrace(s.getString());
-		if (s2.startsWith("@") == false && s2.startsWith("\\") == false) {
+		if (s2.startsWith("@") == false && s2.startsWith("\\") == false)
 			return false;
-		}
+
 		return startsWithSymbolAnd("end", s2) || DiagramType.getTypeFromArobaseStart(s2) != DiagramType.UNKNOWN;
 	}
 
