@@ -2,14 +2,14 @@
  * PlantUML : a free UML diagram generator
  * ========================================================================
  *
- * (C) Copyright 2009-2023, Arnaud Roques
+ * (C) Copyright 2009-2024, Arnaud Roques
  *
- * Project Info:  http://plantuml.com
+ * Project Info:  https://plantuml.com
  * 
  * If you like this project or if you find it useful, you can support us at:
  * 
- * http://plantuml.com/patreon (only 1$ per month!)
- * http://plantuml.com/paypal
+ * https://plantuml.com/patreon (only 1$ per month!)
+ * https://plantuml.com/paypal
  * 
  * This file is part of PlantUML.
  *
@@ -40,52 +40,65 @@ import java.util.Collection;
 import java.util.Collections;
 import java.util.List;
 
-import net.sourceforge.plantuml.Direction;
-import net.sourceforge.plantuml.ISkinParam;
-import net.sourceforge.plantuml.SkinParamColors;
-import net.sourceforge.plantuml.cucadiagram.Display;
-import net.sourceforge.plantuml.graphic.color.ColorType;
-import net.sourceforge.plantuml.graphic.color.Colors;
+import net.sourceforge.plantuml.annotation.DuplicateCode;
+import net.sourceforge.plantuml.klimt.UTranslate;
+import net.sourceforge.plantuml.klimt.color.ColorType;
+import net.sourceforge.plantuml.klimt.color.Colors;
+import net.sourceforge.plantuml.klimt.color.HColor;
+import net.sourceforge.plantuml.klimt.creole.Display;
+import net.sourceforge.plantuml.klimt.geom.XDimension2D;
 import net.sourceforge.plantuml.mindmap.IdeaShape;
+import net.sourceforge.plantuml.skin.SkinParamColors;
+import net.sourceforge.plantuml.stereo.Stereotype;
+import net.sourceforge.plantuml.style.ISkinParam;
 import net.sourceforge.plantuml.style.MergeStrategy;
 import net.sourceforge.plantuml.style.SName;
 import net.sourceforge.plantuml.style.Style;
 import net.sourceforge.plantuml.style.StyleBuilder;
 import net.sourceforge.plantuml.style.StyleSignatureBasic;
-import net.sourceforge.plantuml.ugraphic.color.HColor;
+import net.sourceforge.plantuml.utils.Direction;
 
 final public class WElement {
 
 	private final HColor backColor;
 	private final Display label;
 	private final int level;
-	private final String stereotype;
+	private final Stereotype stereotype;
 	private final WElement parent;
 	private final StyleBuilder styleBuilder;
 	private final List<WElement> childrenLeft = new ArrayList<>();
 	private final List<WElement> childrenRight = new ArrayList<>();
 	private final IdeaShape shape;
+	private UTranslate position;
+	private XDimension2D dimension;
 
+	@DuplicateCode(reference = "Idea")
 	private StyleSignatureBasic getDefaultStyleDefinitionNode(int level) {
 		final String depth = SName.depth(level);
 		if (level == 0)
-			return StyleSignatureBasic.of(SName.root, SName.element, SName.wbsDiagram, SName.node, SName.rootNode)
-					.add(stereotype).add(depth);
+			if (shape == IdeaShape.NONE)
+				return StyleSignatureBasic
+						.of(SName.root, SName.element, SName.wbsDiagram, SName.node, SName.rootNode, SName.boxless)
+						.addS(stereotype).add(depth);
+			else
+				return StyleSignatureBasic.of(SName.root, SName.element, SName.wbsDiagram, SName.node, SName.rootNode)
+						.addS(stereotype).add(depth);
 
 		if (shape == IdeaShape.NONE && isLeaf())
 			return StyleSignatureBasic
 					.of(SName.root, SName.element, SName.wbsDiagram, SName.node, SName.leafNode, SName.boxless)
-					.add(stereotype).add(depth);
+					.addS(stereotype).add(depth);
 
 		if (isLeaf())
 			return StyleSignatureBasic.of(SName.root, SName.element, SName.wbsDiagram, SName.node, SName.leafNode)
-					.add(stereotype).add(depth);
+					.addS(stereotype).add(depth);
 
 		if (shape == IdeaShape.NONE)
 			return StyleSignatureBasic.of(SName.root, SName.element, SName.wbsDiagram, SName.node, SName.boxless)
-					.add(stereotype).add(depth);
+					.addS(stereotype).add(depth);
 
-		return StyleSignatureBasic.of(SName.root, SName.element, SName.wbsDiagram, SName.node).add(stereotype).add(depth);
+		return StyleSignatureBasic.of(SName.root, SName.element, SName.wbsDiagram, SName.node).addS(stereotype)
+				.add(depth);
 	}
 
 	public ISkinParam withBackColor(ISkinParam skinParam) {
@@ -109,12 +122,13 @@ final public class WElement {
 		return result;
 	}
 
-	public WElement(HColor backColor, Display label, String stereotype, StyleBuilder styleBuilder, IdeaShape shape) {
+	public WElement(HColor backColor, Display label, Stereotype stereotype, StyleBuilder styleBuilder,
+			IdeaShape shape) {
 		this(backColor, 0, label, stereotype, null, shape, styleBuilder);
 	}
 
-	private WElement(HColor backColor, int level, Display label, String stereotype, WElement parent, IdeaShape shape,
-			StyleBuilder styleBuilder) {
+	private WElement(HColor backColor, int level, Display label, Stereotype stereotype, WElement parent,
+			IdeaShape shape, StyleBuilder styleBuilder) {
 		this.label = label;
 		this.backColor = backColor;
 		this.level = level;
@@ -128,7 +142,7 @@ final public class WElement {
 		return childrenLeft.size() == 0 && childrenRight.size() == 0;
 	}
 
-	public WElement createElement(HColor backColor, int newLevel, Display newLabel, String stereotype,
+	public WElement createElement(HColor backColor, int newLevel, Display newLabel, Stereotype stereotype,
 			Direction direction, IdeaShape shape, StyleBuilder styleBuilder) {
 		final WElement result = new WElement(backColor, newLevel, newLabel, stereotype, this, shape, styleBuilder);
 		if (direction == Direction.LEFT && newLevel == 1)
@@ -172,4 +186,21 @@ final public class WElement {
 		return styleBuilder;
 	}
 
+	public final void setGeometry(UTranslate position, XDimension2D dimension) {
+		this.position = position;
+		this.dimension = dimension;
+	}
+
+	public final UTranslate getPosition() {
+		return position;
+	}
+
+	public final XDimension2D getDimension() {
+		return dimension;
+	}
+
+	public Stereotype getStereotype() {
+		return stereotype;
+	}
+
 }
